"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

from collections import abc as _abc
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import wrappers_pb2 as _wrappers_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
import builtins as _builtins
import sys
import typing as _typing

if sys.version_info >= (3, 10):
    from typing import TypeAlias as _TypeAlias
else:
    from typing_extensions import TypeAlias as _TypeAlias

DESCRIPTOR: _descriptor.FileDescriptor

@_typing.final
class UserData(_message.Message):
    DESCRIPTOR: _descriptor.Descriptor

    class _UserLinkType:
        ValueType = _typing.NewType("ValueType", _builtins.int)
        V: _TypeAlias = ValueType  # noqa: Y015

    class _UserLinkTypeEnumTypeWrapper(_enum_type_wrapper._EnumTypeWrapper[UserData._UserLinkType.ValueType], _builtins.type):
        DESCRIPTOR: _descriptor.EnumDescriptor
        USER_LINK_TYPE_UNSPECIFIED: UserData._UserLinkType.ValueType  # 0
        USER_LINK_TYPE_PARENT: UserData._UserLinkType.ValueType  # 1
        USER_LINK_TYPE_CHILD: UserData._UserLinkType.ValueType  # 2

    class UserLinkType(_UserLinkType, metaclass=_UserLinkTypeEnumTypeWrapper): ...
    USER_LINK_TYPE_UNSPECIFIED: UserData.UserLinkType.ValueType  # 0
    USER_LINK_TYPE_PARENT: UserData.UserLinkType.ValueType  # 1
    USER_LINK_TYPE_CHILD: UserData.UserLinkType.ValueType  # 2

    class _UserLinkStatus:
        ValueType = _typing.NewType("ValueType", _builtins.int)
        V: _TypeAlias = ValueType  # noqa: Y015

    class _UserLinkStatusEnumTypeWrapper(_enum_type_wrapper._EnumTypeWrapper[UserData._UserLinkStatus.ValueType], _builtins.type):
        DESCRIPTOR: _descriptor.EnumDescriptor
        USER_LINK_STATUS_UNSPECIFIED: UserData._UserLinkStatus.ValueType  # 0
        USER_LINK_STATUS_PENDING: UserData._UserLinkStatus.ValueType  # 1
        USER_LINK_STATUS_ACTIVE: UserData._UserLinkStatus.ValueType  # 2
        USER_LINK_STATUS_INACTIVE: UserData._UserLinkStatus.ValueType  # 3
        USER_LINK_STATUS_DECLINED: UserData._UserLinkStatus.ValueType  # 4

    class UserLinkStatus(_UserLinkStatus, metaclass=_UserLinkStatusEnumTypeWrapper): ...
    USER_LINK_STATUS_UNSPECIFIED: UserData.UserLinkStatus.ValueType  # 0
    USER_LINK_STATUS_PENDING: UserData.UserLinkStatus.ValueType  # 1
    USER_LINK_STATUS_ACTIVE: UserData.UserLinkStatus.ValueType  # 2
    USER_LINK_STATUS_INACTIVE: UserData.UserLinkStatus.ValueType  # 3
    USER_LINK_STATUS_DECLINED: UserData.UserLinkStatus.ValueType  # 4

    class _ClassificationType:
        ValueType = _typing.NewType("ValueType", _builtins.int)
        V: _TypeAlias = ValueType  # noqa: Y015

    class _ClassificationTypeEnumTypeWrapper(_enum_type_wrapper._EnumTypeWrapper[UserData._ClassificationType.ValueType], _builtins.type):
        DESCRIPTOR: _descriptor.EnumDescriptor
        CLASSIFICATION_TYPE_UNSPECIFIED: UserData._ClassificationType.ValueType  # 0
        CLASSIFICATION_TYPE_UNKNOWN: UserData._ClassificationType.ValueType  # 1
        CLASSIFICATION_TYPE_UNSOLICITED_PORNOGRAPHY: UserData._ClassificationType.ValueType  # 100
        CLASSIFICATION_TYPE_NONCONSENSUAL_PORNOGRAPHY: UserData._ClassificationType.ValueType  # 200
        CLASSIFICATION_TYPE_GLORIFYING_VIOLENCE: UserData._ClassificationType.ValueType  # 210
        CLASSIFICATION_TYPE_HATE_SPEECH: UserData._ClassificationType.ValueType  # 220
        CLASSIFICATION_TYPE_CRACKED_ACCOUNTS: UserData._ClassificationType.ValueType  # 230
        CLASSIFICATION_TYPE_ILLICIT_GOODS: UserData._ClassificationType.ValueType  # 240
        CLASSIFICATION_TYPE_SOCIAL_ENGINEERING: UserData._ClassificationType.ValueType  # 250
        CLASSIFICATION_TYPE_SELF_GENERATED_CSAM_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 260
        CLASSIFICATION_TYPE_UNDERAGE_USER_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 270
        CLASSIFICATION_TYPE_CSAM_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 280
        CLASSIFICATION_TYPE_CSAM_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 286
        CLASSIFICATION_TYPE_DOXXING_MEDIUM_RISK_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 290
        CLASSIFICATION_TYPE_DOXXING_MEDIUM_RISK_TIER_2_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 296
        CLASSIFICATION_TYPE_DOXXING_HIGH_RISK_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 300
        CLASSIFICATION_TYPE_DOXXING_HIGH_RISK_TIER_1_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 306
        CLASSIFICATION_TYPE_HARASSMENT_AND_THREATS_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 310
        CLASSIFICATION_TYPE_HATE_SPEECH_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 320
        CLASSIFICATION_TYPE_HATE_SPEECH_AND_SYMBOLS_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 326
        CLASSIFICATION_TYPE_VIOLENCE_GLORIFICATION_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 330
        CLASSIFICATION_TYPE_VIOLENCE_GLORIFICATION_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 336
        CLASSIFICATION_TYPE_REGULATED_GOODS_HIGH_RISK_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 340
        CLASSIFICATION_TYPE_REGULATED_GOODS_MEDIUM_RISK_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 350
        CLASSIFICATION_TYPE_MEDIUM_RISK_DANGEROUS_AND_REGULATED_GOODS_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 356
        CLASSIFICATION_TYPE_REGULATED_GOODS_LOW_RISK_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 360
        CLASSIFICATION_TYPE_FRAUD_SERVICES_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 370
        CLASSIFICATION_TYPE_FRAUD_SERVICES_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 376
        CLASSIFICATION_TYPE_FINANCIAL_SCAMS_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 380
        CLASSIFICATION_TYPE_SEXUAL_HARASSMENT_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 390
        CLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_EXPLICIT_CONTENT_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 400
        CLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_EXPLICIT_CONTENT_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 406
        CLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_SUGGESTIVE_MEDIA_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 410
        CLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_SUGGESTIVE_MEDIA_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 416
        CLASSIFICATION_TYPE_TRANSACTION_SCAMS_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 420
        CLASSIFICATION_TYPE_CSAM_MEDIUM_CONFIDENCE_HASH_MATCH: UserData._ClassificationType.ValueType  # 500
        CLASSIFICATION_TYPE_CSAM_HIGH_CONFIDENCE_HASH_MATCH: UserData._ClassificationType.ValueType  # 501
        CLASSIFICATION_TYPE_CSAM_MEDIUM_CONFIDENCE_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 510
        CLASSIFICATION_TYPE_CHILD_SEXUALIZATION_CONTENT_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 520
        CLASSIFICATION_TYPE_CHILD_SEXUALIZATION_CONTENT_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 526
        CLASSIFICATION_TYPE_CHILD_LED_SEXUAL_SELF_ENDANGERMENT_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 530
        CLASSIFICATION_TYPE_CHILD_LED_SEXUAL_SELF_ENDANGERMENT_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 536
        CLASSIFICATION_TYPE_CHILD_ENGAGING_WITH_SEXUALLY_EXPLICIT_CONTENT_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 540
        CLASSIFICATION_TYPE_TRIBUTES_AND_LEAKED_ADULT_INTIMATE_MEDIA_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 550
        CLASSIFICATION_TYPE_TRIBUTES_AND_LEAKED_ADULT_INTIMATE_MEDIA_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 556
        CLASSIFICATION_TYPE_POSTING_AGERESTRICTED_CONTENT_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 560
        CLASSIFICATION_TYPE_DENIAL_OF_HUMAN_ATROCITY_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 570
        CLASSIFICATION_TYPE_DENIAL_OF_HUMAN_ATROCITY_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 576
        CLASSIFICATION_TYPE_SUICIDE_PROMOTION_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 580
        CLASSIFICATION_TYPE_SUICIDE_PROMOTION_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 586
        CLASSIFICATION_TYPE_SELF_HARM_PROMOTION_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 590
        CLASSIFICATION_TYPE_SELF_HARM_PROMOTION_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 596
        CLASSIFICATION_TYPE_DRAWN_SEXUALIZED_CHILDREN_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 600
        CLASSIFICATION_TYPE_DRAWN_SEXUALIZED_CHILDREN_API: UserData._ClassificationType.ValueType  # 601
        CLASSIFICATION_TYPE_DRAWN_SEXUALIZED_CHILDREN_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 606
        CLASSIFICATION_TYPE_CHILD_LED_VIGILANTISM_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 610
        CLASSIFICATION_TYPE_INAPPROPRIATE_SEXUAL_INTERACTIONS_WITH_MINORS_NON_GROOMING_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 620
        CLASSIFICATION_TYPE_ADMISSION_OF_SEXUAL_MISCONDUCT_WITH_A_CHILD_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 630
        CLASSIFICATION_TYPE_CSAM_SOLICITATION_OR_ADMISSION_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 640
        CLASSIFICATION_TYPE_CSAM_SOLICITATION_OR_ADMISSION_API: UserData._ClassificationType.ValueType  # 641
        CLASSIFICATION_TYPE_CSAM_SOLICITATION_OR_ADMISSION_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 646
        CLASSIFICATION_TYPE_SEXUAL_GROOMING_OF_A_CHILD_AND_CSAM_SOLICITATION_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 650
        CLASSIFICATION_TYPE_UNKNOWN_CSAM_FACILITATION_HASH_MATCH: UserData._ClassificationType.ValueType  # 660
        CLASSIFICATION_TYPE_UNKNOWN_CSAM_FACILITATION_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 661
        CLASSIFICATION_TYPE_VOYEURISTIC_MEDIA_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 670
        CLASSIFICATION_TYPE_VOYEURISTIC_MEDIA_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 676
        CLASSIFICATION_TYPE_SEXUAL_DEEPFAKES_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 680
        CLASSIFICATION_TYPE_SEXUAL_DEEPFAKES_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 686
        CLASSIFICATION_TYPE_IMPERSONATION_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 5726
        CLASSIFICATION_TYPE_INVESTMENT_AND_IDENTITY_SCAMS_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 5727
        CLASSIFICATION_TYPE_MALWARE_AND_MALICIOUS_CONDUCT_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 690
        CLASSIFICATION_TYPE_MALWARE_AND_MALICIOUS_CONDUCT_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 696
        CLASSIFICATION_TYPE_PHISHING_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 700
        CLASSIFICATION_TYPE_IMPERSONATION_HIGH_RISK_SMITE: UserData._ClassificationType.ValueType  # 710
        CLASSIFICATION_TYPE_IMPERSONATION_HIGH_RISK_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 711
        CLASSIFICATION_TYPE_IMPERSONATION_HIGH_RISK_ADMIN: UserData._ClassificationType.ValueType  # 712
        CLASSIFICATION_TYPE_PLATFORM_BAN_EVASION_SMITE: UserData._ClassificationType.ValueType  # 720
        CLASSIFICATION_TYPE_GENERIC_CHILD_SELF_ENDANGERMENT_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 730
        CLASSIFICATION_TYPE_GENERIC_CSAM_AND_CHILD_SEXUALIZATION_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 740
        CLASSIFICATION_TYPE_GENERIC_INAPPROPRIATE_SEXUAL_CONDUCT_WITH_CHILDREN_AND_GROOMING_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 750
        CLASSIFICATION_TYPE_GENERIC_FINANCIAL_SCAMS_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 760
        CLASSIFICATION_TYPE_GENERIC_FRAUD_SERVICES_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 770
        CLASSIFICATION_TYPE_GENERIC_BULLYING_HARASSMENT_AND_THREATS_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 780
        CLASSIFICATION_TYPE_GENERIC_HATE_SPEECH_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 790
        CLASSIFICATION_TYPE_GENERIC_NON_CONSENSUAL_ADULT_INTIMATE_MEDIA_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 800
        CLASSIFICATION_TYPE_GENERIC_SELF_HARM_ENCOURAGEMENT_AND_PROMOTION_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 810
        CLASSIFICATION_TYPE_GENERIC_GLORIFICATION_AND_INCITEMENT_OF_VIOLENCE_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 820
        CLASSIFICATION_TYPE_GENERIC_CYBERCRIME_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 830
        CLASSIFICATION_TYPE_NON_GATED_SERVER_DEDICATED_TO_AGE_RESTRICTED_CONTENT_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 846
        CLASSIFICATION_TYPE_VIOLENT_MEDIA_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 850
        CLASSIFICATION_TYPE_VIOLENT_MEDIA_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 856
        CLASSIFICATION_TYPE_HARASSMENT_AND_NONIMMINENT_AND_OR_NON_PHYSICAL_THREATS_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 866
        CLASSIFICATION_TYPE_SALE_OR_PURCHASE_OF_DISCORD_ASSETS_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 876
        CLASSIFICATION_TYPE_SALE_OF_PLATFORM_ABUSE_TOOLS_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 886
        CLASSIFICATION_TYPE_CHILD_SEXTORTION_FINANCIAL_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 890
        CLASSIFICATION_TYPE_CHILD_SEXTORTION_FINANCIAL_GUILD_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 895
        CLASSIFICATION_TYPE_CHILD_SEXTORTION_FINANCIAL_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 896
        CLASSIFICATION_TYPE_CHILD_SEXTORTION_NON_FINANCIAL_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 900
        CLASSIFICATION_TYPE_CHILD_SEXTORTION_NON_FINANCIAL_GUILD_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 905
        CLASSIFICATION_TYPE_CHILD_SEXTORTION_NON_FINANCIAL_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 906
        CLASSIFICATION_TYPE_ADULT_SEXTORTION_FINANCIAL_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 910
        CLASSIFICATION_TYPE_ADULT_SEXTORTION_FINANCIAL_GUILD_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 915
        CLASSIFICATION_TYPE_ADULT_SEXTORTION_FINANCIAL_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 916
        CLASSIFICATION_TYPE_ADULT_SEXTORTION_NON_FINANCIAL_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 920
        CLASSIFICATION_TYPE_ADULT_SEXTORTION_NON_FINANCIAL_GUILD_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 925
        CLASSIFICATION_TYPE_ADULT_SEXTORTION_NON_FINANCIAL_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 926
        CLASSIFICATION_TYPE_GORE_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 930
        CLASSIFICATION_TYPE_SEXUAL_ASSAULT_VIOLENCE_MEDIA_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 936
        CLASSIFICATION_TYPE_SALE_OF_MALICIOUS_TOOLS_AND_SERVICES_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 940
        CLASSIFICATION_TYPE_SALE_OF_MALICIOUS_TOOLS_AND_SERVICES_GUILD_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 945
        CLASSIFICATION_TYPE_SALE_OF_MALICIOUS_TOOLS_AND_SERVICES_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 946
        CLASSIFICATION_TYPE_FRAUD_SERVICES_LOW_RISK_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 950
        CLASSIFICATION_TYPE_FRAUD_SERVICES_LOW_RISK_GUILD_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 955
        CLASSIFICATION_TYPE_FRAUD_SERVICES_LOW_RISK_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 956
        CLASSIFICATION_TYPE_FRAUD_SERVICES_MEDIUM_RISK_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 960
        CLASSIFICATION_TYPE_FRAUD_SERVICES_MEDIUM_RISK_GUILD_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 965
        CLASSIFICATION_TYPE_FRAUD_SERVICES_MEDIUM_RISK_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 966
        CLASSIFICATION_TYPE_FRAUD_SERVICES_HIGH_RISK_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 970
        CLASSIFICATION_TYPE_FRAUD_SERVICES_HIGH_RISK_GUILD_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 975
        CLASSIFICATION_TYPE_GORE_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 976
        CLASSIFICATION_TYPE_AGE_RESTRICTED_CONTENT_IN_SERVER_ASSETS_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 986
        CLASSIFICATION_TYPE_CSAM_SMITE: UserData._ClassificationType.ValueType  # 3000
        CLASSIFICATION_TYPE_CSAM_GUILD_SMITE: UserData._ClassificationType.ValueType  # 3005
        CLASSIFICATION_TYPE_SUSPICIOUS_LINK_SMITE: UserData._ClassificationType.ValueType  # 3010
        CLASSIFICATION_TYPE_INVESTMENT_AND_IDENTITY_SCAMS_SMITE: UserData._ClassificationType.ValueType  # 3020
        CLASSIFICATION_TYPE_SPAM_SMITE: UserData._ClassificationType.ValueType  # 3030
        CLASSIFICATION_TYPE_SPAM_CEILING_SMITE: UserData._ClassificationType.ValueType  # 3120
        CLASSIFICATION_TYPE_VOLUMETRIC_ABUSE_SMITE: UserData._ClassificationType.ValueType  # 3130
        CLASSIFICATION_TYPE_CHARGEBACK_HIGH_RISK_SMITE: UserData._ClassificationType.ValueType  # 3040
        CLASSIFICATION_TYPE_CHARGEBACK_LOW_RISK_SMITE: UserData._ClassificationType.ValueType  # 3050
        CLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_EXPLICIT_CONTENT_GUILD_SMITE: UserData._ClassificationType.ValueType  # 3065
        CLASSIFICATION_TYPE_INAUTHENTIC_SERVER_MEDIUM_CONFIDENCE_GUILD_SMITE: UserData._ClassificationType.ValueType  # 3075
        CLASSIFICATION_TYPE_MALWARE_AND_MALICIOUS_CONDUCT_SMITE: UserData._ClassificationType.ValueType  # 3085
        CLASSIFICATION_TYPE_MALWARE_AND_MALICIOUS_CONDUCT_GUILD_SMITE: UserData._ClassificationType.ValueType  # 3090
        CLASSIFICATION_TYPE_MALWARE_AND_MALICIOUS_CONDUCT_NON_DEDICATED_GUILD_SMITE: UserData._ClassificationType.ValueType  # 3091
        CLASSIFICATION_TYPE_EARLY_FRAUD_WARNING_LOW_RISK_SMITE: UserData._ClassificationType.ValueType  # 3100
        CLASSIFICATION_TYPE_EARLY_FRAUD_WARNING_HIGH_RISK_SMITE: UserData._ClassificationType.ValueType  # 3110
        CLASSIFICATION_TYPE_PRESENCE_IN_VIOLATIVE_GUILD_HIGH_RISK: UserData._ClassificationType.ValueType  # 4000
        CLASSIFICATION_TYPE_PRESENCE_IN_VIOLATIVE_GUILD_MEDIUM_RISK: UserData._ClassificationType.ValueType  # 4010
        CLASSIFICATION_TYPE_OWNER_OF_VIOLATIVE_GUILD_VERY_HIGH_RISK: UserData._ClassificationType.ValueType  # 4100
        CLASSIFICATION_TYPE_OWNER_OF_VIOLATIVE_GUILD_HIGH_RISK: UserData._ClassificationType.ValueType  # 4110
        CLASSIFICATION_TYPE_OWNER_OF_VIOLATIVE_GUILD_MEDIUM_RISK: UserData._ClassificationType.ValueType  # 4120
        CLASSIFICATION_TYPE_OWNER_OF_VIOLATIVE_GUILD_LOW_RISK: UserData._ClassificationType.ValueType  # 4130
        CLASSIFICATION_TYPE_OWNER_OF_VIOLATIVE_GUILD_COPYRIGHT: UserData._ClassificationType.ValueType  # 4140
        CLASSIFICATION_TYPE_OWNER_OF_INAUTHENTIC_ENGAGEMENT_GUILD: UserData._ClassificationType.ValueType  # 4150
        CLASSIFICATION_TYPE_CSAM_ADMIN: UserData._ClassificationType.ValueType  # 5000
        CLASSIFICATION_TYPE_CSAM_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5005
        CLASSIFICATION_TYPE_CSAM_NON_DEDICATED_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5006
        CLASSIFICATION_TYPE_CHILD_SEXUALIZATION_CONTENT_ADMIN: UserData._ClassificationType.ValueType  # 5010
        CLASSIFICATION_TYPE_CHILD_SEXUALIZATION_CONTENT_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5015
        CLASSIFICATION_TYPE_CHILD_SEXUALIZATION_CONTENT_NON_DEDICATED_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5016
        CLASSIFICATION_TYPE_DRAWN_SEXUALIZED_CHILDREN_ADMIN: UserData._ClassificationType.ValueType  # 5020
        CLASSIFICATION_TYPE_DRAWN_SEXUALIZED_CHILDREN_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5025
        CLASSIFICATION_TYPE_DRAWN_SEXUALIZED_CHILDREN_NON_DEDICATED_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5026
        CLASSIFICATION_TYPE_INAPPROPRIATE_SEXUAL_INTERACTIONS_WITH_MINORS_NON_GROOMING_ADMIN: UserData._ClassificationType.ValueType  # 5030
        CLASSIFICATION_TYPE_INAPPROPRIATE_SEXUAL_INTERACTIONS_WITH_MINORS_NON_GROOMING_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5035
        CLASSIFICATION_TYPE_INAPPROPRIATE_SEXUAL_INTERACTIONS_WITH_MINORS_NON_GROOMING_NON_DEDICATED_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5036
        CLASSIFICATION_TYPE_ADMISSION_OF_SEXUAL_MISCONDUCT_WITH_A_CHILD_ADMIN: UserData._ClassificationType.ValueType  # 5040
        CLASSIFICATION_TYPE_SEXUAL_GROOMING_OF_A_CHILD_AND_CSAM_SOLICITATION_ADMIN: UserData._ClassificationType.ValueType  # 5050
        CLASSIFICATION_TYPE_SEXUAL_GROOMING_OF_A_CHILD_AND_CSAM_SOLICITATION_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5055
        CLASSIFICATION_TYPE_SELF_GENERATED_CSAM_SGCSAM_ADMIN: UserData._ClassificationType.ValueType  # 5060
        CLASSIFICATION_TYPE_SELF_GENERATED_CSAM_SGCSAM_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5065
        CLASSIFICATION_TYPE_CHILD_LED_SEXUAL_SELF_ENDANGERMENT_ADMIN: UserData._ClassificationType.ValueType  # 5070
        CLASSIFICATION_TYPE_CHILD_LED_SEXUAL_SELF_ENDANGERMENT_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5075
        CLASSIFICATION_TYPE_CHILD_LED_SEXUAL_SELF_ENDANGERMENT_NON_DEDICATED_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5076
        CLASSIFICATION_TYPE_CHILD_LED_VIGILANTISM_ADMIN: UserData._ClassificationType.ValueType  # 5080
        CLASSIFICATION_TYPE_CHILD_LED_VIGILANTISM_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5085
        CLASSIFICATION_TYPE_CHILD_ENGAGING_WITH_SEXUALLY_EXPLICIT_CONTENT_ADMIN: UserData._ClassificationType.ValueType  # 5090
        CLASSIFICATION_TYPE_SEXUALLY_EXPLICIT_CONTENT_WITH_IMPLICATIONS_FOR_REAL_WORLD_HARM_ADMIN: UserData._ClassificationType.ValueType  # 5100
        CLASSIFICATION_TYPE_SEXUALLY_EXPLICIT_CONTENT_WITH_IMPLICATIONS_FOR_REAL_WORLD_HARM_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5105
        CLASSIFICATION_TYPE_SEXUALLY_EXPLICIT_CONTENT_WITH_IMPLICATIONS_FOR_REAL_WORLD_HARM_NON_DEDICATED_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5106
        CLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_EXPLICIT_CONTENT_ADMIN: UserData._ClassificationType.ValueType  # 5110
        CLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_EXPLICIT_CONTENT_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5115
        CLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_EXPLICIT_CONTENT_NON_DEDICATED_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5116
        CLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_SUGGESTIVE_MEDIA_ADMIN: UserData._ClassificationType.ValueType  # 5120
        CLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_SUGGESTIVE_MEDIA_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5125
        CLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_SUGGESTIVE_MEDIA_NON_DEDICATED_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5126
        CLASSIFICATION_TYPE_TRIBUTES_AND_LEAKED_ADULT_INTIMATE_MEDIA_ADMIN: UserData._ClassificationType.ValueType  # 5130
        CLASSIFICATION_TYPE_TRIBUTES_AND_LEAKED_ADULT_INTIMATE_MEDIA_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5135
        CLASSIFICATION_TYPE_TRIBUTES_AND_LEAKED_ADULT_INTIMATE_MEDIA_NON_DEDICATED_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5136
        CLASSIFICATION_TYPE_VOYEURISTIC_MEDIA_ADMIN: UserData._ClassificationType.ValueType  # 5140
        CLASSIFICATION_TYPE_VOYEURISTIC_MEDIA_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5145
        CLASSIFICATION_TYPE_VOYEURISTIC_MEDIA_NON_DEDICATED_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5146
        CLASSIFICATION_TYPE_SEXUAL_DEEPFAKES_ADMIN: UserData._ClassificationType.ValueType  # 5150
        CLASSIFICATION_TYPE_SEXUAL_DEEPFAKES_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5155
        CLASSIFICATION_TYPE_SEXUAL_DEEPFAKES_NON_DEDICATED_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5156
        CLASSIFICATION_TYPE_SEXUAL_ASSAULT_VIOLENCE_MEDIA_ADMIN: UserData._ClassificationType.ValueType  # 5160
        CLASSIFICATION_TYPE_SEXUAL_ASSAULT_VIOLENCE_MEDIA_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5165
        CLASSIFICATION_TYPE_SEXUAL_ASSAULT_VIOLENCE_MEDIA_NON_DEDICATED_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5166
        CLASSIFICATION_TYPE_SUICIDE_PROMOTION_ADMIN: UserData._ClassificationType.ValueType  # 5170
        CLASSIFICATION_TYPE_SUICIDE_PROMOTION_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5175
        CLASSIFICATION_TYPE_SUICIDE_PROMOTION_NON_DEDICATED_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5176
        CLASSIFICATION_TYPE_SELF_HARM_PROMOTION_ADMIN: UserData._ClassificationType.ValueType  # 5180
        CLASSIFICATION_TYPE_SELF_HARM_PROMOTION_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5185
        CLASSIFICATION_TYPE_SELF_HARM_PROMOTION_NON_DEDICATED_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5186
        CLASSIFICATION_TYPE_RISK_OF_PHYSICAL_SELF_HARM_ADMIN: UserData._ClassificationType.ValueType  # 5190
        CLASSIFICATION_TYPE_VIOLENT_MEDIA_ADMIN: UserData._ClassificationType.ValueType  # 5200
        CLASSIFICATION_TYPE_VIOLENT_MEDIA_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5205
        CLASSIFICATION_TYPE_VIOLENT_MEDIA_NON_DEDICATED_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5206
        CLASSIFICATION_TYPE_GORE_ADMIN: UserData._ClassificationType.ValueType  # 5210
        CLASSIFICATION_TYPE_GORE_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5215
        CLASSIFICATION_TYPE_GORE_NON_DEDICATED_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5216
        CLASSIFICATION_TYPE_VIOLENCE_GLORIFICATION_PROMOTION_OR_INCITEMENT_ADMIN: UserData._ClassificationType.ValueType  # 5220
        CLASSIFICATION_TYPE_VIOLENCE_GLORIFICATION_PROMOTION_OR_INCITEMENT_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5225
        CLASSIFICATION_TYPE_VIOLENCE_GLORIFICATION_PROMOTION_OR_INCITEMENT_NON_DEDICATED_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5226
        CLASSIFICATION_TYPE_COORDINATION_OR_CREDIBLE_ADMISSION_OF_REAL_WORLD_VIOLENCE_ADMIN: UserData._ClassificationType.ValueType  # 5230
        CLASSIFICATION_TYPE_COORDINATION_OR_CREDIBLE_ADMISSION_OF_REAL_WORLD_VIOLENCE_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5235
        CLASSIFICATION_TYPE_COORDINATION_OR_CREDIBLE_ADMISSION_OF_REAL_WORLD_VIOLENCE_NON_DEDICATED_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5236
        CLASSIFICATION_TYPE_HARASSMENT_AND_NONIMMINENT_AND_OR_NON_PHYSICAL_THREATS_ADMIN: UserData._ClassificationType.ValueType  # 5240
        CLASSIFICATION_TYPE_HARASSMENT_AND_NONIMMINENT_AND_OR_NON_PHYSICAL_THREATS_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5245
        CLASSIFICATION_TYPE_HARASSMENT_AND_NONIMMINENT_AND_OR_NON_PHYSICAL_THREATS_NON_DEDICATED_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5246
        CLASSIFICATION_TYPE_SEXUAL_HARASSMENT_ADMIN: UserData._ClassificationType.ValueType  # 5250
        CLASSIFICATION_TYPE_SERVER_RAIDS_ADMIN: UserData._ClassificationType.ValueType  # 5260
        CLASSIFICATION_TYPE_SERVER_RAIDS_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5265
        CLASSIFICATION_TYPE_SERVER_RAIDS_NON_DEDICATED_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5266
        CLASSIFICATION_TYPE_IMMINENT_THREATS_OF_PHYSICAL_HARM_ADMIN: UserData._ClassificationType.ValueType  # 5270
        CLASSIFICATION_TYPE_IMMINENT_THREATS_OF_PHYSICAL_HARM_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5275
        CLASSIFICATION_TYPE_IMMINENT_THREATS_OF_PHYSICAL_HARM_NON_DEDICATED_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5276
        CLASSIFICATION_TYPE_IMMINENT_THREATS_OF_EXTORTION_ADMIN: UserData._ClassificationType.ValueType  # 5280
        CLASSIFICATION_TYPE_IMMINENT_THREATS_OF_EXTORTION_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5285
        CLASSIFICATION_TYPE_IMMINENT_THREATS_OF_EXTORTION_NON_DEDICATED_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5286
        CLASSIFICATION_TYPE_DOXXING_HIGH_RISK_TIER_1_ADMIN: UserData._ClassificationType.ValueType  # 5290
        CLASSIFICATION_TYPE_DOXXING_HIGH_RISK_TIER_1_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5295
        CLASSIFICATION_TYPE_DOXXING_HIGH_RISK_TIER_1_NON_DEDICATED_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5296
        CLASSIFICATION_TYPE_DOXXING_MEDIUM_RISK_TIER_2_ADMIN: UserData._ClassificationType.ValueType  # 5300
        CLASSIFICATION_TYPE_DOXXING_MEDIUM_RISK_TIER_2_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5305
        CLASSIFICATION_TYPE_DOXXING_MEDIUM_RISK_TIER_2_NON_DEDICATED_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5306
        CLASSIFICATION_TYPE_HATE_SPEECH_AND_SYMBOLS_ADMIN: UserData._ClassificationType.ValueType  # 5310
        CLASSIFICATION_TYPE_HATE_SPEECH_AND_SYMBOLS_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5315
        CLASSIFICATION_TYPE_HATE_SPEECH_AND_SYMBOLS_NON_DEDICATED_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5316
        CLASSIFICATION_TYPE_DENIAL_OF_HUMAN_ATROCITY_ADMIN: UserData._ClassificationType.ValueType  # 5320
        CLASSIFICATION_TYPE_DENIAL_OF_HUMAN_ATROCITY_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5325
        CLASSIFICATION_TYPE_DENIAL_OF_HUMAN_ATROCITY_NON_DEDICATED_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5326
        CLASSIFICATION_TYPE_VIOLENT_EXTREMISM_ORGANIZING_ADMIN: UserData._ClassificationType.ValueType  # 5330
        CLASSIFICATION_TYPE_VIOLENT_EXTREMISM_ORGANIZING_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5335
        CLASSIFICATION_TYPE_VIOLENT_EXTREMISM_SUPPORT_PROMOTION_OR_EMULATION_ADMIN: UserData._ClassificationType.ValueType  # 5340
        CLASSIFICATION_TYPE_VIOLENT_EXTREMISM_SUPPORT_PROMOTION_OR_EMULATION_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5344
        CLASSIFICATION_TYPE_VIOLENT_EXTREMISM_SUPPORT_PROMOTION_OR_EMULATION_NON_DEDICATED_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5346
        CLASSIFICATION_TYPE_HIGH_RISK_DANGEROUS_AND_REGULATED_GOODS_ADMIN: UserData._ClassificationType.ValueType  # 5350
        CLASSIFICATION_TYPE_HIGH_RISK_DANGEROUS_AND_REGULATED_GOODS_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5355
        CLASSIFICATION_TYPE_MEDIUM_RISK_DANGEROUS_AND_REGULATED_GOODS_ADMIN: UserData._ClassificationType.ValueType  # 5360
        CLASSIFICATION_TYPE_MEDIUM_RISK_DANGEROUS_AND_REGULATED_GOODS_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5365
        CLASSIFICATION_TYPE_MEDIUM_RISK_DANGEROUS_AND_REGULATED_GOODS_NON_DEDICATED_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5366
        CLASSIFICATION_TYPE_LOW_RISK_DANGEROUS_AND_REGULATED_GOODS_ADMIN: UserData._ClassificationType.ValueType  # 5370
        CLASSIFICATION_TYPE_LOW_RISK_DANGEROUS_AND_REGULATED_GOODS_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5375
        CLASSIFICATION_TYPE_LOW_RISK_DANGEROUS_AND_REGULATED_GOODS_NON_DEDICATED_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5376
        CLASSIFICATION_TYPE_PROMOTING_OR_PARTICIPATING_IN_REAL_WORLD_SEXUAL_SERVICES_ADMIN: UserData._ClassificationType.ValueType  # 5380
        CLASSIFICATION_TYPE_PROMOTING_OR_PARTICIPATING_IN_REAL_WORLD_SEXUAL_SERVICES_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5385
        CLASSIFICATION_TYPE_PROMOTING_OR_PARTICIPATING_IN_REAL_WORLD_SEXUAL_SERVICES_NON_DEDICATED_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5386
        CLASSIFICATION_TYPE_ORGANIZING_OR_FACILITATING_ILLICIT_GAMBLING_ADMIN: UserData._ClassificationType.ValueType  # 5390
        CLASSIFICATION_TYPE_ORGANIZING_OR_FACILITATING_ILLICIT_GAMBLING_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5395
        CLASSIFICATION_TYPE_ORGANIZING_OR_FACILITATING_ILLICIT_GAMBLING_NON_DEDICATED_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5396
        CLASSIFICATION_TYPE_ORGANIZING_OR_FACILITATING_HUMAN_TRAFFICKING_ADMIN: UserData._ClassificationType.ValueType  # 5400
        CLASSIFICATION_TYPE_ORGANIZING_OR_FACILITATING_HUMAN_TRAFFICKING_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5405
        CLASSIFICATION_TYPE_USER_UNDER_THE_MINIMUM_AGE_WHERE_THEY_RESIDE_ADMIN: UserData._ClassificationType.ValueType  # 5410
        CLASSIFICATION_TYPE_USER_UNDER_THE_MINIMUM_AGE_WHERE_THEY_RESIDE_API: UserData._ClassificationType.ValueType  # 5411
        CLASSIFICATION_TYPE_POSTING_AGERESTRICTED_CONTENT_ADMIN: UserData._ClassificationType.ValueType  # 5420
        CLASSIFICATION_TYPE_COPYRIGHT_MEDIA_UPLOADS_ATTACHMENTS_512C_ADMIN: UserData._ClassificationType.ValueType  # 5430
        CLASSIFICATION_TYPE_COPYRIGHT_MEDIA_UPLOADS_ATTACHMENTS_512C_NON_DEDICATED_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5436
        CLASSIFICATION_TYPE_COPYRIGHT_TEXT_OFFPLATFORM_LINK_512D_ADMIN: UserData._ClassificationType.ValueType  # 5440
        CLASSIFICATION_TYPE_COPYRIGHT_TEXT_OFFPLATFORM_LINK_512D_NON_DEDICATED_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5446
        CLASSIFICATION_TYPE_COPYRIGHT_LIVESTREAMING_512C_ADMIN: UserData._ClassificationType.ValueType  # 5450
        CLASSIFICATION_TYPE_COPYRIGHT_LIVESTREAMING_512C_NON_DEDICATED_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5456
        CLASSIFICATION_TYPE_TRADEMARK_ADMIN: UserData._ClassificationType.ValueType  # 5460
        CLASSIFICATION_TYPE_TRADEMARK_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5465
        CLASSIFICATION_TYPE_TRADEMARK_NON_DEDICATED_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5466
        CLASSIFICATION_TYPE_TRADEMARK_COUNTERFEIT_GOODS_ADMIN: UserData._ClassificationType.ValueType  # 5470
        CLASSIFICATION_TYPE_TRADEMARK_COUNTERFEIT_GOODS_NON_DEDICATED_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5476
        CLASSIFICATION_TYPE_UNAUTHORIZED_COPYRIGHT_ACCESS_ADMIN: UserData._ClassificationType.ValueType  # 5480
        CLASSIFICATION_TYPE_UNAUTHORIZED_COPYRIGHT_ACCESS_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5485
        CLASSIFICATION_TYPE_UNAUTHORIZED_COPYRIGHT_ACCESS_NON_DEDICATED_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5486
        CLASSIFICATION_TYPE_HEALTH_MISINFORMATION_ADMIN: UserData._ClassificationType.ValueType  # 5490
        CLASSIFICATION_TYPE_HEALTH_MISINFORMATION_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5495
        CLASSIFICATION_TYPE_HEALTH_MISINFORMATION_NON_DEDICATED_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5496
        CLASSIFICATION_TYPE_CIVIC_MISINFORMATION_ADMIN: UserData._ClassificationType.ValueType  # 5500
        CLASSIFICATION_TYPE_CIVIC_MISINFORMATION_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5505
        CLASSIFICATION_TYPE_CIVIC_MISINFORMATION_NON_DEDICATED_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5506
        CLASSIFICATION_TYPE_CIVIC_DISRUPTION_MOBILIZATION_FOR_REAL_WORLD_INTERFERENCE_ADMIN: UserData._ClassificationType.ValueType  # 5510
        CLASSIFICATION_TYPE_CIVIC_DISRUPTION_MOBILIZATION_FOR_REAL_WORLD_INTERFERENCE_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5515
        CLASSIFICATION_TYPE_CIVIC_DISRUPTION_MOBILIZATION_FOR_REAL_WORLD_INTERFERENCE_NON_DEDICATED_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5516
        CLASSIFICATION_TYPE_INVESTMENT_AND_IDENTITY_SCAMS_ADMIN: UserData._ClassificationType.ValueType  # 5520
        CLASSIFICATION_TYPE_INVESTMENT_AND_IDENTITY_SCAMS_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5525
        CLASSIFICATION_TYPE_TRANSACTION_SCAMS_ADMIN: UserData._ClassificationType.ValueType  # 5530
        CLASSIFICATION_TYPE_TRANSACTION_SCAMS_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5535
        CLASSIFICATION_TYPE_PHISHING_ADMIN: UserData._ClassificationType.ValueType  # 5540
        CLASSIFICATION_TYPE_MALWARE_AND_MALICIOUS_CONDUCT_ADMIN: UserData._ClassificationType.ValueType  # 5550
        CLASSIFICATION_TYPE_MALWARE_AND_MALICIOUS_CONDUCT_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5555
        CLASSIFICATION_TYPE_MALWARE_AND_MALICIOUS_CONDUCT_NON_DEDICATED_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5556
        CLASSIFICATION_TYPE_MALWARE_TARGETING_CRITICAL_INFRASTRUCTURE_ADMIN: UserData._ClassificationType.ValueType  # 5560
        CLASSIFICATION_TYPE_MALWARE_TARGETING_CRITICAL_INFRASTRUCTURE_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5565
        CLASSIFICATION_TYPE_MALWARE_TARGETING_CRITICAL_INFRASTRUCTURE_NON_DEDICATED_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5566
        CLASSIFICATION_TYPE_MONEY_LAUNDERING_ADMIN: UserData._ClassificationType.ValueType  # 5570
        CLASSIFICATION_TYPE_MONEY_LAUNDERING_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5575
        CLASSIFICATION_TYPE_FORGERY_ADMIN: UserData._ClassificationType.ValueType  # 5580
        CLASSIFICATION_TYPE_FORGERY_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5585
        CLASSIFICATION_TYPE_FRAUD_SERVICES_AND_TOOLS_ADMIN: UserData._ClassificationType.ValueType  # 5590
        CLASSIFICATION_TYPE_FRAUD_SERVICES_AND_TOOLS_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5595
        CLASSIFICATION_TYPE_FRAUD_SERVICES_AND_TOOLS_NON_DEDICATED_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5596
        CLASSIFICATION_TYPE_MISLEADING_ABUSE_REPORTS_ADMIN: UserData._ClassificationType.ValueType  # 5600
        CLASSIFICATION_TYPE_FRAUDULENT_LEGAL_PROCESS_ADMIN: UserData._ClassificationType.ValueType  # 5610
        CLASSIFICATION_TYPE_HARASSMENT_OF_DISCORDS_SUPPORT_TEAMS_ADMIN: UserData._ClassificationType.ValueType  # 5620
        CLASSIFICATION_TYPE_IMPERSONATION_ADMIN: UserData._ClassificationType.ValueType  # 5630
        CLASSIFICATION_TYPE_IMPERSONATION_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5635
        CLASSIFICATION_TYPE_PLATFORM_BAN_EVASION_ADMIN: UserData._ClassificationType.ValueType  # 5640
        CLASSIFICATION_TYPE_PLATFORM_BAN_EVASION_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5645
        CLASSIFICATION_TYPE_OFFPLATFORM_BEHAVIORS_ADMIN: UserData._ClassificationType.ValueType  # 5650
        CLASSIFICATION_TYPE_OFFPLATFORM_BEHAVIORS_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5655
        CLASSIFICATION_TYPE_CSAM_SOLICITATION_OR_ADMISSION_ADMIN: UserData._ClassificationType.ValueType  # 5660
        CLASSIFICATION_TYPE_CSAM_SOLICITATION_OR_ADMISSION_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5665
        CLASSIFICATION_TYPE_CSAM_SOLICITATION_OR_ADMISSION_NON_DEDICATED_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5666
        CLASSIFICATION_TYPE_SALE_OR_PURCHASE_OF_DISCORD_ASSETS_ADMIN: UserData._ClassificationType.ValueType  # 5670
        CLASSIFICATION_TYPE_SALE_OR_PURCHASE_OF_DISCORD_ASSETS_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5675
        CLASSIFICATION_TYPE_SALE_OR_PURCHASE_OF_DISCORD_ASSETS_NON_DEDICATED_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5676
        CLASSIFICATION_TYPE_SALE_OR_PURCHASE_OF_ARTIFICIAL_ENGAGEMENT_ADMIN: UserData._ClassificationType.ValueType  # 5680
        CLASSIFICATION_TYPE_SALE_OR_PURCHASE_OF_ARTIFICIAL_ENGAGEMENT_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5685
        CLASSIFICATION_TYPE_SALE_OR_PURCHASE_OF_ARTIFICIAL_ENGAGEMENT_NON_DEDICATED_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5686
        CLASSIFICATION_TYPE_SERVER_THAT_HAS_ARTIFICIALLY_INFLATED_MEMBERS_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5695
        CLASSIFICATION_TYPE_SALE_OF_PLATFORM_ABUSE_TOOLS_ADMIN: UserData._ClassificationType.ValueType  # 5700
        CLASSIFICATION_TYPE_SALE_OF_PLATFORM_ABUSE_TOOLS_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5705
        CLASSIFICATION_TYPE_SALE_OF_PLATFORM_ABUSE_TOOLS_NON_DEDICATED_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5706
        CLASSIFICATION_TYPE_NON_GATED_CHANNEL_DEDICATED_TO_AGE_RESTRICTED_CONTENT_ADMIN: UserData._ClassificationType.ValueType  # 5716
        CLASSIFICATION_TYPE_NON_GATED_SERVER_DEDICATED_TO_AGE_RESTRICTED_CONTENT_ADMIN: UserData._ClassificationType.ValueType  # 5735
        CLASSIFICATION_TYPE_UNKNOWN_CSAM_FACILITATION_ADMIN: UserData._ClassificationType.ValueType  # 5740
        CLASSIFICATION_TYPE_CHARGEBACK_HIGH_RISK_ADMIN: UserData._ClassificationType.ValueType  # 5750
        CLASSIFICATION_TYPE_CHARGEBACK_LOW_RISK_ADMIN: UserData._ClassificationType.ValueType  # 5760
        CLASSIFICATION_TYPE_CHILD_SEXTORTION_FINANCIAL_ADMIN: UserData._ClassificationType.ValueType  # 5770
        CLASSIFICATION_TYPE_CHILD_SEXTORTION_FINANCIAL_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5775
        CLASSIFICATION_TYPE_CHILD_SEXTORTION_FINANCIAL_NON_DEDICATED_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5776
        CLASSIFICATION_TYPE_CHILD_SEXTORTION_NON_FINANCIAL_ADMIN: UserData._ClassificationType.ValueType  # 5780
        CLASSIFICATION_TYPE_CHILD_SEXTORTION_NON_FINANCIAL_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5785
        CLASSIFICATION_TYPE_CHILD_SEXTORTION_NON_FINANCIAL_NON_DEDICATED_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5786
        CLASSIFICATION_TYPE_ADULT_SEXTORTION_FINANCIAL_ADMIN: UserData._ClassificationType.ValueType  # 5790
        CLASSIFICATION_TYPE_ADULT_SEXTORTION_FINANCIAL_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5795
        CLASSIFICATION_TYPE_ADULT_SEXTORTION_FINANCIAL_NON_DEDICATED_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5796
        CLASSIFICATION_TYPE_ADULT_SEXTORTION_NON_FINANCIAL_ADMIN: UserData._ClassificationType.ValueType  # 5800
        CLASSIFICATION_TYPE_ADULT_SEXTORTION_NON_FINANCIAL_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5805
        CLASSIFICATION_TYPE_ADULT_SEXTORTION_NON_FINANCIAL_NON_DEDICATED_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5806
        CLASSIFICATION_TYPE_SALE_OF_MALICIOUS_TOOLS_AND_SERVICES_ADMIN: UserData._ClassificationType.ValueType  # 5810
        CLASSIFICATION_TYPE_SALE_OF_MALICIOUS_TOOLS_AND_SERVICES_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5815
        CLASSIFICATION_TYPE_SALE_OF_MALICIOUS_TOOLS_AND_SERVICES_NON_DEDICATED_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5816
        CLASSIFICATION_TYPE_FRAUD_SERVICES_LOW_RISK_ADMIN: UserData._ClassificationType.ValueType  # 5820
        CLASSIFICATION_TYPE_FRAUD_SERVICES_MEDIUM_RISK_ADMIN: UserData._ClassificationType.ValueType  # 5830
        CLASSIFICATION_TYPE_FRAUD_SERVICES_LOW_RISK_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5825
        CLASSIFICATION_TYPE_FRAUD_SERVICES_MEDIUM_RISK_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5835
        CLASSIFICATION_TYPE_FRAUD_SERVICES_LOW_RISK_NON_DEDICATED_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5826
        CLASSIFICATION_TYPE_FRAUD_SERVICES_MEDIUM_RISK_NON_DEDICATED_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5836
        CLASSIFICATION_TYPE_FRAUD_SERVICES_HIGH_RISK_ADMIN: UserData._ClassificationType.ValueType  # 5840
        CLASSIFICATION_TYPE_FRAUD_SERVICES_HIGH_RISK_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5845
        CLASSIFICATION_TYPE_DENIED_PARTY_SCREENING_ADMIN: UserData._ClassificationType.ValueType  # 5850
        CLASSIFICATION_TYPE_INAUTHENTIC_SERVER_MEDIUM_CONFIDENCE_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5865
        CLASSIFICATION_TYPE_FRAUDULENT_CHARGE_ADMIN: UserData._ClassificationType.ValueType  # 5870
        CLASSIFICATION_TYPE_HYBRIDIZED_HARM_COORDINATION_OR_FACILITATION_ADMIN: UserData._ClassificationType.ValueType  # 5880
        CLASSIFICATION_TYPE_HYBRIDIZED_HARM_COORDINATION_OR_FACILITATION_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 5885
        CLASSIFICATION_TYPE_PRESENCE_IN_HYBRIDIZED_HARM_COORDINATION_OR_FACILITATION_GUILD: UserData._ClassificationType.ValueType  # 5920
        CLASSIFICATION_TYPE_OWNER_OF_HYBRIDIZED_HARM_COORDINATION_OR_FACILITATION_GUILD: UserData._ClassificationType.ValueType  # 5930
        CLASSIFICATION_TYPE_UNAUTHORIZED_TRANSACTION_ADMIN: UserData._ClassificationType.ValueType  # 5890
        CLASSIFICATION_TYPE_EARLY_FRAUD_WARNING_LOW_RISK_ADMIN: UserData._ClassificationType.ValueType  # 5900
        CLASSIFICATION_TYPE_EARLY_FRAUD_WARNING_HIGH_RISK_ADMIN: UserData._ClassificationType.ValueType  # 5910
        CLASSIFICATION_TYPE_SPAM_CEILING_ADMIN: UserData._ClassificationType.ValueType  # 5940
        CLASSIFICATION_TYPE_HIGH_RISK_DANGEROUS_AND_REGULATED_GOODS_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7005
        CLASSIFICATION_TYPE_MEDIUM_RISK_DANGEROUS_AND_REGULATED_GOODS_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7015
        CLASSIFICATION_TYPE_LOW_RISK_DANGEROUS_AND_REGULATED_GOODS_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7025
        CLASSIFICATION_TYPE_ORGANIZING_OR_FACILITATING_ILLICIT_GAMBLING_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7035
        CLASSIFICATION_TYPE_INVESTMENT_AND_IDENTITY_SCAMS_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7045
        CLASSIFICATION_TYPE_FRAUD_SERVICES_AND_TOOLS_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7055
        CLASSIFICATION_TYPE_PLATFORM_BAN_EVASION_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7065
        CLASSIFICATION_TYPE_SALE_OR_PURCHASE_OF_DISCORD_ASSETS_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7075
        CLASSIFICATION_TYPE_SALE_OR_PURCHASE_OF_ARTIFICIAL_ENGAGEMENT_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7085
        CLASSIFICATION_TYPE_SERVER_THAT_HAS_ARTIFICIALLY_INFLATED_MEMBERS_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7095
        CLASSIFICATION_TYPE_SALE_OF_PLATFORM_ABUSE_TOOLS_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7105
        CLASSIFICATION_TYPE_CHILD_LED_SEXUAL_SELF_ENDANGERMENT_RETOOL: UserData._ClassificationType.ValueType  # 7110
        CLASSIFICATION_TYPE_CHILD_LED_VIGILANTISM_RETOOL: UserData._ClassificationType.ValueType  # 7120
        CLASSIFICATION_TYPE_CHILD_SEXUALIZATION_CONTENT_RETOOL: UserData._ClassificationType.ValueType  # 7130
        CLASSIFICATION_TYPE_CIVIC_DISRUPTION_MOBILIZATION_FOR_REAL_WORLD_INTERFERENCE_RETOOL: UserData._ClassificationType.ValueType  # 7140
        CLASSIFICATION_TYPE_CIVIC_MISINFORMATION_RETOOL: UserData._ClassificationType.ValueType  # 7150
        CLASSIFICATION_TYPE_COORDINATION_OR_CREDIBLE_ADMISSION_OF_REAL_WORLD_VIOLENCE_RETOOL: UserData._ClassificationType.ValueType  # 7160
        CLASSIFICATION_TYPE_CSAM_RETOOL: UserData._ClassificationType.ValueType  # 7170
        CLASSIFICATION_TYPE_DENIAL_OF_HUMAN_ATROCITY_RETOOL: UserData._ClassificationType.ValueType  # 7180
        CLASSIFICATION_TYPE_DRAWN_SEXUALIZED_CHILDREN_RETOOL: UserData._ClassificationType.ValueType  # 7190
        CLASSIFICATION_TYPE_CHILD_LED_SEXUAL_SELF_ENDANGERMENT_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7115
        CLASSIFICATION_TYPE_CHILD_LED_VIGILANTISM_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7125
        CLASSIFICATION_TYPE_CHILD_SEXUALIZATION_CONTENT_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7135
        CLASSIFICATION_TYPE_CIVIC_DISRUPTION_MOBILIZATION_FOR_REAL_WORLD_INTERFERENCE_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7145
        CLASSIFICATION_TYPE_CIVIC_MISINFORMATION_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7155
        CLASSIFICATION_TYPE_COORDINATION_OR_CREDIBLE_ADMISSION_OF_REAL_WORLD_VIOLENCE_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7165
        CLASSIFICATION_TYPE_CSAM_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7175
        CLASSIFICATION_TYPE_DENIAL_OF_HUMAN_ATROCITY_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7185
        CLASSIFICATION_TYPE_DRAWN_SEXUALIZED_CHILDREN_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7195
        CLASSIFICATION_TYPE_CHILD_LED_SEXUAL_SELF_ENDANGERMENT_NON_DEDICATED_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7116
        CLASSIFICATION_TYPE_CHILD_LED_VIGILANTISM_NON_DEDICATED_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7126
        CLASSIFICATION_TYPE_CHILD_SEXUALIZATION_CONTENT_NON_DEDICATED_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7136
        CLASSIFICATION_TYPE_CIVIC_DISRUPTION_MOBILIZATION_FOR_REAL_WORLD_INTERFERENCE_NON_DEDICATED_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7146
        CLASSIFICATION_TYPE_CIVIC_MISINFORMATION_NON_DEDICATED_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7156
        CLASSIFICATION_TYPE_COORDINATION_OR_CREDIBLE_ADMISSION_OF_REAL_WORLD_VIOLENCE_NON_DEDICATED_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7166
        CLASSIFICATION_TYPE_CSAM_NON_DEDICATED_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7176
        CLASSIFICATION_TYPE_DENIAL_OF_HUMAN_ATROCITY_NON_DEDICATED_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7186
        CLASSIFICATION_TYPE_DRAWN_SEXUALIZED_CHILDREN_NON_DEDICATED_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7196
        CLASSIFICATION_TYPE_HARASSMENT_AND_NON_IMMINENT_AND_OR_NON_PHYSICAL_THREATS_RETOOL: UserData._ClassificationType.ValueType  # 7200
        CLASSIFICATION_TYPE_HATE_SPEECH_AND_SYMBOLS_RETOOL: UserData._ClassificationType.ValueType  # 7210
        CLASSIFICATION_TYPE_IMMINENT_THREATS_OF_EXTORTION_RETOOL: UserData._ClassificationType.ValueType  # 7220
        CLASSIFICATION_TYPE_INAPPROPRIATE_SEXUAL_INTERACTIONS_WITH_MINORS_NON_GROOMING_RETOOL: UserData._ClassificationType.ValueType  # 7230
        CLASSIFICATION_TYPE_MALWARE_AND_MALICIOUS_CONDUCT_RETOOL: UserData._ClassificationType.ValueType  # 7240
        CLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_EXPLICIT_CONTENT_RETOOL: UserData._ClassificationType.ValueType  # 7250
        CLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_SUGGESTIVE_MEDIA_RETOOL: UserData._ClassificationType.ValueType  # 7260
        CLASSIFICATION_TYPE_NON_GATED_CHANNEL_DEDICATED_TO_AGE_RESTRICTED_CONTENT_RETOOL: UserData._ClassificationType.ValueType  # 7270
        CLASSIFICATION_TYPE_NON_GATED_SERVER_DEDICATED_TO_AGE_RESTRICTED_CONTENT_RETOOL: UserData._ClassificationType.ValueType  # 7280
        CLASSIFICATION_TYPE_OFF_PLATFORM_BEHAVIORS_RETOOL: UserData._ClassificationType.ValueType  # 7290
        CLASSIFICATION_TYPE_ORGANIZING_OR_FACILITATING_HUMAN_TRAFFICKING_RETOOL: UserData._ClassificationType.ValueType  # 7300
        CLASSIFICATION_TYPE_PLATFORM_BAN_EVASION_RETOOL: UserData._ClassificationType.ValueType  # 7060
        CLASSIFICATION_TYPE_PROMOTING_OR_PARTICIPATING_IN_REAL_WORLD_SEXUAL_SERVICES_RETOOL: UserData._ClassificationType.ValueType  # 7310
        CLASSIFICATION_TYPE_SALE_OF_MALICIOUS_TOOLS_AND_SERVICES_RETOOL: UserData._ClassificationType.ValueType  # 7320
        CLASSIFICATION_TYPE_SELF_GENERATED_CSAM_SG_CSAM_RETOOL: UserData._ClassificationType.ValueType  # 7330
        CLASSIFICATION_TYPE_SELF_HARM_PROMOTION_RETOOL: UserData._ClassificationType.ValueType  # 7340
        CLASSIFICATION_TYPE_SEXUAL_ASSAULT_VIOLENCE_MEDIA_RETOOL: UserData._ClassificationType.ValueType  # 7350
        CLASSIFICATION_TYPE_SEXUAL_DEEPFAKES_RETOOL: UserData._ClassificationType.ValueType  # 7360
        CLASSIFICATION_TYPE_SEXUAL_GROOMING_OF_A_CHILD_AND_CSAM_SOLICITATION_RETOOL: UserData._ClassificationType.ValueType  # 7370
        CLASSIFICATION_TYPE_SEXUALLY_EXPLICIT_CONTENT_WITH_IMPLICATIONS_FOR_REAL_WORLD_HARM_RETOOL: UserData._ClassificationType.ValueType  # 7380
        CLASSIFICATION_TYPE_SUICIDE_PROMOTION_RETOOL: UserData._ClassificationType.ValueType  # 7390
        CLASSIFICATION_TYPE_TRIBUTES_AND_LEAKED_ADULT_INTIMATE_MEDIA_RETOOL: UserData._ClassificationType.ValueType  # 7400
        CLASSIFICATION_TYPE_VIOLENCE_GLORIFICATION_PROMOTION_OR_INCITEMENT_RETOOL: UserData._ClassificationType.ValueType  # 7410
        CLASSIFICATION_TYPE_VIOLENT_EXTREMISM_ORGANIZING_RETOOL: UserData._ClassificationType.ValueType  # 7420
        CLASSIFICATION_TYPE_VIOLENT_EXTREMISM_SUPPORT_PROMOTION_OR_EMULATION_RETOOL: UserData._ClassificationType.ValueType  # 7430
        CLASSIFICATION_TYPE_VOYEURISTIC_MEDIA_RETOOL: UserData._ClassificationType.ValueType  # 7440
        CLASSIFICATION_TYPE_HARASSMENT_AND_NON_IMMINENT_AND_OR_NON_PHYSICAL_THREATS_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7205
        CLASSIFICATION_TYPE_HATE_SPEECH_AND_SYMBOLS_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7215
        CLASSIFICATION_TYPE_IMMINENT_THREATS_OF_EXTORTION_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7225
        CLASSIFICATION_TYPE_INAPPROPRIATE_SEXUAL_INTERACTIONS_WITH_MINORS_NON_GROOMING_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7235
        CLASSIFICATION_TYPE_MALWARE_AND_MALICIOUS_CONDUCT_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7245
        CLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_EXPLICIT_CONTENT_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7255
        CLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_SUGGESTIVE_MEDIA_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7265
        CLASSIFICATION_TYPE_NON_GATED_CHANNEL_DEDICATED_TO_AGE_RESTRICTED_CONTENT_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7275
        CLASSIFICATION_TYPE_NON_GATED_SERVER_DEDICATED_TO_AGE_RESTRICTED_CONTENT_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7285
        CLASSIFICATION_TYPE_OFF_PLATFORM_BEHAVIORS_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7295
        CLASSIFICATION_TYPE_ORGANIZING_OR_FACILITATING_HUMAN_TRAFFICKING_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7305
        CLASSIFICATION_TYPE_PROMOTING_OR_PARTICIPATING_IN_REAL_WORLD_SEXUAL_SERVICES_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7315
        CLASSIFICATION_TYPE_SALE_OF_MALICIOUS_TOOLS_AND_SERVICES_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7325
        CLASSIFICATION_TYPE_SELF_GENERATED_CSAM_SG_CSAM_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7335
        CLASSIFICATION_TYPE_SELF_HARM_PROMOTION_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7345
        CLASSIFICATION_TYPE_SEXUAL_ASSAULT_VIOLENCE_MEDIA_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7355
        CLASSIFICATION_TYPE_SEXUAL_DEEPFAKES_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7365
        CLASSIFICATION_TYPE_SEXUAL_GROOMING_OF_A_CHILD_AND_CSAM_SOLICITATION_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7375
        CLASSIFICATION_TYPE_SEXUALLY_EXPLICIT_CONTENT_WITH_IMPLICATIONS_FOR_REAL_WORLD_HARM_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7385
        CLASSIFICATION_TYPE_SUICIDE_PROMOTION_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7395
        CLASSIFICATION_TYPE_TRIBUTES_AND_LEAKED_ADULT_INTIMATE_MEDIA_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7405
        CLASSIFICATION_TYPE_VIOLENCE_GLORIFICATION_PROMOTION_OR_INCITEMENT_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7415
        CLASSIFICATION_TYPE_VIOLENT_EXTREMISM_ORGANIZING_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7425
        CLASSIFICATION_TYPE_VIOLENT_EXTREMISM_SUPPORT_PROMOTION_OR_EMULATION_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7435
        CLASSIFICATION_TYPE_VOYEURISTIC_MEDIA_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7445
        CLASSIFICATION_TYPE_HARASSMENT_AND_NON_IMMINENT_AND_OR_NON_PHYSICAL_THREATS_NON_DEDICATED_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7206
        CLASSIFICATION_TYPE_HATE_SPEECH_AND_SYMBOLS_NON_DEDICATED_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7216
        CLASSIFICATION_TYPE_IMMINENT_THREATS_OF_EXTORTION_NON_DEDICATED_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7226
        CLASSIFICATION_TYPE_INAPPROPRIATE_SEXUAL_INTERACTIONS_WITH_MINORS_NON_GROOMING_NON_DEDICATED_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7236
        CLASSIFICATION_TYPE_MALWARE_AND_MALICIOUS_CONDUCT_NON_DEDICATED_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7246
        CLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_EXPLICIT_CONTENT_NON_DEDICATED_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7256
        CLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_SUGGESTIVE_MEDIA_NON_DEDICATED_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7266
        CLASSIFICATION_TYPE_NON_GATED_CHANNEL_DEDICATED_TO_AGE_RESTRICTED_CONTENT_NON_DEDICATED_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7276
        CLASSIFICATION_TYPE_NON_GATED_SERVER_DEDICATED_TO_AGE_RESTRICTED_CONTENT_NON_DEDICATED_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7286
        CLASSIFICATION_TYPE_OFF_PLATFORM_BEHAVIORS_NON_DEDICATED_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7296
        CLASSIFICATION_TYPE_ORGANIZING_OR_FACILITATING_HUMAN_TRAFFICKING_NON_DEDICATED_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7306
        CLASSIFICATION_TYPE_PLATFORM_BAN_EVASION_NON_DEDICATED_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7066
        CLASSIFICATION_TYPE_PROMOTING_OR_PARTICIPATING_IN_REAL_WORLD_SEXUAL_SERVICES_NON_DEDICATED_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7316
        CLASSIFICATION_TYPE_SALE_OF_MALICIOUS_TOOLS_AND_SERVICES_NON_DEDICATED_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7326
        CLASSIFICATION_TYPE_SELF_GENERATED_CSAM_SG_CSAM_NON_DEDICATED_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7336
        CLASSIFICATION_TYPE_SELF_HARM_PROMOTION_NON_DEDICATED_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7346
        CLASSIFICATION_TYPE_SEXUAL_ASSAULT_VIOLENCE_MEDIA_NON_DEDICATED_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7356
        CLASSIFICATION_TYPE_SEXUAL_DEEPFAKES_NON_DEDICATED_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7366
        CLASSIFICATION_TYPE_SEXUAL_GROOMING_OF_A_CHILD_AND_CSAM_SOLICITATION_NON_DEDICATED_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7376
        CLASSIFICATION_TYPE_SEXUALLY_EXPLICIT_CONTENT_WITH_IMPLICATIONS_FOR_REAL_WORLD_HARM_NON_DEDICATED_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7386
        CLASSIFICATION_TYPE_SUICIDE_PROMOTION_NON_DEDICATED_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7396
        CLASSIFICATION_TYPE_TRIBUTES_AND_LEAKED_ADULT_INTIMATE_MEDIA_NON_DEDICATED_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7406
        CLASSIFICATION_TYPE_VIOLENCE_GLORIFICATION_PROMOTION_OR_INCITEMENT_NON_DEDICATED_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7416
        CLASSIFICATION_TYPE_VIOLENT_EXTREMISM_ORGANIZING_NON_DEDICATED_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7426
        CLASSIFICATION_TYPE_VIOLENT_EXTREMISM_SUPPORT_PROMOTION_OR_EMULATION_NON_DEDICATED_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7436
        CLASSIFICATION_TYPE_VOYEURISTIC_MEDIA_NON_DEDICATED_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7446
        CLASSIFICATION_TYPE_FRAUD_SERVICES_LOW_RISK_RETOOL: UserData._ClassificationType.ValueType  # 7450
        CLASSIFICATION_TYPE_FRAUD_SERVICES_MEDIUM_RISK_RETOOL: UserData._ClassificationType.ValueType  # 7460
        CLASSIFICATION_TYPE_FRAUD_SERVICES_LOW_RISK_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7455
        CLASSIFICATION_TYPE_FRAUD_SERVICES_MEDIUM_RISK_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7465
        CLASSIFICATION_TYPE_FRAUD_SERVICES_LOW_RISK_NON_DEDICATED_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7456
        CLASSIFICATION_TYPE_FRAUD_SERVICES_MEDIUM_RISK_NON_DEDICATED_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7466
        CLASSIFICATION_TYPE_FRAUD_SERVICES_HIGH_RISK_RETOOL: UserData._ClassificationType.ValueType  # 7470
        CLASSIFICATION_TYPE_FRAUD_SERVICES_HIGH_RISK_GUILD_RETOOL: UserData._ClassificationType.ValueType  # 7475
        CLASSIFICATION_TYPE_NON_CONSENSUAL_ADULT_INTIMATE_MEDIA_TAKEDOWN_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 7480
        CLASSIFICATION_TYPE_NON_CONSENSUAL_ADULT_INTIMATE_MEDIA_TAKEDOWN_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData._ClassificationType.ValueType  # 7486
        CLASSIFICATION_TYPE_NON_CONSENSUAL_ADULT_INTIMATE_MEDIA_TAKEDOWN_ADMIN: UserData._ClassificationType.ValueType  # 7490
        CLASSIFICATION_TYPE_NON_CONSENSUAL_ADULT_INTIMATE_MEDIA_TAKEDOWN_NON_DEDICATED_GUILD_ADMIN: UserData._ClassificationType.ValueType  # 7496
        CLASSIFICATION_TYPE_NON_CONSENSUAL_ADULT_INTIMATE_MEDIA_TAKEDOWN_HASH_MATCH: UserData._ClassificationType.ValueType  # 7500
        CLASSIFICATION_TYPE_TEST_CLASSIFICATION: UserData._ClassificationType.ValueType  # 9000
        CLASSIFICATION_TYPE_TEST_CLASSIFICATION_LOW: UserData._ClassificationType.ValueType  # 9001
        CLASSIFICATION_TYPE_TEST_CLASSIFICATION_SEVERE: UserData._ClassificationType.ValueType  # 9002
        CLASSIFICATION_TYPE_TEST_GUILD_CLASSIFICATION: UserData._ClassificationType.ValueType  # 9100
        CLASSIFICATION_TYPE_TEST_GUILD_CLASSIFICATION_LOW: UserData._ClassificationType.ValueType  # 9101
        CLASSIFICATION_TYPE_TEST_GUILD_CLASSIFICATION_SEVERE: UserData._ClassificationType.ValueType  # 9102
        CLASSIFICATION_TYPE_TEST_PROVISIONAL_ACCOUNT_CLASSIFICATION: UserData._ClassificationType.ValueType  # 9200

    class ClassificationType(_ClassificationType, metaclass=_ClassificationTypeEnumTypeWrapper): ...
    CLASSIFICATION_TYPE_UNSPECIFIED: UserData.ClassificationType.ValueType  # 0
    CLASSIFICATION_TYPE_UNKNOWN: UserData.ClassificationType.ValueType  # 1
    CLASSIFICATION_TYPE_UNSOLICITED_PORNOGRAPHY: UserData.ClassificationType.ValueType  # 100
    CLASSIFICATION_TYPE_NONCONSENSUAL_PORNOGRAPHY: UserData.ClassificationType.ValueType  # 200
    CLASSIFICATION_TYPE_GLORIFYING_VIOLENCE: UserData.ClassificationType.ValueType  # 210
    CLASSIFICATION_TYPE_HATE_SPEECH: UserData.ClassificationType.ValueType  # 220
    CLASSIFICATION_TYPE_CRACKED_ACCOUNTS: UserData.ClassificationType.ValueType  # 230
    CLASSIFICATION_TYPE_ILLICIT_GOODS: UserData.ClassificationType.ValueType  # 240
    CLASSIFICATION_TYPE_SOCIAL_ENGINEERING: UserData.ClassificationType.ValueType  # 250
    CLASSIFICATION_TYPE_SELF_GENERATED_CSAM_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 260
    CLASSIFICATION_TYPE_UNDERAGE_USER_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 270
    CLASSIFICATION_TYPE_CSAM_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 280
    CLASSIFICATION_TYPE_CSAM_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 286
    CLASSIFICATION_TYPE_DOXXING_MEDIUM_RISK_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 290
    CLASSIFICATION_TYPE_DOXXING_MEDIUM_RISK_TIER_2_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 296
    CLASSIFICATION_TYPE_DOXXING_HIGH_RISK_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 300
    CLASSIFICATION_TYPE_DOXXING_HIGH_RISK_TIER_1_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 306
    CLASSIFICATION_TYPE_HARASSMENT_AND_THREATS_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 310
    CLASSIFICATION_TYPE_HATE_SPEECH_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 320
    CLASSIFICATION_TYPE_HATE_SPEECH_AND_SYMBOLS_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 326
    CLASSIFICATION_TYPE_VIOLENCE_GLORIFICATION_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 330
    CLASSIFICATION_TYPE_VIOLENCE_GLORIFICATION_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 336
    CLASSIFICATION_TYPE_REGULATED_GOODS_HIGH_RISK_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 340
    CLASSIFICATION_TYPE_REGULATED_GOODS_MEDIUM_RISK_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 350
    CLASSIFICATION_TYPE_MEDIUM_RISK_DANGEROUS_AND_REGULATED_GOODS_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 356
    CLASSIFICATION_TYPE_REGULATED_GOODS_LOW_RISK_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 360
    CLASSIFICATION_TYPE_FRAUD_SERVICES_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 370
    CLASSIFICATION_TYPE_FRAUD_SERVICES_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 376
    CLASSIFICATION_TYPE_FINANCIAL_SCAMS_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 380
    CLASSIFICATION_TYPE_SEXUAL_HARASSMENT_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 390
    CLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_EXPLICIT_CONTENT_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 400
    CLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_EXPLICIT_CONTENT_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 406
    CLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_SUGGESTIVE_MEDIA_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 410
    CLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_SUGGESTIVE_MEDIA_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 416
    CLASSIFICATION_TYPE_TRANSACTION_SCAMS_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 420
    CLASSIFICATION_TYPE_CSAM_MEDIUM_CONFIDENCE_HASH_MATCH: UserData.ClassificationType.ValueType  # 500
    CLASSIFICATION_TYPE_CSAM_HIGH_CONFIDENCE_HASH_MATCH: UserData.ClassificationType.ValueType  # 501
    CLASSIFICATION_TYPE_CSAM_MEDIUM_CONFIDENCE_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 510
    CLASSIFICATION_TYPE_CHILD_SEXUALIZATION_CONTENT_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 520
    CLASSIFICATION_TYPE_CHILD_SEXUALIZATION_CONTENT_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 526
    CLASSIFICATION_TYPE_CHILD_LED_SEXUAL_SELF_ENDANGERMENT_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 530
    CLASSIFICATION_TYPE_CHILD_LED_SEXUAL_SELF_ENDANGERMENT_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 536
    CLASSIFICATION_TYPE_CHILD_ENGAGING_WITH_SEXUALLY_EXPLICIT_CONTENT_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 540
    CLASSIFICATION_TYPE_TRIBUTES_AND_LEAKED_ADULT_INTIMATE_MEDIA_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 550
    CLASSIFICATION_TYPE_TRIBUTES_AND_LEAKED_ADULT_INTIMATE_MEDIA_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 556
    CLASSIFICATION_TYPE_POSTING_AGERESTRICTED_CONTENT_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 560
    CLASSIFICATION_TYPE_DENIAL_OF_HUMAN_ATROCITY_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 570
    CLASSIFICATION_TYPE_DENIAL_OF_HUMAN_ATROCITY_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 576
    CLASSIFICATION_TYPE_SUICIDE_PROMOTION_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 580
    CLASSIFICATION_TYPE_SUICIDE_PROMOTION_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 586
    CLASSIFICATION_TYPE_SELF_HARM_PROMOTION_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 590
    CLASSIFICATION_TYPE_SELF_HARM_PROMOTION_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 596
    CLASSIFICATION_TYPE_DRAWN_SEXUALIZED_CHILDREN_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 600
    CLASSIFICATION_TYPE_DRAWN_SEXUALIZED_CHILDREN_API: UserData.ClassificationType.ValueType  # 601
    CLASSIFICATION_TYPE_DRAWN_SEXUALIZED_CHILDREN_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 606
    CLASSIFICATION_TYPE_CHILD_LED_VIGILANTISM_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 610
    CLASSIFICATION_TYPE_INAPPROPRIATE_SEXUAL_INTERACTIONS_WITH_MINORS_NON_GROOMING_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 620
    CLASSIFICATION_TYPE_ADMISSION_OF_SEXUAL_MISCONDUCT_WITH_A_CHILD_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 630
    CLASSIFICATION_TYPE_CSAM_SOLICITATION_OR_ADMISSION_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 640
    CLASSIFICATION_TYPE_CSAM_SOLICITATION_OR_ADMISSION_API: UserData.ClassificationType.ValueType  # 641
    CLASSIFICATION_TYPE_CSAM_SOLICITATION_OR_ADMISSION_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 646
    CLASSIFICATION_TYPE_SEXUAL_GROOMING_OF_A_CHILD_AND_CSAM_SOLICITATION_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 650
    CLASSIFICATION_TYPE_UNKNOWN_CSAM_FACILITATION_HASH_MATCH: UserData.ClassificationType.ValueType  # 660
    CLASSIFICATION_TYPE_UNKNOWN_CSAM_FACILITATION_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 661
    CLASSIFICATION_TYPE_VOYEURISTIC_MEDIA_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 670
    CLASSIFICATION_TYPE_VOYEURISTIC_MEDIA_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 676
    CLASSIFICATION_TYPE_SEXUAL_DEEPFAKES_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 680
    CLASSIFICATION_TYPE_SEXUAL_DEEPFAKES_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 686
    CLASSIFICATION_TYPE_IMPERSONATION_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 5726
    CLASSIFICATION_TYPE_INVESTMENT_AND_IDENTITY_SCAMS_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 5727
    CLASSIFICATION_TYPE_MALWARE_AND_MALICIOUS_CONDUCT_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 690
    CLASSIFICATION_TYPE_MALWARE_AND_MALICIOUS_CONDUCT_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 696
    CLASSIFICATION_TYPE_PHISHING_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 700
    CLASSIFICATION_TYPE_IMPERSONATION_HIGH_RISK_SMITE: UserData.ClassificationType.ValueType  # 710
    CLASSIFICATION_TYPE_IMPERSONATION_HIGH_RISK_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 711
    CLASSIFICATION_TYPE_IMPERSONATION_HIGH_RISK_ADMIN: UserData.ClassificationType.ValueType  # 712
    CLASSIFICATION_TYPE_PLATFORM_BAN_EVASION_SMITE: UserData.ClassificationType.ValueType  # 720
    CLASSIFICATION_TYPE_GENERIC_CHILD_SELF_ENDANGERMENT_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 730
    CLASSIFICATION_TYPE_GENERIC_CSAM_AND_CHILD_SEXUALIZATION_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 740
    CLASSIFICATION_TYPE_GENERIC_INAPPROPRIATE_SEXUAL_CONDUCT_WITH_CHILDREN_AND_GROOMING_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 750
    CLASSIFICATION_TYPE_GENERIC_FINANCIAL_SCAMS_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 760
    CLASSIFICATION_TYPE_GENERIC_FRAUD_SERVICES_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 770
    CLASSIFICATION_TYPE_GENERIC_BULLYING_HARASSMENT_AND_THREATS_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 780
    CLASSIFICATION_TYPE_GENERIC_HATE_SPEECH_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 790
    CLASSIFICATION_TYPE_GENERIC_NON_CONSENSUAL_ADULT_INTIMATE_MEDIA_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 800
    CLASSIFICATION_TYPE_GENERIC_SELF_HARM_ENCOURAGEMENT_AND_PROMOTION_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 810
    CLASSIFICATION_TYPE_GENERIC_GLORIFICATION_AND_INCITEMENT_OF_VIOLENCE_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 820
    CLASSIFICATION_TYPE_GENERIC_CYBERCRIME_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 830
    CLASSIFICATION_TYPE_NON_GATED_SERVER_DEDICATED_TO_AGE_RESTRICTED_CONTENT_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 846
    CLASSIFICATION_TYPE_VIOLENT_MEDIA_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 850
    CLASSIFICATION_TYPE_VIOLENT_MEDIA_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 856
    CLASSIFICATION_TYPE_HARASSMENT_AND_NONIMMINENT_AND_OR_NON_PHYSICAL_THREATS_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 866
    CLASSIFICATION_TYPE_SALE_OR_PURCHASE_OF_DISCORD_ASSETS_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 876
    CLASSIFICATION_TYPE_SALE_OF_PLATFORM_ABUSE_TOOLS_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 886
    CLASSIFICATION_TYPE_CHILD_SEXTORTION_FINANCIAL_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 890
    CLASSIFICATION_TYPE_CHILD_SEXTORTION_FINANCIAL_GUILD_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 895
    CLASSIFICATION_TYPE_CHILD_SEXTORTION_FINANCIAL_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 896
    CLASSIFICATION_TYPE_CHILD_SEXTORTION_NON_FINANCIAL_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 900
    CLASSIFICATION_TYPE_CHILD_SEXTORTION_NON_FINANCIAL_GUILD_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 905
    CLASSIFICATION_TYPE_CHILD_SEXTORTION_NON_FINANCIAL_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 906
    CLASSIFICATION_TYPE_ADULT_SEXTORTION_FINANCIAL_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 910
    CLASSIFICATION_TYPE_ADULT_SEXTORTION_FINANCIAL_GUILD_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 915
    CLASSIFICATION_TYPE_ADULT_SEXTORTION_FINANCIAL_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 916
    CLASSIFICATION_TYPE_ADULT_SEXTORTION_NON_FINANCIAL_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 920
    CLASSIFICATION_TYPE_ADULT_SEXTORTION_NON_FINANCIAL_GUILD_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 925
    CLASSIFICATION_TYPE_ADULT_SEXTORTION_NON_FINANCIAL_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 926
    CLASSIFICATION_TYPE_GORE_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 930
    CLASSIFICATION_TYPE_SEXUAL_ASSAULT_VIOLENCE_MEDIA_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 936
    CLASSIFICATION_TYPE_SALE_OF_MALICIOUS_TOOLS_AND_SERVICES_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 940
    CLASSIFICATION_TYPE_SALE_OF_MALICIOUS_TOOLS_AND_SERVICES_GUILD_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 945
    CLASSIFICATION_TYPE_SALE_OF_MALICIOUS_TOOLS_AND_SERVICES_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 946
    CLASSIFICATION_TYPE_FRAUD_SERVICES_LOW_RISK_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 950
    CLASSIFICATION_TYPE_FRAUD_SERVICES_LOW_RISK_GUILD_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 955
    CLASSIFICATION_TYPE_FRAUD_SERVICES_LOW_RISK_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 956
    CLASSIFICATION_TYPE_FRAUD_SERVICES_MEDIUM_RISK_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 960
    CLASSIFICATION_TYPE_FRAUD_SERVICES_MEDIUM_RISK_GUILD_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 965
    CLASSIFICATION_TYPE_FRAUD_SERVICES_MEDIUM_RISK_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 966
    CLASSIFICATION_TYPE_FRAUD_SERVICES_HIGH_RISK_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 970
    CLASSIFICATION_TYPE_FRAUD_SERVICES_HIGH_RISK_GUILD_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 975
    CLASSIFICATION_TYPE_GORE_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 976
    CLASSIFICATION_TYPE_AGE_RESTRICTED_CONTENT_IN_SERVER_ASSETS_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 986
    CLASSIFICATION_TYPE_CSAM_SMITE: UserData.ClassificationType.ValueType  # 3000
    CLASSIFICATION_TYPE_CSAM_GUILD_SMITE: UserData.ClassificationType.ValueType  # 3005
    CLASSIFICATION_TYPE_SUSPICIOUS_LINK_SMITE: UserData.ClassificationType.ValueType  # 3010
    CLASSIFICATION_TYPE_INVESTMENT_AND_IDENTITY_SCAMS_SMITE: UserData.ClassificationType.ValueType  # 3020
    CLASSIFICATION_TYPE_SPAM_SMITE: UserData.ClassificationType.ValueType  # 3030
    CLASSIFICATION_TYPE_SPAM_CEILING_SMITE: UserData.ClassificationType.ValueType  # 3120
    CLASSIFICATION_TYPE_VOLUMETRIC_ABUSE_SMITE: UserData.ClassificationType.ValueType  # 3130
    CLASSIFICATION_TYPE_CHARGEBACK_HIGH_RISK_SMITE: UserData.ClassificationType.ValueType  # 3040
    CLASSIFICATION_TYPE_CHARGEBACK_LOW_RISK_SMITE: UserData.ClassificationType.ValueType  # 3050
    CLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_EXPLICIT_CONTENT_GUILD_SMITE: UserData.ClassificationType.ValueType  # 3065
    CLASSIFICATION_TYPE_INAUTHENTIC_SERVER_MEDIUM_CONFIDENCE_GUILD_SMITE: UserData.ClassificationType.ValueType  # 3075
    CLASSIFICATION_TYPE_MALWARE_AND_MALICIOUS_CONDUCT_SMITE: UserData.ClassificationType.ValueType  # 3085
    CLASSIFICATION_TYPE_MALWARE_AND_MALICIOUS_CONDUCT_GUILD_SMITE: UserData.ClassificationType.ValueType  # 3090
    CLASSIFICATION_TYPE_MALWARE_AND_MALICIOUS_CONDUCT_NON_DEDICATED_GUILD_SMITE: UserData.ClassificationType.ValueType  # 3091
    CLASSIFICATION_TYPE_EARLY_FRAUD_WARNING_LOW_RISK_SMITE: UserData.ClassificationType.ValueType  # 3100
    CLASSIFICATION_TYPE_EARLY_FRAUD_WARNING_HIGH_RISK_SMITE: UserData.ClassificationType.ValueType  # 3110
    CLASSIFICATION_TYPE_PRESENCE_IN_VIOLATIVE_GUILD_HIGH_RISK: UserData.ClassificationType.ValueType  # 4000
    CLASSIFICATION_TYPE_PRESENCE_IN_VIOLATIVE_GUILD_MEDIUM_RISK: UserData.ClassificationType.ValueType  # 4010
    CLASSIFICATION_TYPE_OWNER_OF_VIOLATIVE_GUILD_VERY_HIGH_RISK: UserData.ClassificationType.ValueType  # 4100
    CLASSIFICATION_TYPE_OWNER_OF_VIOLATIVE_GUILD_HIGH_RISK: UserData.ClassificationType.ValueType  # 4110
    CLASSIFICATION_TYPE_OWNER_OF_VIOLATIVE_GUILD_MEDIUM_RISK: UserData.ClassificationType.ValueType  # 4120
    CLASSIFICATION_TYPE_OWNER_OF_VIOLATIVE_GUILD_LOW_RISK: UserData.ClassificationType.ValueType  # 4130
    CLASSIFICATION_TYPE_OWNER_OF_VIOLATIVE_GUILD_COPYRIGHT: UserData.ClassificationType.ValueType  # 4140
    CLASSIFICATION_TYPE_OWNER_OF_INAUTHENTIC_ENGAGEMENT_GUILD: UserData.ClassificationType.ValueType  # 4150
    CLASSIFICATION_TYPE_CSAM_ADMIN: UserData.ClassificationType.ValueType  # 5000
    CLASSIFICATION_TYPE_CSAM_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5005
    CLASSIFICATION_TYPE_CSAM_NON_DEDICATED_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5006
    CLASSIFICATION_TYPE_CHILD_SEXUALIZATION_CONTENT_ADMIN: UserData.ClassificationType.ValueType  # 5010
    CLASSIFICATION_TYPE_CHILD_SEXUALIZATION_CONTENT_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5015
    CLASSIFICATION_TYPE_CHILD_SEXUALIZATION_CONTENT_NON_DEDICATED_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5016
    CLASSIFICATION_TYPE_DRAWN_SEXUALIZED_CHILDREN_ADMIN: UserData.ClassificationType.ValueType  # 5020
    CLASSIFICATION_TYPE_DRAWN_SEXUALIZED_CHILDREN_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5025
    CLASSIFICATION_TYPE_DRAWN_SEXUALIZED_CHILDREN_NON_DEDICATED_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5026
    CLASSIFICATION_TYPE_INAPPROPRIATE_SEXUAL_INTERACTIONS_WITH_MINORS_NON_GROOMING_ADMIN: UserData.ClassificationType.ValueType  # 5030
    CLASSIFICATION_TYPE_INAPPROPRIATE_SEXUAL_INTERACTIONS_WITH_MINORS_NON_GROOMING_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5035
    CLASSIFICATION_TYPE_INAPPROPRIATE_SEXUAL_INTERACTIONS_WITH_MINORS_NON_GROOMING_NON_DEDICATED_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5036
    CLASSIFICATION_TYPE_ADMISSION_OF_SEXUAL_MISCONDUCT_WITH_A_CHILD_ADMIN: UserData.ClassificationType.ValueType  # 5040
    CLASSIFICATION_TYPE_SEXUAL_GROOMING_OF_A_CHILD_AND_CSAM_SOLICITATION_ADMIN: UserData.ClassificationType.ValueType  # 5050
    CLASSIFICATION_TYPE_SEXUAL_GROOMING_OF_A_CHILD_AND_CSAM_SOLICITATION_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5055
    CLASSIFICATION_TYPE_SELF_GENERATED_CSAM_SGCSAM_ADMIN: UserData.ClassificationType.ValueType  # 5060
    CLASSIFICATION_TYPE_SELF_GENERATED_CSAM_SGCSAM_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5065
    CLASSIFICATION_TYPE_CHILD_LED_SEXUAL_SELF_ENDANGERMENT_ADMIN: UserData.ClassificationType.ValueType  # 5070
    CLASSIFICATION_TYPE_CHILD_LED_SEXUAL_SELF_ENDANGERMENT_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5075
    CLASSIFICATION_TYPE_CHILD_LED_SEXUAL_SELF_ENDANGERMENT_NON_DEDICATED_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5076
    CLASSIFICATION_TYPE_CHILD_LED_VIGILANTISM_ADMIN: UserData.ClassificationType.ValueType  # 5080
    CLASSIFICATION_TYPE_CHILD_LED_VIGILANTISM_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5085
    CLASSIFICATION_TYPE_CHILD_ENGAGING_WITH_SEXUALLY_EXPLICIT_CONTENT_ADMIN: UserData.ClassificationType.ValueType  # 5090
    CLASSIFICATION_TYPE_SEXUALLY_EXPLICIT_CONTENT_WITH_IMPLICATIONS_FOR_REAL_WORLD_HARM_ADMIN: UserData.ClassificationType.ValueType  # 5100
    CLASSIFICATION_TYPE_SEXUALLY_EXPLICIT_CONTENT_WITH_IMPLICATIONS_FOR_REAL_WORLD_HARM_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5105
    CLASSIFICATION_TYPE_SEXUALLY_EXPLICIT_CONTENT_WITH_IMPLICATIONS_FOR_REAL_WORLD_HARM_NON_DEDICATED_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5106
    CLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_EXPLICIT_CONTENT_ADMIN: UserData.ClassificationType.ValueType  # 5110
    CLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_EXPLICIT_CONTENT_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5115
    CLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_EXPLICIT_CONTENT_NON_DEDICATED_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5116
    CLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_SUGGESTIVE_MEDIA_ADMIN: UserData.ClassificationType.ValueType  # 5120
    CLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_SUGGESTIVE_MEDIA_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5125
    CLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_SUGGESTIVE_MEDIA_NON_DEDICATED_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5126
    CLASSIFICATION_TYPE_TRIBUTES_AND_LEAKED_ADULT_INTIMATE_MEDIA_ADMIN: UserData.ClassificationType.ValueType  # 5130
    CLASSIFICATION_TYPE_TRIBUTES_AND_LEAKED_ADULT_INTIMATE_MEDIA_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5135
    CLASSIFICATION_TYPE_TRIBUTES_AND_LEAKED_ADULT_INTIMATE_MEDIA_NON_DEDICATED_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5136
    CLASSIFICATION_TYPE_VOYEURISTIC_MEDIA_ADMIN: UserData.ClassificationType.ValueType  # 5140
    CLASSIFICATION_TYPE_VOYEURISTIC_MEDIA_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5145
    CLASSIFICATION_TYPE_VOYEURISTIC_MEDIA_NON_DEDICATED_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5146
    CLASSIFICATION_TYPE_SEXUAL_DEEPFAKES_ADMIN: UserData.ClassificationType.ValueType  # 5150
    CLASSIFICATION_TYPE_SEXUAL_DEEPFAKES_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5155
    CLASSIFICATION_TYPE_SEXUAL_DEEPFAKES_NON_DEDICATED_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5156
    CLASSIFICATION_TYPE_SEXUAL_ASSAULT_VIOLENCE_MEDIA_ADMIN: UserData.ClassificationType.ValueType  # 5160
    CLASSIFICATION_TYPE_SEXUAL_ASSAULT_VIOLENCE_MEDIA_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5165
    CLASSIFICATION_TYPE_SEXUAL_ASSAULT_VIOLENCE_MEDIA_NON_DEDICATED_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5166
    CLASSIFICATION_TYPE_SUICIDE_PROMOTION_ADMIN: UserData.ClassificationType.ValueType  # 5170
    CLASSIFICATION_TYPE_SUICIDE_PROMOTION_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5175
    CLASSIFICATION_TYPE_SUICIDE_PROMOTION_NON_DEDICATED_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5176
    CLASSIFICATION_TYPE_SELF_HARM_PROMOTION_ADMIN: UserData.ClassificationType.ValueType  # 5180
    CLASSIFICATION_TYPE_SELF_HARM_PROMOTION_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5185
    CLASSIFICATION_TYPE_SELF_HARM_PROMOTION_NON_DEDICATED_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5186
    CLASSIFICATION_TYPE_RISK_OF_PHYSICAL_SELF_HARM_ADMIN: UserData.ClassificationType.ValueType  # 5190
    CLASSIFICATION_TYPE_VIOLENT_MEDIA_ADMIN: UserData.ClassificationType.ValueType  # 5200
    CLASSIFICATION_TYPE_VIOLENT_MEDIA_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5205
    CLASSIFICATION_TYPE_VIOLENT_MEDIA_NON_DEDICATED_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5206
    CLASSIFICATION_TYPE_GORE_ADMIN: UserData.ClassificationType.ValueType  # 5210
    CLASSIFICATION_TYPE_GORE_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5215
    CLASSIFICATION_TYPE_GORE_NON_DEDICATED_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5216
    CLASSIFICATION_TYPE_VIOLENCE_GLORIFICATION_PROMOTION_OR_INCITEMENT_ADMIN: UserData.ClassificationType.ValueType  # 5220
    CLASSIFICATION_TYPE_VIOLENCE_GLORIFICATION_PROMOTION_OR_INCITEMENT_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5225
    CLASSIFICATION_TYPE_VIOLENCE_GLORIFICATION_PROMOTION_OR_INCITEMENT_NON_DEDICATED_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5226
    CLASSIFICATION_TYPE_COORDINATION_OR_CREDIBLE_ADMISSION_OF_REAL_WORLD_VIOLENCE_ADMIN: UserData.ClassificationType.ValueType  # 5230
    CLASSIFICATION_TYPE_COORDINATION_OR_CREDIBLE_ADMISSION_OF_REAL_WORLD_VIOLENCE_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5235
    CLASSIFICATION_TYPE_COORDINATION_OR_CREDIBLE_ADMISSION_OF_REAL_WORLD_VIOLENCE_NON_DEDICATED_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5236
    CLASSIFICATION_TYPE_HARASSMENT_AND_NONIMMINENT_AND_OR_NON_PHYSICAL_THREATS_ADMIN: UserData.ClassificationType.ValueType  # 5240
    CLASSIFICATION_TYPE_HARASSMENT_AND_NONIMMINENT_AND_OR_NON_PHYSICAL_THREATS_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5245
    CLASSIFICATION_TYPE_HARASSMENT_AND_NONIMMINENT_AND_OR_NON_PHYSICAL_THREATS_NON_DEDICATED_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5246
    CLASSIFICATION_TYPE_SEXUAL_HARASSMENT_ADMIN: UserData.ClassificationType.ValueType  # 5250
    CLASSIFICATION_TYPE_SERVER_RAIDS_ADMIN: UserData.ClassificationType.ValueType  # 5260
    CLASSIFICATION_TYPE_SERVER_RAIDS_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5265
    CLASSIFICATION_TYPE_SERVER_RAIDS_NON_DEDICATED_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5266
    CLASSIFICATION_TYPE_IMMINENT_THREATS_OF_PHYSICAL_HARM_ADMIN: UserData.ClassificationType.ValueType  # 5270
    CLASSIFICATION_TYPE_IMMINENT_THREATS_OF_PHYSICAL_HARM_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5275
    CLASSIFICATION_TYPE_IMMINENT_THREATS_OF_PHYSICAL_HARM_NON_DEDICATED_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5276
    CLASSIFICATION_TYPE_IMMINENT_THREATS_OF_EXTORTION_ADMIN: UserData.ClassificationType.ValueType  # 5280
    CLASSIFICATION_TYPE_IMMINENT_THREATS_OF_EXTORTION_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5285
    CLASSIFICATION_TYPE_IMMINENT_THREATS_OF_EXTORTION_NON_DEDICATED_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5286
    CLASSIFICATION_TYPE_DOXXING_HIGH_RISK_TIER_1_ADMIN: UserData.ClassificationType.ValueType  # 5290
    CLASSIFICATION_TYPE_DOXXING_HIGH_RISK_TIER_1_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5295
    CLASSIFICATION_TYPE_DOXXING_HIGH_RISK_TIER_1_NON_DEDICATED_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5296
    CLASSIFICATION_TYPE_DOXXING_MEDIUM_RISK_TIER_2_ADMIN: UserData.ClassificationType.ValueType  # 5300
    CLASSIFICATION_TYPE_DOXXING_MEDIUM_RISK_TIER_2_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5305
    CLASSIFICATION_TYPE_DOXXING_MEDIUM_RISK_TIER_2_NON_DEDICATED_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5306
    CLASSIFICATION_TYPE_HATE_SPEECH_AND_SYMBOLS_ADMIN: UserData.ClassificationType.ValueType  # 5310
    CLASSIFICATION_TYPE_HATE_SPEECH_AND_SYMBOLS_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5315
    CLASSIFICATION_TYPE_HATE_SPEECH_AND_SYMBOLS_NON_DEDICATED_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5316
    CLASSIFICATION_TYPE_DENIAL_OF_HUMAN_ATROCITY_ADMIN: UserData.ClassificationType.ValueType  # 5320
    CLASSIFICATION_TYPE_DENIAL_OF_HUMAN_ATROCITY_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5325
    CLASSIFICATION_TYPE_DENIAL_OF_HUMAN_ATROCITY_NON_DEDICATED_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5326
    CLASSIFICATION_TYPE_VIOLENT_EXTREMISM_ORGANIZING_ADMIN: UserData.ClassificationType.ValueType  # 5330
    CLASSIFICATION_TYPE_VIOLENT_EXTREMISM_ORGANIZING_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5335
    CLASSIFICATION_TYPE_VIOLENT_EXTREMISM_SUPPORT_PROMOTION_OR_EMULATION_ADMIN: UserData.ClassificationType.ValueType  # 5340
    CLASSIFICATION_TYPE_VIOLENT_EXTREMISM_SUPPORT_PROMOTION_OR_EMULATION_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5344
    CLASSIFICATION_TYPE_VIOLENT_EXTREMISM_SUPPORT_PROMOTION_OR_EMULATION_NON_DEDICATED_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5346
    CLASSIFICATION_TYPE_HIGH_RISK_DANGEROUS_AND_REGULATED_GOODS_ADMIN: UserData.ClassificationType.ValueType  # 5350
    CLASSIFICATION_TYPE_HIGH_RISK_DANGEROUS_AND_REGULATED_GOODS_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5355
    CLASSIFICATION_TYPE_MEDIUM_RISK_DANGEROUS_AND_REGULATED_GOODS_ADMIN: UserData.ClassificationType.ValueType  # 5360
    CLASSIFICATION_TYPE_MEDIUM_RISK_DANGEROUS_AND_REGULATED_GOODS_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5365
    CLASSIFICATION_TYPE_MEDIUM_RISK_DANGEROUS_AND_REGULATED_GOODS_NON_DEDICATED_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5366
    CLASSIFICATION_TYPE_LOW_RISK_DANGEROUS_AND_REGULATED_GOODS_ADMIN: UserData.ClassificationType.ValueType  # 5370
    CLASSIFICATION_TYPE_LOW_RISK_DANGEROUS_AND_REGULATED_GOODS_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5375
    CLASSIFICATION_TYPE_LOW_RISK_DANGEROUS_AND_REGULATED_GOODS_NON_DEDICATED_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5376
    CLASSIFICATION_TYPE_PROMOTING_OR_PARTICIPATING_IN_REAL_WORLD_SEXUAL_SERVICES_ADMIN: UserData.ClassificationType.ValueType  # 5380
    CLASSIFICATION_TYPE_PROMOTING_OR_PARTICIPATING_IN_REAL_WORLD_SEXUAL_SERVICES_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5385
    CLASSIFICATION_TYPE_PROMOTING_OR_PARTICIPATING_IN_REAL_WORLD_SEXUAL_SERVICES_NON_DEDICATED_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5386
    CLASSIFICATION_TYPE_ORGANIZING_OR_FACILITATING_ILLICIT_GAMBLING_ADMIN: UserData.ClassificationType.ValueType  # 5390
    CLASSIFICATION_TYPE_ORGANIZING_OR_FACILITATING_ILLICIT_GAMBLING_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5395
    CLASSIFICATION_TYPE_ORGANIZING_OR_FACILITATING_ILLICIT_GAMBLING_NON_DEDICATED_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5396
    CLASSIFICATION_TYPE_ORGANIZING_OR_FACILITATING_HUMAN_TRAFFICKING_ADMIN: UserData.ClassificationType.ValueType  # 5400
    CLASSIFICATION_TYPE_ORGANIZING_OR_FACILITATING_HUMAN_TRAFFICKING_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5405
    CLASSIFICATION_TYPE_USER_UNDER_THE_MINIMUM_AGE_WHERE_THEY_RESIDE_ADMIN: UserData.ClassificationType.ValueType  # 5410
    CLASSIFICATION_TYPE_USER_UNDER_THE_MINIMUM_AGE_WHERE_THEY_RESIDE_API: UserData.ClassificationType.ValueType  # 5411
    CLASSIFICATION_TYPE_POSTING_AGERESTRICTED_CONTENT_ADMIN: UserData.ClassificationType.ValueType  # 5420
    CLASSIFICATION_TYPE_COPYRIGHT_MEDIA_UPLOADS_ATTACHMENTS_512C_ADMIN: UserData.ClassificationType.ValueType  # 5430
    CLASSIFICATION_TYPE_COPYRIGHT_MEDIA_UPLOADS_ATTACHMENTS_512C_NON_DEDICATED_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5436
    CLASSIFICATION_TYPE_COPYRIGHT_TEXT_OFFPLATFORM_LINK_512D_ADMIN: UserData.ClassificationType.ValueType  # 5440
    CLASSIFICATION_TYPE_COPYRIGHT_TEXT_OFFPLATFORM_LINK_512D_NON_DEDICATED_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5446
    CLASSIFICATION_TYPE_COPYRIGHT_LIVESTREAMING_512C_ADMIN: UserData.ClassificationType.ValueType  # 5450
    CLASSIFICATION_TYPE_COPYRIGHT_LIVESTREAMING_512C_NON_DEDICATED_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5456
    CLASSIFICATION_TYPE_TRADEMARK_ADMIN: UserData.ClassificationType.ValueType  # 5460
    CLASSIFICATION_TYPE_TRADEMARK_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5465
    CLASSIFICATION_TYPE_TRADEMARK_NON_DEDICATED_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5466
    CLASSIFICATION_TYPE_TRADEMARK_COUNTERFEIT_GOODS_ADMIN: UserData.ClassificationType.ValueType  # 5470
    CLASSIFICATION_TYPE_TRADEMARK_COUNTERFEIT_GOODS_NON_DEDICATED_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5476
    CLASSIFICATION_TYPE_UNAUTHORIZED_COPYRIGHT_ACCESS_ADMIN: UserData.ClassificationType.ValueType  # 5480
    CLASSIFICATION_TYPE_UNAUTHORIZED_COPYRIGHT_ACCESS_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5485
    CLASSIFICATION_TYPE_UNAUTHORIZED_COPYRIGHT_ACCESS_NON_DEDICATED_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5486
    CLASSIFICATION_TYPE_HEALTH_MISINFORMATION_ADMIN: UserData.ClassificationType.ValueType  # 5490
    CLASSIFICATION_TYPE_HEALTH_MISINFORMATION_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5495
    CLASSIFICATION_TYPE_HEALTH_MISINFORMATION_NON_DEDICATED_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5496
    CLASSIFICATION_TYPE_CIVIC_MISINFORMATION_ADMIN: UserData.ClassificationType.ValueType  # 5500
    CLASSIFICATION_TYPE_CIVIC_MISINFORMATION_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5505
    CLASSIFICATION_TYPE_CIVIC_MISINFORMATION_NON_DEDICATED_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5506
    CLASSIFICATION_TYPE_CIVIC_DISRUPTION_MOBILIZATION_FOR_REAL_WORLD_INTERFERENCE_ADMIN: UserData.ClassificationType.ValueType  # 5510
    CLASSIFICATION_TYPE_CIVIC_DISRUPTION_MOBILIZATION_FOR_REAL_WORLD_INTERFERENCE_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5515
    CLASSIFICATION_TYPE_CIVIC_DISRUPTION_MOBILIZATION_FOR_REAL_WORLD_INTERFERENCE_NON_DEDICATED_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5516
    CLASSIFICATION_TYPE_INVESTMENT_AND_IDENTITY_SCAMS_ADMIN: UserData.ClassificationType.ValueType  # 5520
    CLASSIFICATION_TYPE_INVESTMENT_AND_IDENTITY_SCAMS_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5525
    CLASSIFICATION_TYPE_TRANSACTION_SCAMS_ADMIN: UserData.ClassificationType.ValueType  # 5530
    CLASSIFICATION_TYPE_TRANSACTION_SCAMS_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5535
    CLASSIFICATION_TYPE_PHISHING_ADMIN: UserData.ClassificationType.ValueType  # 5540
    CLASSIFICATION_TYPE_MALWARE_AND_MALICIOUS_CONDUCT_ADMIN: UserData.ClassificationType.ValueType  # 5550
    CLASSIFICATION_TYPE_MALWARE_AND_MALICIOUS_CONDUCT_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5555
    CLASSIFICATION_TYPE_MALWARE_AND_MALICIOUS_CONDUCT_NON_DEDICATED_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5556
    CLASSIFICATION_TYPE_MALWARE_TARGETING_CRITICAL_INFRASTRUCTURE_ADMIN: UserData.ClassificationType.ValueType  # 5560
    CLASSIFICATION_TYPE_MALWARE_TARGETING_CRITICAL_INFRASTRUCTURE_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5565
    CLASSIFICATION_TYPE_MALWARE_TARGETING_CRITICAL_INFRASTRUCTURE_NON_DEDICATED_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5566
    CLASSIFICATION_TYPE_MONEY_LAUNDERING_ADMIN: UserData.ClassificationType.ValueType  # 5570
    CLASSIFICATION_TYPE_MONEY_LAUNDERING_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5575
    CLASSIFICATION_TYPE_FORGERY_ADMIN: UserData.ClassificationType.ValueType  # 5580
    CLASSIFICATION_TYPE_FORGERY_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5585
    CLASSIFICATION_TYPE_FRAUD_SERVICES_AND_TOOLS_ADMIN: UserData.ClassificationType.ValueType  # 5590
    CLASSIFICATION_TYPE_FRAUD_SERVICES_AND_TOOLS_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5595
    CLASSIFICATION_TYPE_FRAUD_SERVICES_AND_TOOLS_NON_DEDICATED_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5596
    CLASSIFICATION_TYPE_MISLEADING_ABUSE_REPORTS_ADMIN: UserData.ClassificationType.ValueType  # 5600
    CLASSIFICATION_TYPE_FRAUDULENT_LEGAL_PROCESS_ADMIN: UserData.ClassificationType.ValueType  # 5610
    CLASSIFICATION_TYPE_HARASSMENT_OF_DISCORDS_SUPPORT_TEAMS_ADMIN: UserData.ClassificationType.ValueType  # 5620
    CLASSIFICATION_TYPE_IMPERSONATION_ADMIN: UserData.ClassificationType.ValueType  # 5630
    CLASSIFICATION_TYPE_IMPERSONATION_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5635
    CLASSIFICATION_TYPE_PLATFORM_BAN_EVASION_ADMIN: UserData.ClassificationType.ValueType  # 5640
    CLASSIFICATION_TYPE_PLATFORM_BAN_EVASION_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5645
    CLASSIFICATION_TYPE_OFFPLATFORM_BEHAVIORS_ADMIN: UserData.ClassificationType.ValueType  # 5650
    CLASSIFICATION_TYPE_OFFPLATFORM_BEHAVIORS_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5655
    CLASSIFICATION_TYPE_CSAM_SOLICITATION_OR_ADMISSION_ADMIN: UserData.ClassificationType.ValueType  # 5660
    CLASSIFICATION_TYPE_CSAM_SOLICITATION_OR_ADMISSION_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5665
    CLASSIFICATION_TYPE_CSAM_SOLICITATION_OR_ADMISSION_NON_DEDICATED_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5666
    CLASSIFICATION_TYPE_SALE_OR_PURCHASE_OF_DISCORD_ASSETS_ADMIN: UserData.ClassificationType.ValueType  # 5670
    CLASSIFICATION_TYPE_SALE_OR_PURCHASE_OF_DISCORD_ASSETS_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5675
    CLASSIFICATION_TYPE_SALE_OR_PURCHASE_OF_DISCORD_ASSETS_NON_DEDICATED_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5676
    CLASSIFICATION_TYPE_SALE_OR_PURCHASE_OF_ARTIFICIAL_ENGAGEMENT_ADMIN: UserData.ClassificationType.ValueType  # 5680
    CLASSIFICATION_TYPE_SALE_OR_PURCHASE_OF_ARTIFICIAL_ENGAGEMENT_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5685
    CLASSIFICATION_TYPE_SALE_OR_PURCHASE_OF_ARTIFICIAL_ENGAGEMENT_NON_DEDICATED_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5686
    CLASSIFICATION_TYPE_SERVER_THAT_HAS_ARTIFICIALLY_INFLATED_MEMBERS_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5695
    CLASSIFICATION_TYPE_SALE_OF_PLATFORM_ABUSE_TOOLS_ADMIN: UserData.ClassificationType.ValueType  # 5700
    CLASSIFICATION_TYPE_SALE_OF_PLATFORM_ABUSE_TOOLS_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5705
    CLASSIFICATION_TYPE_SALE_OF_PLATFORM_ABUSE_TOOLS_NON_DEDICATED_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5706
    CLASSIFICATION_TYPE_NON_GATED_CHANNEL_DEDICATED_TO_AGE_RESTRICTED_CONTENT_ADMIN: UserData.ClassificationType.ValueType  # 5716
    CLASSIFICATION_TYPE_NON_GATED_SERVER_DEDICATED_TO_AGE_RESTRICTED_CONTENT_ADMIN: UserData.ClassificationType.ValueType  # 5735
    CLASSIFICATION_TYPE_UNKNOWN_CSAM_FACILITATION_ADMIN: UserData.ClassificationType.ValueType  # 5740
    CLASSIFICATION_TYPE_CHARGEBACK_HIGH_RISK_ADMIN: UserData.ClassificationType.ValueType  # 5750
    CLASSIFICATION_TYPE_CHARGEBACK_LOW_RISK_ADMIN: UserData.ClassificationType.ValueType  # 5760
    CLASSIFICATION_TYPE_CHILD_SEXTORTION_FINANCIAL_ADMIN: UserData.ClassificationType.ValueType  # 5770
    CLASSIFICATION_TYPE_CHILD_SEXTORTION_FINANCIAL_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5775
    CLASSIFICATION_TYPE_CHILD_SEXTORTION_FINANCIAL_NON_DEDICATED_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5776
    CLASSIFICATION_TYPE_CHILD_SEXTORTION_NON_FINANCIAL_ADMIN: UserData.ClassificationType.ValueType  # 5780
    CLASSIFICATION_TYPE_CHILD_SEXTORTION_NON_FINANCIAL_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5785
    CLASSIFICATION_TYPE_CHILD_SEXTORTION_NON_FINANCIAL_NON_DEDICATED_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5786
    CLASSIFICATION_TYPE_ADULT_SEXTORTION_FINANCIAL_ADMIN: UserData.ClassificationType.ValueType  # 5790
    CLASSIFICATION_TYPE_ADULT_SEXTORTION_FINANCIAL_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5795
    CLASSIFICATION_TYPE_ADULT_SEXTORTION_FINANCIAL_NON_DEDICATED_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5796
    CLASSIFICATION_TYPE_ADULT_SEXTORTION_NON_FINANCIAL_ADMIN: UserData.ClassificationType.ValueType  # 5800
    CLASSIFICATION_TYPE_ADULT_SEXTORTION_NON_FINANCIAL_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5805
    CLASSIFICATION_TYPE_ADULT_SEXTORTION_NON_FINANCIAL_NON_DEDICATED_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5806
    CLASSIFICATION_TYPE_SALE_OF_MALICIOUS_TOOLS_AND_SERVICES_ADMIN: UserData.ClassificationType.ValueType  # 5810
    CLASSIFICATION_TYPE_SALE_OF_MALICIOUS_TOOLS_AND_SERVICES_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5815
    CLASSIFICATION_TYPE_SALE_OF_MALICIOUS_TOOLS_AND_SERVICES_NON_DEDICATED_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5816
    CLASSIFICATION_TYPE_FRAUD_SERVICES_LOW_RISK_ADMIN: UserData.ClassificationType.ValueType  # 5820
    CLASSIFICATION_TYPE_FRAUD_SERVICES_MEDIUM_RISK_ADMIN: UserData.ClassificationType.ValueType  # 5830
    CLASSIFICATION_TYPE_FRAUD_SERVICES_LOW_RISK_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5825
    CLASSIFICATION_TYPE_FRAUD_SERVICES_MEDIUM_RISK_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5835
    CLASSIFICATION_TYPE_FRAUD_SERVICES_LOW_RISK_NON_DEDICATED_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5826
    CLASSIFICATION_TYPE_FRAUD_SERVICES_MEDIUM_RISK_NON_DEDICATED_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5836
    CLASSIFICATION_TYPE_FRAUD_SERVICES_HIGH_RISK_ADMIN: UserData.ClassificationType.ValueType  # 5840
    CLASSIFICATION_TYPE_FRAUD_SERVICES_HIGH_RISK_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5845
    CLASSIFICATION_TYPE_DENIED_PARTY_SCREENING_ADMIN: UserData.ClassificationType.ValueType  # 5850
    CLASSIFICATION_TYPE_INAUTHENTIC_SERVER_MEDIUM_CONFIDENCE_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5865
    CLASSIFICATION_TYPE_FRAUDULENT_CHARGE_ADMIN: UserData.ClassificationType.ValueType  # 5870
    CLASSIFICATION_TYPE_HYBRIDIZED_HARM_COORDINATION_OR_FACILITATION_ADMIN: UserData.ClassificationType.ValueType  # 5880
    CLASSIFICATION_TYPE_HYBRIDIZED_HARM_COORDINATION_OR_FACILITATION_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 5885
    CLASSIFICATION_TYPE_PRESENCE_IN_HYBRIDIZED_HARM_COORDINATION_OR_FACILITATION_GUILD: UserData.ClassificationType.ValueType  # 5920
    CLASSIFICATION_TYPE_OWNER_OF_HYBRIDIZED_HARM_COORDINATION_OR_FACILITATION_GUILD: UserData.ClassificationType.ValueType  # 5930
    CLASSIFICATION_TYPE_UNAUTHORIZED_TRANSACTION_ADMIN: UserData.ClassificationType.ValueType  # 5890
    CLASSIFICATION_TYPE_EARLY_FRAUD_WARNING_LOW_RISK_ADMIN: UserData.ClassificationType.ValueType  # 5900
    CLASSIFICATION_TYPE_EARLY_FRAUD_WARNING_HIGH_RISK_ADMIN: UserData.ClassificationType.ValueType  # 5910
    CLASSIFICATION_TYPE_SPAM_CEILING_ADMIN: UserData.ClassificationType.ValueType  # 5940
    CLASSIFICATION_TYPE_HIGH_RISK_DANGEROUS_AND_REGULATED_GOODS_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7005
    CLASSIFICATION_TYPE_MEDIUM_RISK_DANGEROUS_AND_REGULATED_GOODS_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7015
    CLASSIFICATION_TYPE_LOW_RISK_DANGEROUS_AND_REGULATED_GOODS_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7025
    CLASSIFICATION_TYPE_ORGANIZING_OR_FACILITATING_ILLICIT_GAMBLING_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7035
    CLASSIFICATION_TYPE_INVESTMENT_AND_IDENTITY_SCAMS_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7045
    CLASSIFICATION_TYPE_FRAUD_SERVICES_AND_TOOLS_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7055
    CLASSIFICATION_TYPE_PLATFORM_BAN_EVASION_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7065
    CLASSIFICATION_TYPE_SALE_OR_PURCHASE_OF_DISCORD_ASSETS_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7075
    CLASSIFICATION_TYPE_SALE_OR_PURCHASE_OF_ARTIFICIAL_ENGAGEMENT_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7085
    CLASSIFICATION_TYPE_SERVER_THAT_HAS_ARTIFICIALLY_INFLATED_MEMBERS_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7095
    CLASSIFICATION_TYPE_SALE_OF_PLATFORM_ABUSE_TOOLS_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7105
    CLASSIFICATION_TYPE_CHILD_LED_SEXUAL_SELF_ENDANGERMENT_RETOOL: UserData.ClassificationType.ValueType  # 7110
    CLASSIFICATION_TYPE_CHILD_LED_VIGILANTISM_RETOOL: UserData.ClassificationType.ValueType  # 7120
    CLASSIFICATION_TYPE_CHILD_SEXUALIZATION_CONTENT_RETOOL: UserData.ClassificationType.ValueType  # 7130
    CLASSIFICATION_TYPE_CIVIC_DISRUPTION_MOBILIZATION_FOR_REAL_WORLD_INTERFERENCE_RETOOL: UserData.ClassificationType.ValueType  # 7140
    CLASSIFICATION_TYPE_CIVIC_MISINFORMATION_RETOOL: UserData.ClassificationType.ValueType  # 7150
    CLASSIFICATION_TYPE_COORDINATION_OR_CREDIBLE_ADMISSION_OF_REAL_WORLD_VIOLENCE_RETOOL: UserData.ClassificationType.ValueType  # 7160
    CLASSIFICATION_TYPE_CSAM_RETOOL: UserData.ClassificationType.ValueType  # 7170
    CLASSIFICATION_TYPE_DENIAL_OF_HUMAN_ATROCITY_RETOOL: UserData.ClassificationType.ValueType  # 7180
    CLASSIFICATION_TYPE_DRAWN_SEXUALIZED_CHILDREN_RETOOL: UserData.ClassificationType.ValueType  # 7190
    CLASSIFICATION_TYPE_CHILD_LED_SEXUAL_SELF_ENDANGERMENT_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7115
    CLASSIFICATION_TYPE_CHILD_LED_VIGILANTISM_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7125
    CLASSIFICATION_TYPE_CHILD_SEXUALIZATION_CONTENT_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7135
    CLASSIFICATION_TYPE_CIVIC_DISRUPTION_MOBILIZATION_FOR_REAL_WORLD_INTERFERENCE_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7145
    CLASSIFICATION_TYPE_CIVIC_MISINFORMATION_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7155
    CLASSIFICATION_TYPE_COORDINATION_OR_CREDIBLE_ADMISSION_OF_REAL_WORLD_VIOLENCE_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7165
    CLASSIFICATION_TYPE_CSAM_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7175
    CLASSIFICATION_TYPE_DENIAL_OF_HUMAN_ATROCITY_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7185
    CLASSIFICATION_TYPE_DRAWN_SEXUALIZED_CHILDREN_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7195
    CLASSIFICATION_TYPE_CHILD_LED_SEXUAL_SELF_ENDANGERMENT_NON_DEDICATED_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7116
    CLASSIFICATION_TYPE_CHILD_LED_VIGILANTISM_NON_DEDICATED_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7126
    CLASSIFICATION_TYPE_CHILD_SEXUALIZATION_CONTENT_NON_DEDICATED_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7136
    CLASSIFICATION_TYPE_CIVIC_DISRUPTION_MOBILIZATION_FOR_REAL_WORLD_INTERFERENCE_NON_DEDICATED_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7146
    CLASSIFICATION_TYPE_CIVIC_MISINFORMATION_NON_DEDICATED_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7156
    CLASSIFICATION_TYPE_COORDINATION_OR_CREDIBLE_ADMISSION_OF_REAL_WORLD_VIOLENCE_NON_DEDICATED_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7166
    CLASSIFICATION_TYPE_CSAM_NON_DEDICATED_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7176
    CLASSIFICATION_TYPE_DENIAL_OF_HUMAN_ATROCITY_NON_DEDICATED_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7186
    CLASSIFICATION_TYPE_DRAWN_SEXUALIZED_CHILDREN_NON_DEDICATED_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7196
    CLASSIFICATION_TYPE_HARASSMENT_AND_NON_IMMINENT_AND_OR_NON_PHYSICAL_THREATS_RETOOL: UserData.ClassificationType.ValueType  # 7200
    CLASSIFICATION_TYPE_HATE_SPEECH_AND_SYMBOLS_RETOOL: UserData.ClassificationType.ValueType  # 7210
    CLASSIFICATION_TYPE_IMMINENT_THREATS_OF_EXTORTION_RETOOL: UserData.ClassificationType.ValueType  # 7220
    CLASSIFICATION_TYPE_INAPPROPRIATE_SEXUAL_INTERACTIONS_WITH_MINORS_NON_GROOMING_RETOOL: UserData.ClassificationType.ValueType  # 7230
    CLASSIFICATION_TYPE_MALWARE_AND_MALICIOUS_CONDUCT_RETOOL: UserData.ClassificationType.ValueType  # 7240
    CLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_EXPLICIT_CONTENT_RETOOL: UserData.ClassificationType.ValueType  # 7250
    CLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_SUGGESTIVE_MEDIA_RETOOL: UserData.ClassificationType.ValueType  # 7260
    CLASSIFICATION_TYPE_NON_GATED_CHANNEL_DEDICATED_TO_AGE_RESTRICTED_CONTENT_RETOOL: UserData.ClassificationType.ValueType  # 7270
    CLASSIFICATION_TYPE_NON_GATED_SERVER_DEDICATED_TO_AGE_RESTRICTED_CONTENT_RETOOL: UserData.ClassificationType.ValueType  # 7280
    CLASSIFICATION_TYPE_OFF_PLATFORM_BEHAVIORS_RETOOL: UserData.ClassificationType.ValueType  # 7290
    CLASSIFICATION_TYPE_ORGANIZING_OR_FACILITATING_HUMAN_TRAFFICKING_RETOOL: UserData.ClassificationType.ValueType  # 7300
    CLASSIFICATION_TYPE_PLATFORM_BAN_EVASION_RETOOL: UserData.ClassificationType.ValueType  # 7060
    CLASSIFICATION_TYPE_PROMOTING_OR_PARTICIPATING_IN_REAL_WORLD_SEXUAL_SERVICES_RETOOL: UserData.ClassificationType.ValueType  # 7310
    CLASSIFICATION_TYPE_SALE_OF_MALICIOUS_TOOLS_AND_SERVICES_RETOOL: UserData.ClassificationType.ValueType  # 7320
    CLASSIFICATION_TYPE_SELF_GENERATED_CSAM_SG_CSAM_RETOOL: UserData.ClassificationType.ValueType  # 7330
    CLASSIFICATION_TYPE_SELF_HARM_PROMOTION_RETOOL: UserData.ClassificationType.ValueType  # 7340
    CLASSIFICATION_TYPE_SEXUAL_ASSAULT_VIOLENCE_MEDIA_RETOOL: UserData.ClassificationType.ValueType  # 7350
    CLASSIFICATION_TYPE_SEXUAL_DEEPFAKES_RETOOL: UserData.ClassificationType.ValueType  # 7360
    CLASSIFICATION_TYPE_SEXUAL_GROOMING_OF_A_CHILD_AND_CSAM_SOLICITATION_RETOOL: UserData.ClassificationType.ValueType  # 7370
    CLASSIFICATION_TYPE_SEXUALLY_EXPLICIT_CONTENT_WITH_IMPLICATIONS_FOR_REAL_WORLD_HARM_RETOOL: UserData.ClassificationType.ValueType  # 7380
    CLASSIFICATION_TYPE_SUICIDE_PROMOTION_RETOOL: UserData.ClassificationType.ValueType  # 7390
    CLASSIFICATION_TYPE_TRIBUTES_AND_LEAKED_ADULT_INTIMATE_MEDIA_RETOOL: UserData.ClassificationType.ValueType  # 7400
    CLASSIFICATION_TYPE_VIOLENCE_GLORIFICATION_PROMOTION_OR_INCITEMENT_RETOOL: UserData.ClassificationType.ValueType  # 7410
    CLASSIFICATION_TYPE_VIOLENT_EXTREMISM_ORGANIZING_RETOOL: UserData.ClassificationType.ValueType  # 7420
    CLASSIFICATION_TYPE_VIOLENT_EXTREMISM_SUPPORT_PROMOTION_OR_EMULATION_RETOOL: UserData.ClassificationType.ValueType  # 7430
    CLASSIFICATION_TYPE_VOYEURISTIC_MEDIA_RETOOL: UserData.ClassificationType.ValueType  # 7440
    CLASSIFICATION_TYPE_HARASSMENT_AND_NON_IMMINENT_AND_OR_NON_PHYSICAL_THREATS_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7205
    CLASSIFICATION_TYPE_HATE_SPEECH_AND_SYMBOLS_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7215
    CLASSIFICATION_TYPE_IMMINENT_THREATS_OF_EXTORTION_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7225
    CLASSIFICATION_TYPE_INAPPROPRIATE_SEXUAL_INTERACTIONS_WITH_MINORS_NON_GROOMING_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7235
    CLASSIFICATION_TYPE_MALWARE_AND_MALICIOUS_CONDUCT_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7245
    CLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_EXPLICIT_CONTENT_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7255
    CLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_SUGGESTIVE_MEDIA_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7265
    CLASSIFICATION_TYPE_NON_GATED_CHANNEL_DEDICATED_TO_AGE_RESTRICTED_CONTENT_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7275
    CLASSIFICATION_TYPE_NON_GATED_SERVER_DEDICATED_TO_AGE_RESTRICTED_CONTENT_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7285
    CLASSIFICATION_TYPE_OFF_PLATFORM_BEHAVIORS_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7295
    CLASSIFICATION_TYPE_ORGANIZING_OR_FACILITATING_HUMAN_TRAFFICKING_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7305
    CLASSIFICATION_TYPE_PROMOTING_OR_PARTICIPATING_IN_REAL_WORLD_SEXUAL_SERVICES_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7315
    CLASSIFICATION_TYPE_SALE_OF_MALICIOUS_TOOLS_AND_SERVICES_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7325
    CLASSIFICATION_TYPE_SELF_GENERATED_CSAM_SG_CSAM_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7335
    CLASSIFICATION_TYPE_SELF_HARM_PROMOTION_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7345
    CLASSIFICATION_TYPE_SEXUAL_ASSAULT_VIOLENCE_MEDIA_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7355
    CLASSIFICATION_TYPE_SEXUAL_DEEPFAKES_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7365
    CLASSIFICATION_TYPE_SEXUAL_GROOMING_OF_A_CHILD_AND_CSAM_SOLICITATION_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7375
    CLASSIFICATION_TYPE_SEXUALLY_EXPLICIT_CONTENT_WITH_IMPLICATIONS_FOR_REAL_WORLD_HARM_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7385
    CLASSIFICATION_TYPE_SUICIDE_PROMOTION_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7395
    CLASSIFICATION_TYPE_TRIBUTES_AND_LEAKED_ADULT_INTIMATE_MEDIA_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7405
    CLASSIFICATION_TYPE_VIOLENCE_GLORIFICATION_PROMOTION_OR_INCITEMENT_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7415
    CLASSIFICATION_TYPE_VIOLENT_EXTREMISM_ORGANIZING_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7425
    CLASSIFICATION_TYPE_VIOLENT_EXTREMISM_SUPPORT_PROMOTION_OR_EMULATION_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7435
    CLASSIFICATION_TYPE_VOYEURISTIC_MEDIA_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7445
    CLASSIFICATION_TYPE_HARASSMENT_AND_NON_IMMINENT_AND_OR_NON_PHYSICAL_THREATS_NON_DEDICATED_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7206
    CLASSIFICATION_TYPE_HATE_SPEECH_AND_SYMBOLS_NON_DEDICATED_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7216
    CLASSIFICATION_TYPE_IMMINENT_THREATS_OF_EXTORTION_NON_DEDICATED_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7226
    CLASSIFICATION_TYPE_INAPPROPRIATE_SEXUAL_INTERACTIONS_WITH_MINORS_NON_GROOMING_NON_DEDICATED_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7236
    CLASSIFICATION_TYPE_MALWARE_AND_MALICIOUS_CONDUCT_NON_DEDICATED_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7246
    CLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_EXPLICIT_CONTENT_NON_DEDICATED_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7256
    CLASSIFICATION_TYPE_NON_CONSENSUAL_SEXUALLY_SUGGESTIVE_MEDIA_NON_DEDICATED_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7266
    CLASSIFICATION_TYPE_NON_GATED_CHANNEL_DEDICATED_TO_AGE_RESTRICTED_CONTENT_NON_DEDICATED_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7276
    CLASSIFICATION_TYPE_NON_GATED_SERVER_DEDICATED_TO_AGE_RESTRICTED_CONTENT_NON_DEDICATED_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7286
    CLASSIFICATION_TYPE_OFF_PLATFORM_BEHAVIORS_NON_DEDICATED_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7296
    CLASSIFICATION_TYPE_ORGANIZING_OR_FACILITATING_HUMAN_TRAFFICKING_NON_DEDICATED_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7306
    CLASSIFICATION_TYPE_PLATFORM_BAN_EVASION_NON_DEDICATED_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7066
    CLASSIFICATION_TYPE_PROMOTING_OR_PARTICIPATING_IN_REAL_WORLD_SEXUAL_SERVICES_NON_DEDICATED_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7316
    CLASSIFICATION_TYPE_SALE_OF_MALICIOUS_TOOLS_AND_SERVICES_NON_DEDICATED_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7326
    CLASSIFICATION_TYPE_SELF_GENERATED_CSAM_SG_CSAM_NON_DEDICATED_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7336
    CLASSIFICATION_TYPE_SELF_HARM_PROMOTION_NON_DEDICATED_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7346
    CLASSIFICATION_TYPE_SEXUAL_ASSAULT_VIOLENCE_MEDIA_NON_DEDICATED_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7356
    CLASSIFICATION_TYPE_SEXUAL_DEEPFAKES_NON_DEDICATED_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7366
    CLASSIFICATION_TYPE_SEXUAL_GROOMING_OF_A_CHILD_AND_CSAM_SOLICITATION_NON_DEDICATED_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7376
    CLASSIFICATION_TYPE_SEXUALLY_EXPLICIT_CONTENT_WITH_IMPLICATIONS_FOR_REAL_WORLD_HARM_NON_DEDICATED_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7386
    CLASSIFICATION_TYPE_SUICIDE_PROMOTION_NON_DEDICATED_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7396
    CLASSIFICATION_TYPE_TRIBUTES_AND_LEAKED_ADULT_INTIMATE_MEDIA_NON_DEDICATED_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7406
    CLASSIFICATION_TYPE_VIOLENCE_GLORIFICATION_PROMOTION_OR_INCITEMENT_NON_DEDICATED_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7416
    CLASSIFICATION_TYPE_VIOLENT_EXTREMISM_ORGANIZING_NON_DEDICATED_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7426
    CLASSIFICATION_TYPE_VIOLENT_EXTREMISM_SUPPORT_PROMOTION_OR_EMULATION_NON_DEDICATED_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7436
    CLASSIFICATION_TYPE_VOYEURISTIC_MEDIA_NON_DEDICATED_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7446
    CLASSIFICATION_TYPE_FRAUD_SERVICES_LOW_RISK_RETOOL: UserData.ClassificationType.ValueType  # 7450
    CLASSIFICATION_TYPE_FRAUD_SERVICES_MEDIUM_RISK_RETOOL: UserData.ClassificationType.ValueType  # 7460
    CLASSIFICATION_TYPE_FRAUD_SERVICES_LOW_RISK_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7455
    CLASSIFICATION_TYPE_FRAUD_SERVICES_MEDIUM_RISK_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7465
    CLASSIFICATION_TYPE_FRAUD_SERVICES_LOW_RISK_NON_DEDICATED_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7456
    CLASSIFICATION_TYPE_FRAUD_SERVICES_MEDIUM_RISK_NON_DEDICATED_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7466
    CLASSIFICATION_TYPE_FRAUD_SERVICES_HIGH_RISK_RETOOL: UserData.ClassificationType.ValueType  # 7470
    CLASSIFICATION_TYPE_FRAUD_SERVICES_HIGH_RISK_GUILD_RETOOL: UserData.ClassificationType.ValueType  # 7475
    CLASSIFICATION_TYPE_NON_CONSENSUAL_ADULT_INTIMATE_MEDIA_TAKEDOWN_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 7480
    CLASSIFICATION_TYPE_NON_CONSENSUAL_ADULT_INTIMATE_MEDIA_TAKEDOWN_NON_DEDICATED_GUILD_SAFETY_DISPATCH: UserData.ClassificationType.ValueType  # 7486
    CLASSIFICATION_TYPE_NON_CONSENSUAL_ADULT_INTIMATE_MEDIA_TAKEDOWN_ADMIN: UserData.ClassificationType.ValueType  # 7490
    CLASSIFICATION_TYPE_NON_CONSENSUAL_ADULT_INTIMATE_MEDIA_TAKEDOWN_NON_DEDICATED_GUILD_ADMIN: UserData.ClassificationType.ValueType  # 7496
    CLASSIFICATION_TYPE_NON_CONSENSUAL_ADULT_INTIMATE_MEDIA_TAKEDOWN_HASH_MATCH: UserData.ClassificationType.ValueType  # 7500
    CLASSIFICATION_TYPE_TEST_CLASSIFICATION: UserData.ClassificationType.ValueType  # 9000
    CLASSIFICATION_TYPE_TEST_CLASSIFICATION_LOW: UserData.ClassificationType.ValueType  # 9001
    CLASSIFICATION_TYPE_TEST_CLASSIFICATION_SEVERE: UserData.ClassificationType.ValueType  # 9002
    CLASSIFICATION_TYPE_TEST_GUILD_CLASSIFICATION: UserData.ClassificationType.ValueType  # 9100
    CLASSIFICATION_TYPE_TEST_GUILD_CLASSIFICATION_LOW: UserData.ClassificationType.ValueType  # 9101
    CLASSIFICATION_TYPE_TEST_GUILD_CLASSIFICATION_SEVERE: UserData.ClassificationType.ValueType  # 9102
    CLASSIFICATION_TYPE_TEST_PROVISIONAL_ACCOUNT_CLASSIFICATION: UserData.ClassificationType.ValueType  # 9200

    class _SafetyStateReason:
        ValueType = _typing.NewType("ValueType", _builtins.int)
        V: _TypeAlias = ValueType  # noqa: Y015

    class _SafetyStateReasonEnumTypeWrapper(_enum_type_wrapper._EnumTypeWrapper[UserData._SafetyStateReason.ValueType], _builtins.type):
        DESCRIPTOR: _descriptor.EnumDescriptor
        SAFETY_STATE_REASON_REASON_UNSPECIFIED: UserData._SafetyStateReason.ValueType  # 0
        SAFETY_STATE_REASON_DISABLED_SUSPICIOUS_ACTIVITY: UserData._SafetyStateReason.ValueType  # 1
        SAFETY_STATE_REASON_SMITE_REMOVE_EMAIL_VERIFICATION: UserData._SafetyStateReason.ValueType  # 2
        SAFETY_STATE_REASON_USER_REQUIRED_VERIFICATION_INTERVENTIONS_CLIENT: UserData._SafetyStateReason.ValueType  # 3
        SAFETY_STATE_REASON_ACTIVE_ASSIGNMENT_COMPLETED: UserData._SafetyStateReason.ValueType  # 4
        SAFETY_STATE_REASON_ACTIVE_ASSIGNMENT_CREATED: UserData._SafetyStateReason.ValueType  # 5
        SAFETY_STATE_REASON_DEFERRED_ASSIGNMENT_CREATED: UserData._SafetyStateReason.ValueType  # 6
        SAFETY_STATE_REASON_DEFERRED_ASSIGNMENT_UPGRADED_TO_ACTIVE: UserData._SafetyStateReason.ValueType  # 7
        SAFETY_STATE_REASON_DEFERRED_ASSIGNMENT_CANCELLED: UserData._SafetyStateReason.ValueType  # 8
        SAFETY_STATE_REASON_ASSIGNMENT_STATE_REPAIRED: UserData._SafetyStateReason.ValueType  # 9
        SAFETY_STATE_REASON_MANUAL_PERMANENT_BAN: UserData._SafetyStateReason.ValueType  # 10
        SAFETY_STATE_REASON_SAFETY_SYSTEM_UNBAN: UserData._SafetyStateReason.ValueType  # 11
        SAFETY_STATE_REASON_GENERIC_AUTOMATED_SAFETY_ACTION: UserData._SafetyStateReason.ValueType  # 12
        SAFETY_STATE_REASON_GENERIC_MANUAL_SAFETY_ACTION: UserData._SafetyStateReason.ValueType  # 13
        SAFETY_STATE_REASON_BANNED_USER_BACKFILL: UserData._SafetyStateReason.ValueType  # 14

    class SafetyStateReason(_SafetyStateReason, metaclass=_SafetyStateReasonEnumTypeWrapper): ...
    SAFETY_STATE_REASON_REASON_UNSPECIFIED: UserData.SafetyStateReason.ValueType  # 0
    SAFETY_STATE_REASON_DISABLED_SUSPICIOUS_ACTIVITY: UserData.SafetyStateReason.ValueType  # 1
    SAFETY_STATE_REASON_SMITE_REMOVE_EMAIL_VERIFICATION: UserData.SafetyStateReason.ValueType  # 2
    SAFETY_STATE_REASON_USER_REQUIRED_VERIFICATION_INTERVENTIONS_CLIENT: UserData.SafetyStateReason.ValueType  # 3
    SAFETY_STATE_REASON_ACTIVE_ASSIGNMENT_COMPLETED: UserData.SafetyStateReason.ValueType  # 4
    SAFETY_STATE_REASON_ACTIVE_ASSIGNMENT_CREATED: UserData.SafetyStateReason.ValueType  # 5
    SAFETY_STATE_REASON_DEFERRED_ASSIGNMENT_CREATED: UserData.SafetyStateReason.ValueType  # 6
    SAFETY_STATE_REASON_DEFERRED_ASSIGNMENT_UPGRADED_TO_ACTIVE: UserData.SafetyStateReason.ValueType  # 7
    SAFETY_STATE_REASON_DEFERRED_ASSIGNMENT_CANCELLED: UserData.SafetyStateReason.ValueType  # 8
    SAFETY_STATE_REASON_ASSIGNMENT_STATE_REPAIRED: UserData.SafetyStateReason.ValueType  # 9
    SAFETY_STATE_REASON_MANUAL_PERMANENT_BAN: UserData.SafetyStateReason.ValueType  # 10
    SAFETY_STATE_REASON_SAFETY_SYSTEM_UNBAN: UserData.SafetyStateReason.ValueType  # 11
    SAFETY_STATE_REASON_GENERIC_AUTOMATED_SAFETY_ACTION: UserData.SafetyStateReason.ValueType  # 12
    SAFETY_STATE_REASON_GENERIC_MANUAL_SAFETY_ACTION: UserData.SafetyStateReason.ValueType  # 13
    SAFETY_STATE_REASON_BANNED_USER_BACKFILL: UserData.SafetyStateReason.ValueType  # 14

    class _SafetyAnnotations:
        ValueType = _typing.NewType("ValueType", _builtins.int)
        V: _TypeAlias = ValueType  # noqa: Y015

    class _SafetyAnnotationsEnumTypeWrapper(_enum_type_wrapper._EnumTypeWrapper[UserData._SafetyAnnotations.ValueType], _builtins.type):
        DESCRIPTOR: _descriptor.EnumDescriptor
        SAFETY_ANNOTATIONS_ANNOTATION_UNSPECIFIED: UserData._SafetyAnnotations.ValueType  # 0
        SAFETY_ANNOTATIONS_SPAMMER: UserData._SafetyAnnotations.ValueType  # 1
        SAFETY_ANNOTATIONS_SELF_DELETED: UserData._SafetyAnnotations.ValueType  # 2
        SAFETY_ANNOTATIONS_SELF_DISABLED: UserData._SafetyAnnotations.ValueType  # 3
        SAFETY_ANNOTATIONS_UNDERAGE_DELETED: UserData._SafetyAnnotations.ValueType  # 4
        SAFETY_ANNOTATIONS_SAFETY_POLICY_VIOLATION: UserData._SafetyAnnotations.ValueType  # 5
        SAFETY_ANNOTATIONS_INACTIVITY_DELETED: UserData._SafetyAnnotations.ValueType  # 6
        SAFETY_ANNOTATIONS_GENERIC_DELETED: UserData._SafetyAnnotations.ValueType  # 7

    class SafetyAnnotations(_SafetyAnnotations, metaclass=_SafetyAnnotationsEnumTypeWrapper): ...
    SAFETY_ANNOTATIONS_ANNOTATION_UNSPECIFIED: UserData.SafetyAnnotations.ValueType  # 0
    SAFETY_ANNOTATIONS_SPAMMER: UserData.SafetyAnnotations.ValueType  # 1
    SAFETY_ANNOTATIONS_SELF_DELETED: UserData.SafetyAnnotations.ValueType  # 2
    SAFETY_ANNOTATIONS_SELF_DISABLED: UserData.SafetyAnnotations.ValueType  # 3
    SAFETY_ANNOTATIONS_UNDERAGE_DELETED: UserData.SafetyAnnotations.ValueType  # 4
    SAFETY_ANNOTATIONS_SAFETY_POLICY_VIOLATION: UserData.SafetyAnnotations.ValueType  # 5
    SAFETY_ANNOTATIONS_INACTIVITY_DELETED: UserData.SafetyAnnotations.ValueType  # 6
    SAFETY_ANNOTATIONS_GENERIC_DELETED: UserData.SafetyAnnotations.ValueType  # 7

    class _PremiumSource:
        ValueType = _typing.NewType("ValueType", _builtins.int)
        V: _TypeAlias = ValueType  # noqa: Y015

    class _PremiumSourceEnumTypeWrapper(_enum_type_wrapper._EnumTypeWrapper[UserData._PremiumSource.ValueType], _builtins.type):
        DESCRIPTOR: _descriptor.EnumDescriptor
        PREMIUM_SOURCE_NONE_UNSPECIFIED: UserData._PremiumSource.ValueType  # 0
        PREMIUM_SOURCE_SUBSCRIPTION: UserData._PremiumSource.ValueType  # 1
        PREMIUM_SOURCE_FRACTIONAL_NITRO: UserData._PremiumSource.ValueType  # 2
        PREMIUM_SOURCE_REVERSE_TRIAL: UserData._PremiumSource.ValueType  # 3
        PREMIUM_SOURCE_SUBSCRIPTION_GROUP: UserData._PremiumSource.ValueType  # 4

    class PremiumSource(_PremiumSource, metaclass=_PremiumSourceEnumTypeWrapper): ...
    PREMIUM_SOURCE_NONE_UNSPECIFIED: UserData.PremiumSource.ValueType  # 0
    PREMIUM_SOURCE_SUBSCRIPTION: UserData.PremiumSource.ValueType  # 1
    PREMIUM_SOURCE_FRACTIONAL_NITRO: UserData.PremiumSource.ValueType  # 2
    PREMIUM_SOURCE_REVERSE_TRIAL: UserData.PremiumSource.ValueType  # 3
    PREMIUM_SOURCE_SUBSCRIPTION_GROUP: UserData.PremiumSource.ValueType  # 4

    class _PremiumSubscriptionType:
        ValueType = _typing.NewType("ValueType", _builtins.int)
        V: _TypeAlias = ValueType  # noqa: Y015

    class _PremiumSubscriptionTypeEnumTypeWrapper(_enum_type_wrapper._EnumTypeWrapper[UserData._PremiumSubscriptionType.ValueType], _builtins.type):
        DESCRIPTOR: _descriptor.EnumDescriptor
        PREMIUM_SUBSCRIPTION_TYPE_NONE_UNSPECIFIED: UserData._PremiumSubscriptionType.ValueType  # 0
        PREMIUM_SUBSCRIPTION_TYPE_BOOST_ONLY: UserData._PremiumSubscriptionType.ValueType  # 1
        PREMIUM_SUBSCRIPTION_TYPE_TIER_0: UserData._PremiumSubscriptionType.ValueType  # 2
        PREMIUM_SUBSCRIPTION_TYPE_TIER_1: UserData._PremiumSubscriptionType.ValueType  # 3
        PREMIUM_SUBSCRIPTION_TYPE_TIER_2: UserData._PremiumSubscriptionType.ValueType  # 4

    class PremiumSubscriptionType(_PremiumSubscriptionType, metaclass=_PremiumSubscriptionTypeEnumTypeWrapper): ...
    PREMIUM_SUBSCRIPTION_TYPE_NONE_UNSPECIFIED: UserData.PremiumSubscriptionType.ValueType  # 0
    PREMIUM_SUBSCRIPTION_TYPE_BOOST_ONLY: UserData.PremiumSubscriptionType.ValueType  # 1
    PREMIUM_SUBSCRIPTION_TYPE_TIER_0: UserData.PremiumSubscriptionType.ValueType  # 2
    PREMIUM_SUBSCRIPTION_TYPE_TIER_1: UserData.PremiumSubscriptionType.ValueType  # 3
    PREMIUM_SUBSCRIPTION_TYPE_TIER_2: UserData.PremiumSubscriptionType.ValueType  # 4

    class _PremiumSubscriptionGroupRole:
        ValueType = _typing.NewType("ValueType", _builtins.int)
        V: _TypeAlias = ValueType  # noqa: Y015

    class _PremiumSubscriptionGroupRoleEnumTypeWrapper(_enum_type_wrapper._EnumTypeWrapper[UserData._PremiumSubscriptionGroupRole.ValueType], _builtins.type):
        DESCRIPTOR: _descriptor.EnumDescriptor
        PREMIUM_SUBSCRIPTION_GROUP_ROLE_UNSPECIFIED: UserData._PremiumSubscriptionGroupRole.ValueType  # 0
        PREMIUM_SUBSCRIPTION_GROUP_ROLE_PRIMARY: UserData._PremiumSubscriptionGroupRole.ValueType  # 1
        PREMIUM_SUBSCRIPTION_GROUP_ROLE_MEMBER: UserData._PremiumSubscriptionGroupRole.ValueType  # 2

    class PremiumSubscriptionGroupRole(_PremiumSubscriptionGroupRole, metaclass=_PremiumSubscriptionGroupRoleEnumTypeWrapper): ...
    PREMIUM_SUBSCRIPTION_GROUP_ROLE_UNSPECIFIED: UserData.PremiumSubscriptionGroupRole.ValueType  # 0
    PREMIUM_SUBSCRIPTION_GROUP_ROLE_PRIMARY: UserData.PremiumSubscriptionGroupRole.ValueType  # 1
    PREMIUM_SUBSCRIPTION_GROUP_ROLE_MEMBER: UserData.PremiumSubscriptionGroupRole.ValueType  # 2

    class _DisplayNameFont:
        ValueType = _typing.NewType("ValueType", _builtins.int)
        V: _TypeAlias = ValueType  # noqa: Y015

    class _DisplayNameFontEnumTypeWrapper(_enum_type_wrapper._EnumTypeWrapper[UserData._DisplayNameFont.ValueType], _builtins.type):
        DESCRIPTOR: _descriptor.EnumDescriptor
        DISPLAY_NAME_FONT_UNSPECIFIED: UserData._DisplayNameFont.ValueType  # 0
        DISPLAY_NAME_FONT_DEFAULT: UserData._DisplayNameFont.ValueType  # 11
        DISPLAY_NAME_FONT_BANGERS: UserData._DisplayNameFont.ValueType  # 1
        DISPLAY_NAME_FONT_BIO_RHYME: UserData._DisplayNameFont.ValueType  # 2
        DISPLAY_NAME_FONT_CHERRY_BOMB: UserData._DisplayNameFont.ValueType  # 3
        DISPLAY_NAME_FONT_CHICLE: UserData._DisplayNameFont.ValueType  # 4
        DISPLAY_NAME_FONT_COMPAGNON: UserData._DisplayNameFont.ValueType  # 5
        DISPLAY_NAME_FONT_MUSEO_MODERNO: UserData._DisplayNameFont.ValueType  # 6
        DISPLAY_NAME_FONT_NEO_CASTEL: UserData._DisplayNameFont.ValueType  # 7
        DISPLAY_NAME_FONT_PIXELIFY: UserData._DisplayNameFont.ValueType  # 8
        DISPLAY_NAME_FONT_RIBES: UserData._DisplayNameFont.ValueType  # 9
        DISPLAY_NAME_FONT_SINISTRE: UserData._DisplayNameFont.ValueType  # 10
        DISPLAY_NAME_FONT_ZILLA_SLAB: UserData._DisplayNameFont.ValueType  # 12

    class DisplayNameFont(_DisplayNameFont, metaclass=_DisplayNameFontEnumTypeWrapper): ...
    DISPLAY_NAME_FONT_UNSPECIFIED: UserData.DisplayNameFont.ValueType  # 0
    DISPLAY_NAME_FONT_DEFAULT: UserData.DisplayNameFont.ValueType  # 11
    DISPLAY_NAME_FONT_BANGERS: UserData.DisplayNameFont.ValueType  # 1
    DISPLAY_NAME_FONT_BIO_RHYME: UserData.DisplayNameFont.ValueType  # 2
    DISPLAY_NAME_FONT_CHERRY_BOMB: UserData.DisplayNameFont.ValueType  # 3
    DISPLAY_NAME_FONT_CHICLE: UserData.DisplayNameFont.ValueType  # 4
    DISPLAY_NAME_FONT_COMPAGNON: UserData.DisplayNameFont.ValueType  # 5
    DISPLAY_NAME_FONT_MUSEO_MODERNO: UserData.DisplayNameFont.ValueType  # 6
    DISPLAY_NAME_FONT_NEO_CASTEL: UserData.DisplayNameFont.ValueType  # 7
    DISPLAY_NAME_FONT_PIXELIFY: UserData.DisplayNameFont.ValueType  # 8
    DISPLAY_NAME_FONT_RIBES: UserData.DisplayNameFont.ValueType  # 9
    DISPLAY_NAME_FONT_SINISTRE: UserData.DisplayNameFont.ValueType  # 10
    DISPLAY_NAME_FONT_ZILLA_SLAB: UserData.DisplayNameFont.ValueType  # 12

    class _DisplayNameEffect:
        ValueType = _typing.NewType("ValueType", _builtins.int)
        V: _TypeAlias = ValueType  # noqa: Y015

    class _DisplayNameEffectEnumTypeWrapper(_enum_type_wrapper._EnumTypeWrapper[UserData._DisplayNameEffect.ValueType], _builtins.type):
        DESCRIPTOR: _descriptor.EnumDescriptor
        DISPLAY_NAME_EFFECT_UNSPECIFIED: UserData._DisplayNameEffect.ValueType  # 0
        DISPLAY_NAME_EFFECT_SOLID: UserData._DisplayNameEffect.ValueType  # 1
        DISPLAY_NAME_EFFECT_GRADIENT: UserData._DisplayNameEffect.ValueType  # 2
        DISPLAY_NAME_EFFECT_NEON: UserData._DisplayNameEffect.ValueType  # 3
        DISPLAY_NAME_EFFECT_TOON: UserData._DisplayNameEffect.ValueType  # 4
        DISPLAY_NAME_EFFECT_POP: UserData._DisplayNameEffect.ValueType  # 5
        DISPLAY_NAME_EFFECT_GLOW: UserData._DisplayNameEffect.ValueType  # 6

    class DisplayNameEffect(_DisplayNameEffect, metaclass=_DisplayNameEffectEnumTypeWrapper): ...
    DISPLAY_NAME_EFFECT_UNSPECIFIED: UserData.DisplayNameEffect.ValueType  # 0
    DISPLAY_NAME_EFFECT_SOLID: UserData.DisplayNameEffect.ValueType  # 1
    DISPLAY_NAME_EFFECT_GRADIENT: UserData.DisplayNameEffect.ValueType  # 2
    DISPLAY_NAME_EFFECT_NEON: UserData.DisplayNameEffect.ValueType  # 3
    DISPLAY_NAME_EFFECT_TOON: UserData.DisplayNameEffect.ValueType  # 4
    DISPLAY_NAME_EFFECT_POP: UserData.DisplayNameEffect.ValueType  # 5
    DISPLAY_NAME_EFFECT_GLOW: UserData.DisplayNameEffect.ValueType  # 6

    class _DayOfWeek:
        ValueType = _typing.NewType("ValueType", _builtins.int)
        V: _TypeAlias = ValueType  # noqa: Y015

    class _DayOfWeekEnumTypeWrapper(_enum_type_wrapper._EnumTypeWrapper[UserData._DayOfWeek.ValueType], _builtins.type):
        DESCRIPTOR: _descriptor.EnumDescriptor
        DAY_OF_WEEK_UNSPECIFIED: UserData._DayOfWeek.ValueType  # 0
        DAY_OF_WEEK_MONDAY: UserData._DayOfWeek.ValueType  # 1
        DAY_OF_WEEK_TUESDAY: UserData._DayOfWeek.ValueType  # 2
        DAY_OF_WEEK_WEDNESDAY: UserData._DayOfWeek.ValueType  # 3
        DAY_OF_WEEK_THURSDAY: UserData._DayOfWeek.ValueType  # 4
        DAY_OF_WEEK_FRIDAY: UserData._DayOfWeek.ValueType  # 5
        DAY_OF_WEEK_SATURDAY: UserData._DayOfWeek.ValueType  # 6
        DAY_OF_WEEK_SUNDAY: UserData._DayOfWeek.ValueType  # 7

    class DayOfWeek(_DayOfWeek, metaclass=_DayOfWeekEnumTypeWrapper): ...
    DAY_OF_WEEK_UNSPECIFIED: UserData.DayOfWeek.ValueType  # 0
    DAY_OF_WEEK_MONDAY: UserData.DayOfWeek.ValueType  # 1
    DAY_OF_WEEK_TUESDAY: UserData.DayOfWeek.ValueType  # 2
    DAY_OF_WEEK_WEDNESDAY: UserData.DayOfWeek.ValueType  # 3
    DAY_OF_WEEK_THURSDAY: UserData.DayOfWeek.ValueType  # 4
    DAY_OF_WEEK_FRIDAY: UserData.DayOfWeek.ValueType  # 5
    DAY_OF_WEEK_SATURDAY: UserData.DayOfWeek.ValueType  # 6
    DAY_OF_WEEK_SUNDAY: UserData.DayOfWeek.ValueType  # 7

    class _AgeAssuranceMethod:
        ValueType = _typing.NewType("ValueType", _builtins.int)
        V: _TypeAlias = ValueType  # noqa: Y015

    class _AgeAssuranceMethodEnumTypeWrapper(_enum_type_wrapper._EnumTypeWrapper[UserData._AgeAssuranceMethod.ValueType], _builtins.type):
        DESCRIPTOR: _descriptor.EnumDescriptor
        AGE_ASSURANCE_METHOD_UNSPECIFIED: UserData._AgeAssuranceMethod.ValueType  # 0
        AGE_ASSURANCE_METHOD_ID_SELFIE_MATCH: UserData._AgeAssuranceMethod.ValueType  # 1
        AGE_ASSURANCE_METHOD_ID_SCAN: UserData._AgeAssuranceMethod.ValueType  # 2
        AGE_ASSURANCE_METHOD_FACIAL_AGE_ESTIMATION: UserData._AgeAssuranceMethod.ValueType  # 3
        AGE_ASSURANCE_METHOD_BEHAVIORAL_INFERENCE: UserData._AgeAssuranceMethod.ValueType  # 4
        AGE_ASSURANCE_METHOD_CREDIT_CARD: UserData._AgeAssuranceMethod.ValueType  # 5
        AGE_ASSURANCE_METHOD_EMAIL_DOMAIN: UserData._AgeAssuranceMethod.ValueType  # 6
        AGE_ASSURANCE_METHOD_OS_SIGNAL: UserData._AgeAssuranceMethod.ValueType  # 7
        AGE_ASSURANCE_METHOD_ML_AGE_INFERENCE: UserData._AgeAssuranceMethod.ValueType  # 8

    class AgeAssuranceMethod(_AgeAssuranceMethod, metaclass=_AgeAssuranceMethodEnumTypeWrapper): ...
    AGE_ASSURANCE_METHOD_UNSPECIFIED: UserData.AgeAssuranceMethod.ValueType  # 0
    AGE_ASSURANCE_METHOD_ID_SELFIE_MATCH: UserData.AgeAssuranceMethod.ValueType  # 1
    AGE_ASSURANCE_METHOD_ID_SCAN: UserData.AgeAssuranceMethod.ValueType  # 2
    AGE_ASSURANCE_METHOD_FACIAL_AGE_ESTIMATION: UserData.AgeAssuranceMethod.ValueType  # 3
    AGE_ASSURANCE_METHOD_BEHAVIORAL_INFERENCE: UserData.AgeAssuranceMethod.ValueType  # 4
    AGE_ASSURANCE_METHOD_CREDIT_CARD: UserData.AgeAssuranceMethod.ValueType  # 5
    AGE_ASSURANCE_METHOD_EMAIL_DOMAIN: UserData.AgeAssuranceMethod.ValueType  # 6
    AGE_ASSURANCE_METHOD_OS_SIGNAL: UserData.AgeAssuranceMethod.ValueType  # 7
    AGE_ASSURANCE_METHOD_ML_AGE_INFERENCE: UserData.AgeAssuranceMethod.ValueType  # 8

    class _AgeAssuranceVendor:
        ValueType = _typing.NewType("ValueType", _builtins.int)
        V: _TypeAlias = ValueType  # noqa: Y015

    class _AgeAssuranceVendorEnumTypeWrapper(_enum_type_wrapper._EnumTypeWrapper[UserData._AgeAssuranceVendor.ValueType], _builtins.type):
        DESCRIPTOR: _descriptor.EnumDescriptor
        AGE_ASSURANCE_VENDOR_UNSPECIFIED: UserData._AgeAssuranceVendor.ValueType  # 0
        AGE_ASSURANCE_VENDOR_K_ID: UserData._AgeAssuranceVendor.ValueType  # 1
        AGE_ASSURANCE_VENDOR_PERSONA: UserData._AgeAssuranceVendor.ValueType  # 2
        AGE_ASSURANCE_VENDOR_INCODE: UserData._AgeAssuranceVendor.ValueType  # 3
        AGE_ASSURANCE_VENDOR_DISCORD: UserData._AgeAssuranceVendor.ValueType  # 4

    class AgeAssuranceVendor(_AgeAssuranceVendor, metaclass=_AgeAssuranceVendorEnumTypeWrapper): ...
    AGE_ASSURANCE_VENDOR_UNSPECIFIED: UserData.AgeAssuranceVendor.ValueType  # 0
    AGE_ASSURANCE_VENDOR_K_ID: UserData.AgeAssuranceVendor.ValueType  # 1
    AGE_ASSURANCE_VENDOR_PERSONA: UserData.AgeAssuranceVendor.ValueType  # 2
    AGE_ASSURANCE_VENDOR_INCODE: UserData.AgeAssuranceVendor.ValueType  # 3
    AGE_ASSURANCE_VENDOR_DISCORD: UserData.AgeAssuranceVendor.ValueType  # 4

    class _PerkSource:
        ValueType = _typing.NewType("ValueType", _builtins.int)
        V: _TypeAlias = ValueType  # noqa: Y015

    class _PerkSourceEnumTypeWrapper(_enum_type_wrapper._EnumTypeWrapper[UserData._PerkSource.ValueType], _builtins.type):
        DESCRIPTOR: _descriptor.EnumDescriptor
        PERK_SOURCE_SOURCE_UNSPECIFIED: UserData._PerkSource.ValueType  # 0
        PERK_SOURCE_SOURCE_NITRO: UserData._PerkSource.ValueType  # 1
        PERK_SOURCE_SOURCE_THIRDPARTY_CROISSANT: UserData._PerkSource.ValueType  # 2

    class PerkSource(_PerkSource, metaclass=_PerkSourceEnumTypeWrapper): ...
    PERK_SOURCE_SOURCE_UNSPECIFIED: UserData.PerkSource.ValueType  # 0
    PERK_SOURCE_SOURCE_NITRO: UserData.PerkSource.ValueType  # 1
    PERK_SOURCE_SOURCE_THIRDPARTY_CROISSANT: UserData.PerkSource.ValueType  # 2

    @_typing.final
    class LinkedUser(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        USER_ID_FIELD_NUMBER: _builtins.int
        LINK_TYPE_FIELD_NUMBER: _builtins.int
        LINK_STATUS_FIELD_NUMBER: _builtins.int
        REQUESTOR_ID_FIELD_NUMBER: _builtins.int
        CREATED_AT_FIELD_NUMBER: _builtins.int
        UPDATED_AT_FIELD_NUMBER: _builtins.int
        user_id: _builtins.int
        link_type: Global___UserData.UserLinkType.ValueType
        link_status: Global___UserData.UserLinkStatus.ValueType
        requestor_id: _builtins.int
        @_builtins.property
        def created_at(self) -> _timestamp_pb2.Timestamp: ...
        @_builtins.property
        def updated_at(self) -> _timestamp_pb2.Timestamp: ...
        def __init__(
            self,
            *,
            user_id: _builtins.int = ...,
            link_type: Global___UserData.UserLinkType.ValueType = ...,
            link_status: Global___UserData.UserLinkStatus.ValueType = ...,
            requestor_id: _builtins.int = ...,
            created_at: _timestamp_pb2.Timestamp | None = ...,
            updated_at: _timestamp_pb2.Timestamp | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_created_at", b"_created_at", "_updated_at", b"_updated_at", "created_at", b"created_at", "updated_at", b"updated_at"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_created_at", b"_created_at", "_updated_at", b"_updated_at", "created_at", b"created_at", "link_status", b"link_status", "link_type", b"link_type", "requestor_id", b"requestor_id", "updated_at", b"updated_at", "user_id", b"user_id"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__created_at: _TypeAlias = _typing.Literal["created_at"]  # noqa: Y015
        _WhichOneofArgType__created_at: _TypeAlias = _typing.Literal["_created_at", b"_created_at"]  # noqa: Y015
        _WhichOneofReturnType__updated_at: _TypeAlias = _typing.Literal["updated_at"]  # noqa: Y015
        _WhichOneofArgType__updated_at: _TypeAlias = _typing.Literal["_updated_at", b"_updated_at"]  # noqa: Y015
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__created_at) -> _WhichOneofReturnType__created_at | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__updated_at) -> _WhichOneofReturnType__updated_at | None: ...

    @_typing.final
    class RateLimitData(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        LIMIT_EXPIRY_FIELD_NUMBER: _builtins.int
        @_builtins.property
        def limit_expiry(self) -> _timestamp_pb2.Timestamp: ...
        def __init__(
            self,
            *,
            limit_expiry: _timestamp_pb2.Timestamp | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_limit_expiry", b"_limit_expiry", "limit_expiry", b"limit_expiry"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_limit_expiry", b"_limit_expiry", "limit_expiry", b"limit_expiry"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__limit_expiry: _TypeAlias = _typing.Literal["limit_expiry"]  # noqa: Y015
        _WhichOneofArgType__limit_expiry: _TypeAlias = _typing.Literal["_limit_expiry", b"_limit_expiry"]  # noqa: Y015
        def WhichOneof(self, oneof_group: _WhichOneofArgType__limit_expiry) -> _WhichOneofReturnType__limit_expiry | None: ...

    @_typing.final
    class FeatureLimits(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        @_typing.final
        class MapEntry(_message.Message):
            DESCRIPTOR: _descriptor.Descriptor

            KEY_FIELD_NUMBER: _builtins.int
            VALUE_FIELD_NUMBER: _builtins.int
            key: _builtins.int
            @_builtins.property
            def value(self) -> Global___UserData.RateLimitData: ...
            def __init__(
                self,
                *,
                key: _builtins.int = ...,
                value: Global___UserData.RateLimitData | None = ...,
            ) -> None: ...
            _HasFieldArgType: _TypeAlias = _typing.Literal["value", b"value"]  # noqa: Y015
            def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
            _ClearFieldArgType: _TypeAlias = _typing.Literal["key", b"key", "value", b"value"]  # noqa: Y015
            def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

        MAP_FIELD_NUMBER: _builtins.int
        @_builtins.property
        def map(self) -> _containers.MessageMap[_builtins.int, Global___UserData.RateLimitData]: ...
        def __init__(
            self,
            *,
            map: _abc.Mapping[_builtins.int, Global___UserData.RateLimitData] | None = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["map", b"map"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class SafetyFlag(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        FLAG_EXPIRY_FIELD_NUMBER: _builtins.int
        @_builtins.property
        def flag_expiry(self) -> _timestamp_pb2.Timestamp: ...
        def __init__(
            self,
            *,
            flag_expiry: _timestamp_pb2.Timestamp | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_flag_expiry", b"_flag_expiry", "flag_expiry", b"flag_expiry"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_flag_expiry", b"_flag_expiry", "flag_expiry", b"flag_expiry"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__flag_expiry: _TypeAlias = _typing.Literal["flag_expiry"]  # noqa: Y015
        _WhichOneofArgType__flag_expiry: _TypeAlias = _typing.Literal["_flag_expiry", b"_flag_expiry"]  # noqa: Y015
        def WhichOneof(self, oneof_group: _WhichOneofArgType__flag_expiry) -> _WhichOneofReturnType__flag_expiry | None: ...

    @_typing.final
    class QuestMetadata(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        QUESTS_COMPLETED_FIELD_NUMBER: _builtins.int
        quests_completed: _builtins.int
        def __init__(
            self,
            *,
            quests_completed: _builtins.int = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["quests_completed", b"quests_completed"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class UserPrimaryGuild(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        IDENTITY_GUILD_ID_FIELD_NUMBER: _builtins.int
        IDENTITY_ENABLED_FIELD_NUMBER: _builtins.int
        TAG_FIELD_NUMBER: _builtins.int
        BADGE_FIELD_NUMBER: _builtins.int
        @_builtins.property
        def identity_guild_id(self) -> _wrappers_pb2.UInt64Value: ...
        @_builtins.property
        def identity_enabled(self) -> _wrappers_pb2.BoolValue: ...
        @_builtins.property
        def tag(self) -> _wrappers_pb2.StringValue: ...
        @_builtins.property
        def badge(self) -> _wrappers_pb2.StringValue: ...
        def __init__(
            self,
            *,
            identity_guild_id: _wrappers_pb2.UInt64Value | None = ...,
            identity_enabled: _wrappers_pb2.BoolValue | None = ...,
            tag: _wrappers_pb2.StringValue | None = ...,
            badge: _wrappers_pb2.StringValue | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_badge", b"_badge", "_identity_enabled", b"_identity_enabled", "_identity_guild_id", b"_identity_guild_id", "_tag", b"_tag", "badge", b"badge", "identity_enabled", b"identity_enabled", "identity_guild_id", b"identity_guild_id", "tag", b"tag"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_badge", b"_badge", "_identity_enabled", b"_identity_enabled", "_identity_guild_id", b"_identity_guild_id", "_tag", b"_tag", "badge", b"badge", "identity_enabled", b"identity_enabled", "identity_guild_id", b"identity_guild_id", "tag", b"tag"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__badge: _TypeAlias = _typing.Literal["badge"]  # noqa: Y015
        _WhichOneofArgType__badge: _TypeAlias = _typing.Literal["_badge", b"_badge"]  # noqa: Y015
        _WhichOneofReturnType__identity_enabled: _TypeAlias = _typing.Literal["identity_enabled"]  # noqa: Y015
        _WhichOneofArgType__identity_enabled: _TypeAlias = _typing.Literal["_identity_enabled", b"_identity_enabled"]  # noqa: Y015
        _WhichOneofReturnType__identity_guild_id: _TypeAlias = _typing.Literal["identity_guild_id"]  # noqa: Y015
        _WhichOneofArgType__identity_guild_id: _TypeAlias = _typing.Literal["_identity_guild_id", b"_identity_guild_id"]  # noqa: Y015
        _WhichOneofReturnType__tag: _TypeAlias = _typing.Literal["tag"]  # noqa: Y015
        _WhichOneofArgType__tag: _TypeAlias = _typing.Literal["_tag", b"_tag"]  # noqa: Y015
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__badge) -> _WhichOneofReturnType__badge | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__identity_enabled) -> _WhichOneofReturnType__identity_enabled | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__identity_guild_id) -> _WhichOneofReturnType__identity_guild_id | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__tag) -> _WhichOneofReturnType__tag | None: ...

    @_typing.final
    class CrossPlatformRestriction(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        RESTRICTION_EXPIRY_FIELD_NUMBER: _builtins.int
        APPLICATION_ID_FIELD_NUMBER: _builtins.int
        application_id: _builtins.int
        @_builtins.property
        def restriction_expiry(self) -> _timestamp_pb2.Timestamp: ...
        def __init__(
            self,
            *,
            restriction_expiry: _timestamp_pb2.Timestamp | None = ...,
            application_id: _builtins.int = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_restriction_expiry", b"_restriction_expiry", "restriction_expiry", b"restriction_expiry"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_restriction_expiry", b"_restriction_expiry", "application_id", b"application_id", "restriction_expiry", b"restriction_expiry"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__restriction_expiry: _TypeAlias = _typing.Literal["restriction_expiry"]  # noqa: Y015
        _WhichOneofArgType__restriction_expiry: _TypeAlias = _typing.Literal["_restriction_expiry", b"_restriction_expiry"]  # noqa: Y015
        def WhichOneof(self, oneof_group: _WhichOneofArgType__restriction_expiry) -> _WhichOneofReturnType__restriction_expiry | None: ...

    @_typing.final
    class UserNameplate(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        ASSET_FIELD_NUMBER: _builtins.int
        PALETTE_FIELD_NUMBER: _builtins.int
        SKU_ID_FIELD_NUMBER: _builtins.int
        EXPIRES_AT_FIELD_NUMBER: _builtins.int
        LABEL_FIELD_NUMBER: _builtins.int
        asset: _builtins.str
        palette: _builtins.str
        label: _builtins.str
        @_builtins.property
        def sku_id(self) -> _wrappers_pb2.UInt64Value: ...
        @_builtins.property
        def expires_at(self) -> _timestamp_pb2.Timestamp: ...
        def __init__(
            self,
            *,
            asset: _builtins.str = ...,
            palette: _builtins.str = ...,
            sku_id: _wrappers_pb2.UInt64Value | None = ...,
            expires_at: _timestamp_pb2.Timestamp | None = ...,
            label: _builtins.str = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_expires_at", b"_expires_at", "_sku_id", b"_sku_id", "expires_at", b"expires_at", "sku_id", b"sku_id"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_expires_at", b"_expires_at", "_sku_id", b"_sku_id", "asset", b"asset", "expires_at", b"expires_at", "label", b"label", "palette", b"palette", "sku_id", b"sku_id"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__expires_at: _TypeAlias = _typing.Literal["expires_at"]  # noqa: Y015
        _WhichOneofArgType__expires_at: _TypeAlias = _typing.Literal["_expires_at", b"_expires_at"]  # noqa: Y015
        _WhichOneofReturnType__sku_id: _TypeAlias = _typing.Literal["sku_id"]  # noqa: Y015
        _WhichOneofArgType__sku_id: _TypeAlias = _typing.Literal["_sku_id", b"_sku_id"]  # noqa: Y015
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__expires_at) -> _WhichOneofReturnType__expires_at | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__sku_id) -> _WhichOneofReturnType__sku_id | None: ...

    @_typing.final
    class UserCollectibles(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        NAMEPLATE_FIELD_NUMBER: _builtins.int
        @_builtins.property
        def nameplate(self) -> Global___UserData.UserNameplate: ...
        def __init__(
            self,
            *,
            nameplate: Global___UserData.UserNameplate | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_nameplate", b"_nameplate", "nameplate", b"nameplate"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_nameplate", b"_nameplate", "nameplate", b"nameplate"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__nameplate: _TypeAlias = _typing.Literal["nameplate"]  # noqa: Y015
        _WhichOneofArgType__nameplate: _TypeAlias = _typing.Literal["_nameplate", b"_nameplate"]  # noqa: Y015
        def WhichOneof(self, oneof_group: _WhichOneofArgType__nameplate) -> _WhichOneofReturnType__nameplate | None: ...

    @_typing.final
    class NormalState(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        def __init__(
            self,
        ) -> None: ...

    @_typing.final
    class RestrictedState(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        RESTRICTED_UNTIL_FIELD_NUMBER: _builtins.int
        @_builtins.property
        def restricted_until(self) -> _timestamp_pb2.Timestamp: ...
        def __init__(
            self,
            *,
            restricted_until: _timestamp_pb2.Timestamp | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_restricted_until", b"_restricted_until", "restricted_until", b"restricted_until"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_restricted_until", b"_restricted_until", "restricted_until", b"restricted_until"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__restricted_until: _TypeAlias = _typing.Literal["restricted_until"]  # noqa: Y015
        _WhichOneofArgType__restricted_until: _TypeAlias = _typing.Literal["_restricted_until", b"_restricted_until"]  # noqa: Y015
        def WhichOneof(self, oneof_group: _WhichOneofArgType__restricted_until) -> _WhichOneofReturnType__restricted_until | None: ...

    @_typing.final
    class DeferredActionState(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        ACTION_DEFERRED_UNTIL_FIELD_NUMBER: _builtins.int
        @_builtins.property
        def action_deferred_until(self) -> _timestamp_pb2.Timestamp: ...
        def __init__(
            self,
            *,
            action_deferred_until: _timestamp_pb2.Timestamp | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_action_deferred_until", b"_action_deferred_until", "action_deferred_until", b"action_deferred_until"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_action_deferred_until", b"_action_deferred_until", "action_deferred_until", b"action_deferred_until"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__action_deferred_until: _TypeAlias = _typing.Literal["action_deferred_until"]  # noqa: Y015
        _WhichOneofArgType__action_deferred_until: _TypeAlias = _typing.Literal["_action_deferred_until", b"_action_deferred_until"]  # noqa: Y015
        def WhichOneof(self, oneof_group: _WhichOneofArgType__action_deferred_until) -> _WhichOneofReturnType__action_deferred_until | None: ...

    @_typing.final
    class TempBannedState(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        BANNED_UNTIL_FIELD_NUMBER: _builtins.int
        CLASSIFICATION_TYPES_FIELD_NUMBER: _builtins.int
        @_builtins.property
        def banned_until(self) -> _timestamp_pb2.Timestamp: ...
        @_builtins.property
        def classification_types(self) -> _containers.RepeatedScalarFieldContainer[Global___UserData.ClassificationType.ValueType]: ...
        def __init__(
            self,
            *,
            banned_until: _timestamp_pb2.Timestamp | None = ...,
            classification_types: _abc.Iterable[Global___UserData.ClassificationType.ValueType] | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_banned_until", b"_banned_until", "banned_until", b"banned_until"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_banned_until", b"_banned_until", "banned_until", b"banned_until", "classification_types", b"classification_types"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__banned_until: _TypeAlias = _typing.Literal["banned_until"]  # noqa: Y015
        _WhichOneofArgType__banned_until: _TypeAlias = _typing.Literal["_banned_until", b"_banned_until"]  # noqa: Y015
        def WhichOneof(self, oneof_group: _WhichOneofArgType__banned_until) -> _WhichOneofReturnType__banned_until | None: ...

    @_typing.final
    class BannedState(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        CLASSIFICATION_TYPES_FIELD_NUMBER: _builtins.int
        @_builtins.property
        def classification_types(self) -> _containers.RepeatedScalarFieldContainer[Global___UserData.ClassificationType.ValueType]: ...
        def __init__(
            self,
            *,
            classification_types: _abc.Iterable[Global___UserData.ClassificationType.ValueType] | None = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["classification_types", b"classification_types"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class SafetyState(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        NORMAL_FIELD_NUMBER: _builtins.int
        RESTRICTED_FIELD_NUMBER: _builtins.int
        DEFERRED_ACTION_FIELD_NUMBER: _builtins.int
        TEMP_BANNED_FIELD_NUMBER: _builtins.int
        BANNED_FIELD_NUMBER: _builtins.int
        REASON_FIELD_NUMBER: _builtins.int
        ANNOTATIONS_FIELD_NUMBER: _builtins.int
        LAST_MUTATION_ID_FIELD_NUMBER: _builtins.int
        reason: Global___UserData.SafetyStateReason.ValueType
        @_builtins.property
        def normal(self) -> Global___UserData.NormalState: ...
        @_builtins.property
        def restricted(self) -> Global___UserData.RestrictedState: ...
        @_builtins.property
        def deferred_action(self) -> Global___UserData.DeferredActionState: ...
        @_builtins.property
        def temp_banned(self) -> Global___UserData.TempBannedState: ...
        @_builtins.property
        def banned(self) -> Global___UserData.BannedState: ...
        @_builtins.property
        def annotations(self) -> _containers.RepeatedScalarFieldContainer[Global___UserData.SafetyAnnotations.ValueType]: ...
        @_builtins.property
        def last_mutation_id(self) -> _wrappers_pb2.UInt64Value: ...
        def __init__(
            self,
            *,
            normal: Global___UserData.NormalState | None = ...,
            restricted: Global___UserData.RestrictedState | None = ...,
            deferred_action: Global___UserData.DeferredActionState | None = ...,
            temp_banned: Global___UserData.TempBannedState | None = ...,
            banned: Global___UserData.BannedState | None = ...,
            reason: Global___UserData.SafetyStateReason.ValueType = ...,
            annotations: _abc.Iterable[Global___UserData.SafetyAnnotations.ValueType] | None = ...,
            last_mutation_id: _wrappers_pb2.UInt64Value | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_last_mutation_id", b"_last_mutation_id", "banned", b"banned", "deferred_action", b"deferred_action", "last_mutation_id", b"last_mutation_id", "normal", b"normal", "restricted", b"restricted", "state", b"state", "temp_banned", b"temp_banned"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_last_mutation_id", b"_last_mutation_id", "annotations", b"annotations", "banned", b"banned", "deferred_action", b"deferred_action", "last_mutation_id", b"last_mutation_id", "normal", b"normal", "reason", b"reason", "restricted", b"restricted", "state", b"state", "temp_banned", b"temp_banned"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__last_mutation_id: _TypeAlias = _typing.Literal["last_mutation_id"]  # noqa: Y015
        _WhichOneofArgType__last_mutation_id: _TypeAlias = _typing.Literal["_last_mutation_id", b"_last_mutation_id"]  # noqa: Y015
        _WhichOneofReturnType_state: _TypeAlias = _typing.Literal["normal", "restricted", "deferred_action", "temp_banned", "banned"]  # noqa: Y015
        _WhichOneofArgType_state: _TypeAlias = _typing.Literal["state", b"state"]  # noqa: Y015
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__last_mutation_id) -> _WhichOneofReturnType__last_mutation_id | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType_state) -> _WhichOneofReturnType_state | None: ...

    @_typing.final
    class PremiumState(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        PREMIUM_SOURCE_FIELD_NUMBER: _builtins.int
        PREMIUM_SUBSCRIPTION_TYPE_FIELD_NUMBER: _builtins.int
        PREMIUM_SUBSCRIPTION_GROUP_ROLE_FIELD_NUMBER: _builtins.int
        premium_source: Global___UserData.PremiumSource.ValueType
        premium_subscription_type: Global___UserData.PremiumSubscriptionType.ValueType
        premium_subscription_group_role: Global___UserData.PremiumSubscriptionGroupRole.ValueType
        def __init__(
            self,
            *,
            premium_source: Global___UserData.PremiumSource.ValueType = ...,
            premium_subscription_type: Global___UserData.PremiumSubscriptionType.ValueType = ...,
            premium_subscription_group_role: Global___UserData.PremiumSubscriptionGroupRole.ValueType = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["premium_source", b"premium_source", "premium_subscription_group_role", b"premium_subscription_group_role", "premium_subscription_type", b"premium_subscription_type"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class DisplayNameStyles(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        FONT_ID_FIELD_NUMBER: _builtins.int
        EFFECT_ID_FIELD_NUMBER: _builtins.int
        COLORS_FIELD_NUMBER: _builtins.int
        font_id: Global___UserData.DisplayNameFont.ValueType
        effect_id: Global___UserData.DisplayNameEffect.ValueType
        @_builtins.property
        def colors(self) -> _containers.RepeatedScalarFieldContainer[_builtins.int]: ...
        def __init__(
            self,
            *,
            font_id: Global___UserData.DisplayNameFont.ValueType = ...,
            effect_id: Global___UserData.DisplayNameEffect.ValueType = ...,
            colors: _abc.Iterable[_builtins.int] | None = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["colors", b"colors", "effect_id", b"effect_id", "font_id", b"font_id"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class StoreCountry(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        COUNTRY_FIELD_NUMBER: _builtins.int
        SET_AT_FIELD_NUMBER: _builtins.int
        country: _builtins.str
        @_builtins.property
        def set_at(self) -> _timestamp_pb2.Timestamp: ...
        def __init__(
            self,
            *,
            country: _builtins.str = ...,
            set_at: _timestamp_pb2.Timestamp | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_set_at", b"_set_at", "set_at", b"set_at"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_set_at", b"_set_at", "country", b"country", "set_at", b"set_at"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__set_at: _TypeAlias = _typing.Literal["set_at"]  # noqa: Y015
        _WhichOneofArgType__set_at: _TypeAlias = _typing.Literal["_set_at", b"_set_at"]  # noqa: Y015
        def WhichOneof(self, oneof_group: _WhichOneofArgType__set_at) -> _WhichOneofReturnType__set_at | None: ...

    @_typing.final
    class TimeOfDay(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        HOURS_FIELD_NUMBER: _builtins.int
        MINUTES_FIELD_NUMBER: _builtins.int
        SECONDS_FIELD_NUMBER: _builtins.int
        NANOS_FIELD_NUMBER: _builtins.int
        hours: _builtins.int
        minutes: _builtins.int
        seconds: _builtins.int
        nanos: _builtins.int
        def __init__(
            self,
            *,
            hours: _builtins.int = ...,
            minutes: _builtins.int = ...,
            seconds: _builtins.int = ...,
            nanos: _builtins.int = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["hours", b"hours", "minutes", b"minutes", "nanos", b"nanos", "seconds", b"seconds"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class ScheduleRule(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        RULE_ID_FIELD_NUMBER: _builtins.int
        LABEL_FIELD_NUMBER: _builtins.int
        START_TIME_FIELD_NUMBER: _builtins.int
        END_TIME_FIELD_NUMBER: _builtins.int
        DAYS_FIELD_NUMBER: _builtins.int
        rule_id: _builtins.str
        label: _builtins.str
        @_builtins.property
        def start_time(self) -> Global___UserData.TimeOfDay: ...
        @_builtins.property
        def end_time(self) -> Global___UserData.TimeOfDay: ...
        @_builtins.property
        def days(self) -> _containers.RepeatedScalarFieldContainer[Global___UserData.DayOfWeek.ValueType]: ...
        def __init__(
            self,
            *,
            rule_id: _builtins.str = ...,
            label: _builtins.str = ...,
            start_time: Global___UserData.TimeOfDay | None = ...,
            end_time: Global___UserData.TimeOfDay | None = ...,
            days: _abc.Iterable[Global___UserData.DayOfWeek.ValueType] | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_end_time", b"_end_time", "_start_time", b"_start_time", "end_time", b"end_time", "start_time", b"start_time"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_end_time", b"_end_time", "_start_time", b"_start_time", "days", b"days", "end_time", b"end_time", "label", b"label", "rule_id", b"rule_id", "start_time", b"start_time"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__end_time: _TypeAlias = _typing.Literal["end_time"]  # noqa: Y015
        _WhichOneofArgType__end_time: _TypeAlias = _typing.Literal["_end_time", b"_end_time"]  # noqa: Y015
        _WhichOneofReturnType__start_time: _TypeAlias = _typing.Literal["start_time"]  # noqa: Y015
        _WhichOneofArgType__start_time: _TypeAlias = _typing.Literal["_start_time", b"_start_time"]  # noqa: Y015
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__end_time) -> _WhichOneofReturnType__end_time | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__start_time) -> _WhichOneofReturnType__start_time | None: ...

    @_typing.final
    class RestrictedSchedule(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        RULES_FIELD_NUMBER: _builtins.int
        @_builtins.property
        def rules(self) -> _containers.RepeatedCompositeFieldContainer[Global___UserData.ScheduleRule]: ...
        def __init__(
            self,
            *,
            rules: _abc.Iterable[Global___UserData.ScheduleRule] | None = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["rules", b"rules"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class AgeAssuranceData(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        ESTIMATED_DATE_OF_BIRTH_FIELD_NUMBER: _builtins.int
        METHOD_FIELD_NUMBER: _builtins.int
        METHOD_VERSION_FIELD_NUMBER: _builtins.int
        VENDOR_FIELD_NUMBER: _builtins.int
        VERIFIED_AT_FIELD_NUMBER: _builtins.int
        method: Global___UserData.AgeAssuranceMethod.ValueType
        method_version: _builtins.int
        vendor: Global___UserData.AgeAssuranceVendor.ValueType
        @_builtins.property
        def estimated_date_of_birth(self) -> _timestamp_pb2.Timestamp: ...
        @_builtins.property
        def verified_at(self) -> _timestamp_pb2.Timestamp: ...
        def __init__(
            self,
            *,
            estimated_date_of_birth: _timestamp_pb2.Timestamp | None = ...,
            method: Global___UserData.AgeAssuranceMethod.ValueType = ...,
            method_version: _builtins.int = ...,
            vendor: Global___UserData.AgeAssuranceVendor.ValueType = ...,
            verified_at: _timestamp_pb2.Timestamp | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_estimated_date_of_birth", b"_estimated_date_of_birth", "_verified_at", b"_verified_at", "estimated_date_of_birth", b"estimated_date_of_birth", "verified_at", b"verified_at"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_estimated_date_of_birth", b"_estimated_date_of_birth", "_verified_at", b"_verified_at", "estimated_date_of_birth", b"estimated_date_of_birth", "method", b"method", "method_version", b"method_version", "vendor", b"vendor", "verified_at", b"verified_at"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__estimated_date_of_birth: _TypeAlias = _typing.Literal["estimated_date_of_birth"]  # noqa: Y015
        _WhichOneofArgType__estimated_date_of_birth: _TypeAlias = _typing.Literal["_estimated_date_of_birth", b"_estimated_date_of_birth"]  # noqa: Y015
        _WhichOneofReturnType__verified_at: _TypeAlias = _typing.Literal["verified_at"]  # noqa: Y015
        _WhichOneofArgType__verified_at: _TypeAlias = _typing.Literal["_verified_at", b"_verified_at"]  # noqa: Y015
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__estimated_date_of_birth) -> _WhichOneofReturnType__estimated_date_of_birth | None: ...
        @_typing.overload
        def WhichOneof(self, oneof_group: _WhichOneofArgType__verified_at) -> _WhichOneofReturnType__verified_at | None: ...

    @_typing.final
    class PerkConfigIncreasedFileUploadSize(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        MAX_SIZE_FIELD_NUMBER: _builtins.int
        max_size: _builtins.int
        def __init__(
            self,
            *,
            max_size: _builtins.int = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["max_size", b"max_size"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class PerkConfigIncreasedGuildLimit(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        MAX_GUILDS_FIELD_NUMBER: _builtins.int
        max_guilds: _builtins.int
        def __init__(
            self,
            *,
            max_guilds: _builtins.int = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["max_guilds", b"max_guilds"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class PerkConfig(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        INCREASED_FILE_UPLOAD_SIZE_FIELD_NUMBER: _builtins.int
        INCREASED_GUILD_LIMIT_FIELD_NUMBER: _builtins.int
        SOURCE_FIELD_NUMBER: _builtins.int
        @_builtins.property
        def increased_file_upload_size(self) -> Global___UserData.PerkConfigIncreasedFileUploadSize: ...
        @_builtins.property
        def increased_guild_limit(self) -> Global___UserData.PerkConfigIncreasedGuildLimit: ...
        @_builtins.property
        def source(self) -> _containers.RepeatedScalarFieldContainer[Global___UserData.PerkSource.ValueType]: ...
        def __init__(
            self,
            *,
            increased_file_upload_size: Global___UserData.PerkConfigIncreasedFileUploadSize | None = ...,
            increased_guild_limit: Global___UserData.PerkConfigIncreasedGuildLimit | None = ...,
            source: _abc.Iterable[Global___UserData.PerkSource.ValueType] | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["increased_file_upload_size", b"increased_file_upload_size", "increased_guild_limit", b"increased_guild_limit", "kind", b"kind"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["increased_file_upload_size", b"increased_file_upload_size", "increased_guild_limit", b"increased_guild_limit", "kind", b"kind", "source", b"source"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType_kind: _TypeAlias = _typing.Literal["increased_file_upload_size", "increased_guild_limit"]  # noqa: Y015
        _WhichOneofArgType_kind: _TypeAlias = _typing.Literal["kind", b"kind"]  # noqa: Y015
        def WhichOneof(self, oneof_group: _WhichOneofArgType_kind) -> _WhichOneofReturnType_kind | None: ...

    @_typing.final
    class Perks(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        @_typing.final
        class ConfigByPerkEntry(_message.Message):
            DESCRIPTOR: _descriptor.Descriptor

            KEY_FIELD_NUMBER: _builtins.int
            VALUE_FIELD_NUMBER: _builtins.int
            key: _builtins.int
            @_builtins.property
            def value(self) -> Global___UserData.PerkConfig: ...
            def __init__(
                self,
                *,
                key: _builtins.int = ...,
                value: Global___UserData.PerkConfig | None = ...,
            ) -> None: ...
            _HasFieldArgType: _TypeAlias = _typing.Literal["value", b"value"]  # noqa: Y015
            def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
            _ClearFieldArgType: _TypeAlias = _typing.Literal["key", b"key", "value", b"value"]  # noqa: Y015
            def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

        ACTIVE_PERKS_BITMASK_FIELD_NUMBER: _builtins.int
        CONFIG_BY_PERK_FIELD_NUMBER: _builtins.int
        RULES_VERSION_FIELD_NUMBER: _builtins.int
        UPDATED_AT_FIELD_NUMBER: _builtins.int
        rules_version: _builtins.int
        @_builtins.property
        def active_perks_bitmask(self) -> _containers.RepeatedScalarFieldContainer[_builtins.int]: ...
        @_builtins.property
        def config_by_perk(self) -> _containers.MessageMap[_builtins.int, Global___UserData.PerkConfig]: ...
        @_builtins.property
        def updated_at(self) -> _timestamp_pb2.Timestamp: ...
        def __init__(
            self,
            *,
            active_perks_bitmask: _abc.Iterable[_builtins.int] | None = ...,
            config_by_perk: _abc.Mapping[_builtins.int, Global___UserData.PerkConfig] | None = ...,
            rules_version: _builtins.int = ...,
            updated_at: _timestamp_pb2.Timestamp | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_updated_at", b"_updated_at", "updated_at", b"updated_at"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_updated_at", b"_updated_at", "active_perks_bitmask", b"active_perks_bitmask", "config_by_perk", b"config_by_perk", "rules_version", b"rules_version", "updated_at", b"updated_at"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__updated_at: _TypeAlias = _typing.Literal["updated_at"]  # noqa: Y015
        _WhichOneofArgType__updated_at: _TypeAlias = _typing.Literal["_updated_at", b"_updated_at"]  # noqa: Y015
        def WhichOneof(self, oneof_group: _WhichOneofArgType__updated_at) -> _WhichOneofReturnType__updated_at | None: ...

    @_typing.final
    class BadgeCommon(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        OBTAINED_AT_FIELD_NUMBER: _builtins.int
        @_builtins.property
        def obtained_at(self) -> _timestamp_pb2.Timestamp: ...
        def __init__(
            self,
            *,
            obtained_at: _timestamp_pb2.Timestamp | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_obtained_at", b"_obtained_at", "obtained_at", b"obtained_at"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_obtained_at", b"_obtained_at", "obtained_at", b"obtained_at"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__obtained_at: _TypeAlias = _typing.Literal["obtained_at"]  # noqa: Y015
        _WhichOneofArgType__obtained_at: _TypeAlias = _typing.Literal["_obtained_at", b"_obtained_at"]  # noqa: Y015
        def WhichOneof(self, oneof_group: _WhichOneofArgType__obtained_at) -> _WhichOneofReturnType__obtained_at | None: ...

    @_typing.final
    class AprilFools2026Badge(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        COMMON_FIELD_NUMBER: _builtins.int
        LEVEL_FIELD_NUMBER: _builtins.int
        COMBAT_CLASS_FIELD_NUMBER: _builtins.int
        level: _builtins.int
        combat_class: _builtins.str
        @_builtins.property
        def common(self) -> Global___UserData.BadgeCommon: ...
        def __init__(
            self,
            *,
            common: Global___UserData.BadgeCommon | None = ...,
            level: _builtins.int = ...,
            combat_class: _builtins.str = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["_common", b"_common", "common", b"common"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["_common", b"_common", "combat_class", b"combat_class", "common", b"common", "level", b"level"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType__common: _TypeAlias = _typing.Literal["common"]  # noqa: Y015
        _WhichOneofArgType__common: _TypeAlias = _typing.Literal["_common", b"_common"]  # noqa: Y015
        def WhichOneof(self, oneof_group: _WhichOneofArgType__common) -> _WhichOneofReturnType__common | None: ...

    @_typing.final
    class Badge(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        APRIL_FOOLS_2026_FIELD_NUMBER: _builtins.int
        @_builtins.property
        def april_fools_2026(self) -> Global___UserData.AprilFools2026Badge: ...
        def __init__(
            self,
            *,
            april_fools_2026: Global___UserData.AprilFools2026Badge | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["april_fools_2026", b"april_fools_2026", "badge", b"badge"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["april_fools_2026", b"april_fools_2026", "badge", b"badge"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
        _WhichOneofReturnType_badge: _TypeAlias = _typing.Literal["april_fools_2026"]  # noqa: Y015
        _WhichOneofArgType_badge: _TypeAlias = _typing.Literal["badge", b"badge"]  # noqa: Y015
        def WhichOneof(self, oneof_group: _WhichOneofArgType_badge) -> _WhichOneofReturnType_badge | None: ...

    @_typing.final
    class UserBadges(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        BADGES_FIELD_NUMBER: _builtins.int
        @_builtins.property
        def badges(self) -> _containers.RepeatedCompositeFieldContainer[Global___UserData.Badge]: ...
        def __init__(
            self,
            *,
            badges: _abc.Iterable[Global___UserData.Badge] | None = ...,
        ) -> None: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["badges", b"badges"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class LinkedUsersEntry(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        KEY_FIELD_NUMBER: _builtins.int
        VALUE_FIELD_NUMBER: _builtins.int
        key: _builtins.int
        @_builtins.property
        def value(self) -> Global___UserData.LinkedUser: ...
        def __init__(
            self,
            *,
            key: _builtins.int = ...,
            value: Global___UserData.LinkedUser | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["value", b"value"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["key", b"key", "value", b"value"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class SafetyFeatureLimitsEntry(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        KEY_FIELD_NUMBER: _builtins.int
        VALUE_FIELD_NUMBER: _builtins.int
        key: _builtins.int
        @_builtins.property
        def value(self) -> Global___UserData.FeatureLimits: ...
        def __init__(
            self,
            *,
            key: _builtins.int = ...,
            value: Global___UserData.FeatureLimits | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["value", b"value"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["key", b"key", "value", b"value"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    @_typing.final
    class SafetyFlagsEntry(_message.Message):
        DESCRIPTOR: _descriptor.Descriptor

        KEY_FIELD_NUMBER: _builtins.int
        VALUE_FIELD_NUMBER: _builtins.int
        key: _builtins.int
        @_builtins.property
        def value(self) -> Global___UserData.SafetyFlag: ...
        def __init__(
            self,
            *,
            key: _builtins.int = ...,
            value: Global___UserData.SafetyFlag | None = ...,
        ) -> None: ...
        _HasFieldArgType: _TypeAlias = _typing.Literal["value", b"value"]  # noqa: Y015
        def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
        _ClearFieldArgType: _TypeAlias = _typing.Literal["key", b"key", "value", b"value"]  # noqa: Y015
        def ClearField(self, field_name: _ClearFieldArgType) -> None: ...

    LINKED_USERS_FIELD_NUMBER: _builtins.int
    SAFETY_FEATURE_LIMITS_FIELD_NUMBER: _builtins.int
    SAFETY_FLAGS_FIELD_NUMBER: _builtins.int
    QUEST_FIELD_NUMBER: _builtins.int
    PRIMARY_GUILD_FIELD_NUMBER: _builtins.int
    CROSS_PLATFORM_RESTRICTION_FIELD_NUMBER: _builtins.int
    COLLECTIBLES_FIELD_NUMBER: _builtins.int
    SAFETY_STATE_FIELD_NUMBER: _builtins.int
    PREMIUM_STATE_FIELD_NUMBER: _builtins.int
    DISPLAY_NAME_STYLES_FIELD_NUMBER: _builtins.int
    STORE_COUNTRY_FIELD_NUMBER: _builtins.int
    RESTRICTED_SCHEDULE_FIELD_NUMBER: _builtins.int
    AGE_ASSURANCE_DATA_FIELD_NUMBER: _builtins.int
    PERKS_FIELD_NUMBER: _builtins.int
    BADGES_FIELD_NUMBER: _builtins.int
    @_builtins.property
    def linked_users(self) -> _containers.MessageMap[_builtins.int, Global___UserData.LinkedUser]: ...
    @_builtins.property
    def safety_feature_limits(self) -> _containers.MessageMap[_builtins.int, Global___UserData.FeatureLimits]: ...
    @_builtins.property
    def safety_flags(self) -> _containers.MessageMap[_builtins.int, Global___UserData.SafetyFlag]: ...
    @_builtins.property
    def quest(self) -> Global___UserData.QuestMetadata: ...
    @_builtins.property
    def primary_guild(self) -> Global___UserData.UserPrimaryGuild: ...
    @_builtins.property
    def cross_platform_restriction(self) -> Global___UserData.CrossPlatformRestriction: ...
    @_builtins.property
    def collectibles(self) -> Global___UserData.UserCollectibles: ...
    @_builtins.property
    def safety_state(self) -> Global___UserData.SafetyState: ...
    @_builtins.property
    def premium_state(self) -> Global___UserData.PremiumState: ...
    @_builtins.property
    def display_name_styles(self) -> Global___UserData.DisplayNameStyles: ...
    @_builtins.property
    def store_country(self) -> Global___UserData.StoreCountry: ...
    @_builtins.property
    def restricted_schedule(self) -> Global___UserData.RestrictedSchedule: ...
    @_builtins.property
    def age_assurance_data(self) -> Global___UserData.AgeAssuranceData: ...
    @_builtins.property
    def perks(self) -> Global___UserData.Perks: ...
    @_builtins.property
    def badges(self) -> Global___UserData.UserBadges: ...
    def __init__(
        self,
        *,
        linked_users: _abc.Mapping[_builtins.int, Global___UserData.LinkedUser] | None = ...,
        safety_feature_limits: _abc.Mapping[_builtins.int, Global___UserData.FeatureLimits] | None = ...,
        safety_flags: _abc.Mapping[_builtins.int, Global___UserData.SafetyFlag] | None = ...,
        quest: Global___UserData.QuestMetadata | None = ...,
        primary_guild: Global___UserData.UserPrimaryGuild | None = ...,
        cross_platform_restriction: Global___UserData.CrossPlatformRestriction | None = ...,
        collectibles: Global___UserData.UserCollectibles | None = ...,
        safety_state: Global___UserData.SafetyState | None = ...,
        premium_state: Global___UserData.PremiumState | None = ...,
        display_name_styles: Global___UserData.DisplayNameStyles | None = ...,
        store_country: Global___UserData.StoreCountry | None = ...,
        restricted_schedule: Global___UserData.RestrictedSchedule | None = ...,
        age_assurance_data: Global___UserData.AgeAssuranceData | None = ...,
        perks: Global___UserData.Perks | None = ...,
        badges: Global___UserData.UserBadges | None = ...,
    ) -> None: ...
    _HasFieldArgType: _TypeAlias = _typing.Literal["_age_assurance_data", b"_age_assurance_data", "_badges", b"_badges", "_collectibles", b"_collectibles", "_cross_platform_restriction", b"_cross_platform_restriction", "_display_name_styles", b"_display_name_styles", "_perks", b"_perks", "_premium_state", b"_premium_state", "_primary_guild", b"_primary_guild", "_quest", b"_quest", "_restricted_schedule", b"_restricted_schedule", "_safety_state", b"_safety_state", "_store_country", b"_store_country", "age_assurance_data", b"age_assurance_data", "badges", b"badges", "collectibles", b"collectibles", "cross_platform_restriction", b"cross_platform_restriction", "display_name_styles", b"display_name_styles", "perks", b"perks", "premium_state", b"premium_state", "primary_guild", b"primary_guild", "quest", b"quest", "restricted_schedule", b"restricted_schedule", "safety_state", b"safety_state", "store_country", b"store_country"]  # noqa: Y015
    def HasField(self, field_name: _HasFieldArgType) -> _builtins.bool: ...
    _ClearFieldArgType: _TypeAlias = _typing.Literal["_age_assurance_data", b"_age_assurance_data", "_badges", b"_badges", "_collectibles", b"_collectibles", "_cross_platform_restriction", b"_cross_platform_restriction", "_display_name_styles", b"_display_name_styles", "_perks", b"_perks", "_premium_state", b"_premium_state", "_primary_guild", b"_primary_guild", "_quest", b"_quest", "_restricted_schedule", b"_restricted_schedule", "_safety_state", b"_safety_state", "_store_country", b"_store_country", "age_assurance_data", b"age_assurance_data", "badges", b"badges", "collectibles", b"collectibles", "cross_platform_restriction", b"cross_platform_restriction", "display_name_styles", b"display_name_styles", "linked_users", b"linked_users", "perks", b"perks", "premium_state", b"premium_state", "primary_guild", b"primary_guild", "quest", b"quest", "restricted_schedule", b"restricted_schedule", "safety_feature_limits", b"safety_feature_limits", "safety_flags", b"safety_flags", "safety_state", b"safety_state", "store_country", b"store_country"]  # noqa: Y015
    def ClearField(self, field_name: _ClearFieldArgType) -> None: ...
    _WhichOneofReturnType__age_assurance_data: _TypeAlias = _typing.Literal["age_assurance_data"]  # noqa: Y015
    _WhichOneofArgType__age_assurance_data: _TypeAlias = _typing.Literal["_age_assurance_data", b"_age_assurance_data"]  # noqa: Y015
    _WhichOneofReturnType__badges: _TypeAlias = _typing.Literal["badges"]  # noqa: Y015
    _WhichOneofArgType__badges: _TypeAlias = _typing.Literal["_badges", b"_badges"]  # noqa: Y015
    _WhichOneofReturnType__collectibles: _TypeAlias = _typing.Literal["collectibles"]  # noqa: Y015
    _WhichOneofArgType__collectibles: _TypeAlias = _typing.Literal["_collectibles", b"_collectibles"]  # noqa: Y015
    _WhichOneofReturnType__cross_platform_restriction: _TypeAlias = _typing.Literal["cross_platform_restriction"]  # noqa: Y015
    _WhichOneofArgType__cross_platform_restriction: _TypeAlias = _typing.Literal["_cross_platform_restriction", b"_cross_platform_restriction"]  # noqa: Y015
    _WhichOneofReturnType__display_name_styles: _TypeAlias = _typing.Literal["display_name_styles"]  # noqa: Y015
    _WhichOneofArgType__display_name_styles: _TypeAlias = _typing.Literal["_display_name_styles", b"_display_name_styles"]  # noqa: Y015
    _WhichOneofReturnType__perks: _TypeAlias = _typing.Literal["perks"]  # noqa: Y015
    _WhichOneofArgType__perks: _TypeAlias = _typing.Literal["_perks", b"_perks"]  # noqa: Y015
    _WhichOneofReturnType__premium_state: _TypeAlias = _typing.Literal["premium_state"]  # noqa: Y015
    _WhichOneofArgType__premium_state: _TypeAlias = _typing.Literal["_premium_state", b"_premium_state"]  # noqa: Y015
    _WhichOneofReturnType__primary_guild: _TypeAlias = _typing.Literal["primary_guild"]  # noqa: Y015
    _WhichOneofArgType__primary_guild: _TypeAlias = _typing.Literal["_primary_guild", b"_primary_guild"]  # noqa: Y015
    _WhichOneofReturnType__quest: _TypeAlias = _typing.Literal["quest"]  # noqa: Y015
    _WhichOneofArgType__quest: _TypeAlias = _typing.Literal["_quest", b"_quest"]  # noqa: Y015
    _WhichOneofReturnType__restricted_schedule: _TypeAlias = _typing.Literal["restricted_schedule"]  # noqa: Y015
    _WhichOneofArgType__restricted_schedule: _TypeAlias = _typing.Literal["_restricted_schedule", b"_restricted_schedule"]  # noqa: Y015
    _WhichOneofReturnType__safety_state: _TypeAlias = _typing.Literal["safety_state"]  # noqa: Y015
    _WhichOneofArgType__safety_state: _TypeAlias = _typing.Literal["_safety_state", b"_safety_state"]  # noqa: Y015
    _WhichOneofReturnType__store_country: _TypeAlias = _typing.Literal["store_country"]  # noqa: Y015
    _WhichOneofArgType__store_country: _TypeAlias = _typing.Literal["_store_country", b"_store_country"]  # noqa: Y015
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__age_assurance_data) -> _WhichOneofReturnType__age_assurance_data | None: ...
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__badges) -> _WhichOneofReturnType__badges | None: ...
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__collectibles) -> _WhichOneofReturnType__collectibles | None: ...
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__cross_platform_restriction) -> _WhichOneofReturnType__cross_platform_restriction | None: ...
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__display_name_styles) -> _WhichOneofReturnType__display_name_styles | None: ...
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__perks) -> _WhichOneofReturnType__perks | None: ...
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__premium_state) -> _WhichOneofReturnType__premium_state | None: ...
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__primary_guild) -> _WhichOneofReturnType__primary_guild | None: ...
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__quest) -> _WhichOneofReturnType__quest | None: ...
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__restricted_schedule) -> _WhichOneofReturnType__restricted_schedule | None: ...
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__safety_state) -> _WhichOneofReturnType__safety_state | None: ...
    @_typing.overload
    def WhichOneof(self, oneof_group: _WhichOneofArgType__store_country) -> _WhichOneofReturnType__store_country | None: ...

Global___UserData: _TypeAlias = UserData  # noqa: Y015
